@@ -42,6 +42,7 @@
 #include "fedit_config.h"
 
 #include <rcsc/formation/formation_dt.h>
+#include <rcsc/formation/formation_knn.h>
 
 #include <rcsc/geom/triangle_2d.h>
 
@@ -60,10 +61,14 @@ FEditCanvas::FEditCanvas( MainWindow * parent )
     , M_field_center( 0, 0 )
     , M_focus_point( 0.0, 0.0 )
     , M_enlarged( true )
+    , M_show_index( true )
+    , M_show_circumcircle( false )
     , M_field_brush( QColor( 31, 160, 31 ), Qt::SolidPattern )
     , M_field_dark_brush( QColor( 15, 143, 15 ), Qt::SolidPattern )
     , M_line_pen( QColor( 255, 255, 255 ), 1, Qt::SolidLine )
-    , M_triangle_pen( QColor( 255, 127, 0 ), 1, Qt::SolidLine )
+      //, M_triangle_pen( QColor( 255, 127, 0 ), 1, Qt::SolidLine )
+    , M_triangle_pen( QColor( 255, 0, 0 ), 1, Qt::SolidLine )
+      //, M_triangle_pen( QColor( 0, 0, 255 ), 1, Qt::SolidLine )
     , M_triangle_font( "Sans Serif", 10 )
     , M_area_pen( QColor( 127, 127, 127 ), 1, Qt::SolidLine )
     , M_ball_pen( QColor( 255, 255, 255 ), 1, Qt::SolidLine )
@@ -72,7 +77,7 @@ FEditCanvas::FEditCanvas( MainWindow * parent )
     , M_select_pen( Qt::white, 2, Qt::SolidLine )
     , M_left_team_brush( QColor( 255, 215, 0 ), Qt::SolidPattern )
     , M_right_team_brush( QColor( 240, 20, 20 ), Qt::SolidPattern )
-    , M_mirror_brush( QColor( 0, 255, 95 ), Qt::SolidPattern )
+    , M_synmetry_brush( QColor( 0, 255, 95 ), Qt::SolidPattern )
     , M_player_font( "Sans Serif", 10 )
 {
     assert( parent );
@@ -260,70 +265,77 @@ FEditCanvas::drawContainedArea( QPainter & painter )
         return;
     }
 
-    if ( f->methodName() != rcsc::FormationDT::name() )
+    if ( f->methodName() == rcsc::FormationDT::name() )
     {
-        return;
-    }
+        if ( ptr->triangulation().vertices().size() < 3 )
+        {
+            return;
+        }
 
-    if ( ptr->triangulation().vertices().size() < 3 )
-    {
-        return;
-    }
+        //std::cerr << "triangle size = " << ptr->triangulation().triangleMap().size()
+        //          << std::endl;
 
-    // draw polygon
-    const rcsc::DelaunayTriangulation::TrianglePtr tri
-        = ptr->triangulation().findTriangleContains( ptr->ball() );
-    if ( tri )
-    {
-        painter.setPen( Qt::NoPen );
-        painter.setBrush( M_field_dark_brush );
+        // draw polygon
+        const rcsc::DelaunayTriangulation::TrianglePtr tri
+            = ptr->triangulation().findTriangleContains( ptr->ball() );
+        if ( tri )
+        {
+            painter.setPen( Qt::NoPen );
+            painter.setBrush( M_field_dark_brush );
 
-        QPointArray vertices( 3 );
-        vertices.setPoint( 0,
-                           screenX( tri->vertex( 0 )->pos().x ),
-                           screenY( tri->vertex( 0 )->pos().y ) );
-        vertices.setPoint( 1,
-                           screenX( tri->vertex( 1 )->pos().x ),
-                           screenY( tri->vertex( 1 )->pos().y ) );
-        vertices.setPoint( 2,
-                           screenX( tri->vertex( 2 )->pos().x ),
-                           screenY( tri->vertex( 2 )->pos().y ) );
+            QPointArray vertices( 3 );
+            vertices.setPoint( 0,
+                               screenX( tri->vertex( 0 )->pos().x ),
+                               screenY( tri->vertex( 0 )->pos().y ) );
+            vertices.setPoint( 1,
+                               screenX( tri->vertex( 1 )->pos().x ),
+                               screenY( tri->vertex( 1 )->pos().y ) );
+            vertices.setPoint( 2,
+                               screenX( tri->vertex( 2 )->pos().x ),
+                               screenY( tri->vertex( 2 )->pos().y ) );
 
-        painter.drawConvexPolygon( vertices );
+            painter.drawConvexPolygon( vertices );
 
-        // draw center point
-        rcsc::Vector2D center
-            = rcsc::Triangle2D::centroid( tri->vertex( 0 )->pos(),
-                                          tri->vertex( 1 )->pos(),
-                                          tri->vertex( 2 )->pos() );
+            // draw center point
+            rcsc::Vector2D center
+                = rcsc::Triangle2D::centroid( tri->vertex( 0 )->pos(),
+                                              tri->vertex( 1 )->pos(),
+                                              tri->vertex( 2 )->pos() );
 
-        painter.setPen( Qt::cyan );
-        painter.setBrush( Qt::cyan );
-        painter.drawRect( screenX( center.x ) - 1,
-                          screenY( center.y ) - 1,
-                          3, 3 );
+
+            painter.setPen( Qt::red );
+            painter.setBrush( Qt::red );
+            painter.drawRect( screenX( center.x ) - 1,
+                              screenY( center.y ) - 1,
+                              3, 3 );
 #if 0
-        center = rcsc::Triangle2D::incenter( tri->vertex( 0 )->pos(),
-                                             tri->vertex( 1 )->pos(),
-                                             tri->vertex( 2 )->pos() );
-
-        painter.setPen( Qt::red );
-        painter.setBrush( Qt::red );
-        painter.drawRect( screenX( center.x ) - 1,
-                          screenY( center.y ) - 1,
-                          3, 3 );
-
-
-        center = rcsc::Triangle2D::circumcenter( tri->vertex( 0 )->pos(),
+            center = rcsc::Triangle2D::incenter( tri->vertex( 0 )->pos(),
                                                  tri->vertex( 1 )->pos(),
                                                  tri->vertex( 2 )->pos() );
-
-        painter.setPen( Qt::red );
-        painter.setBrush( Qt::red );
-        painter.drawRect( screenX( center.x ) - 1,
-                          screenY( center.y ) - 1,
-                          3, 3 );
+            painter.setPen( Qt::red );
+            painter.setBrush( Qt::red );
+            painter.drawRect( screenX( center.x ) - 1,
+                              screenY( center.y ) - 1,
+                              3, 3 );
 #endif
+
+            // draw circum circle of this triangle
+
+            if ( M_show_circumcircle )
+            {
+                int x = screenX( tri->circumcenter().x );
+                int y = screenY( tri->circumcenter().y );
+                int r = scale( tri->circumradius() );
+
+                painter.setPen( Qt::cyan );
+                painter.setBrush( Qt::cyan );
+                painter.drawRect( x - 1, y - 1,
+                                  3, 3 );
+                painter.setBrush( Qt::NoBrush );
+                painter.drawEllipse( x - r, y - r,
+                                     r * 2, r * 2 );
+            }
+        }
     }
 }
 
@@ -346,11 +358,65 @@ FEditCanvas::drawTrainingData( QPainter & painter )
         return;
     }
 
-    // if method type is not a FormationDelaunayTriangulation
+    if ( f->methodName() == rcsc::FormationDT::name()
+         || f->methodName() == rcsc::FormationKNN::name() )
+    {
+        // draw delaunay triangulation
+
+        if ( ptr->triangulation().vertices().size() < 3 )
+        {
+            // too few kernel points
+            // no valid triangulation
+            return;
+        }
+
+        painter.setPen( M_triangle_pen );
+        painter.setBrush( Qt::NoBrush );
+
+        const std::map< int, rcsc::DelaunayTriangulation::EdgePtr >::const_iterator edge_end
+            = ptr->triangulation().edgeMap().end();
+        for ( std::map< int, rcsc::DelaunayTriangulation::EdgePtr >::const_iterator it
+                  = ptr->triangulation().edgeMap().begin();
+              it != edge_end;
+              ++it )
+        {
+            painter.drawLine( screenX( it->second->vertex( 0 )->pos().x ),
+                              screenY( it->second->vertex( 0 )->pos().y ),
+                              screenX( it->second->vertex( 1 )->pos().x ),
+                              screenY( it->second->vertex( 1 )->pos().y ) );
+        }
+
+        painter.setFont( M_player_font );
+        painter.setPen( Qt::red );
+        //painter.setPen( Qt::black );
+        painter.setBackgroundMode( Qt::TransparentMode );
+
+        const int radius = scale( 0.7 );
+        int count = 0;
+        const std::list< rcsc::Formation::Snapshot >::const_iterator data_end
+            = ptr->trainingData().end();
+        for ( std::list< rcsc::Formation::Snapshot >::const_iterator it
+                  = ptr->trainingData().begin();
+              it != data_end;
+              ++it )
+        {
+            int ix = screenX( it->ball_.x );
+            int iy = screenY( it->ball_.y );
+            //char buf[4];
+            //std::snprintf( buf, 4, "%2d", ++count );
+            if ( M_show_index )
+            {
+                painter.drawText( ix + radius, iy - radius,
+                                  QString().sprintf( "%2d", ++count ) ); //QString::fromAscii( buf ) );
+            }
+        }
+    }
+    else
+    // if method type is not a FormationDT
     // only sample ball points are drawn
-    if ( f->methodName() != rcsc::FormationDT::name() )
     {
         painter.setPen( Qt::red );
+        //painter.setPen( Qt::black );
         painter.setBrush( Qt::NoBrush );
         painter.setFont( M_player_font );
         //painter.setBackgroundMode( Qt::TransparentMode );
@@ -358,15 +424,15 @@ FEditCanvas::drawTrainingData( QPainter & painter )
         const int r = scale( 0.5 );
 
         int count = 0;
-        const std::list< rcsc::Formation::Snapshot >::const_iterator train_end
+        const std::list< rcsc::Formation::Snapshot >::const_iterator data_end
             = ptr->trainingData().end();
-        for ( std::list< rcsc::Formation::Snapshot >::const_iterator train_it
+        for ( std::list< rcsc::Formation::Snapshot >::const_iterator it
                   = ptr->trainingData().begin();
-              train_it != train_end;
-              ++train_it )
+              it != data_end;
+              ++it )
         {
-            int x = screenX( train_it->ball_.x );
-            int y = screenY( train_it->ball_.y );
+            int x = screenX( it->ball_.x );
+            int y = screenY( it->ball_.y );
             //painter.DrawCircle( x, y, r );
             painter.drawLine( x - r, y - r,
                               x + r, y + r );
@@ -374,58 +440,63 @@ FEditCanvas::drawTrainingData( QPainter & painter )
                               x + r, y - r );
             //char buf[4];
             //std::snprintf( buf, 4, "%2d", ++count );
-            painter.drawText( x + r, y - r,
-                              QString().sprintf( "%2d", ++count ) );// QString::fromAscii( buf ) );
+            if ( M_show_index )
+            {
+                painter.drawText( x + r, y - r,
+                                  QString().sprintf( "%2d", ++count ) );// QString::fromAscii( buf ) );
+            }
         }
 
-        return;
     }
 
-    // draw delaunay triangulation
-
-    if ( ptr->triangulation().vertices().size() < 3 )
+    if ( f->methodName() == rcsc::FormationKNN::name() )
     {
-        // too few kernel points
-        // no valid triangulation
-        return;
+        const int k = std::min( size_t( 3 ), ptr->trainingData().size() );
+
+        std::vector< rcsc::Vector2D > points( k );
+        std::vector< double > dists( k, std::numeric_limits< double >::max() );
+
+        const std::list< rcsc::Formation::Snapshot >::const_iterator end
+            = ptr->trainingData().end();
+        for ( std::list< rcsc::Formation::Snapshot >::const_iterator it
+                  = ptr->trainingData().begin();
+              it != end;
+              ++it )
+        {
+            double d2 = it->ball_.dist2( ptr->ball() );
+            for ( int i = 0; i < k; ++i )
+            {
+                if ( dists[i] > d2 )
+                {
+                    for ( int j = k - 2; j >= i; --j )
+                    {
+                        dists[j+1] = dists[j];
+                        points[j+1] = points[j];
+                    }
+                    dists[i] = d2;
+                    points[i] = it->ball_;
+                    break;
+                }
+            }
+        }
+
+        painter.setPen( Qt::blue );
+        painter.setBrush( Qt::NoBrush );
+        const int r = scale( 1.0 );
+
+        for ( int i = 0; i < k; ++i )
+        {
+            //std::cerr << "  " << i << " : " << points[i] << std::endl;
+            int x = screenX( points[i].x );
+            int y = screenY( points[i].y );
+            painter.drawEllipse( x - r, y - r, r*2, r*2 );
+//             painter.drawLine( x - r, y - r,
+//                               x + r, y + r );
+//             painter.drawLine( x - r, y + r,
+//                               x + r, y - r );
+        }
     }
 
-    painter.setPen( M_triangle_pen );
-    painter.setBrush( Qt::NoBrush );
-
-    const std::map< int, rcsc::DelaunayTriangulation::EdgePtr >::const_iterator end
-        = ptr->triangulation().edgeMap().end();
-    for ( std::map< int, rcsc::DelaunayTriangulation::EdgePtr >::const_iterator it
-              = ptr->triangulation().edgeMap().begin();
-          it != end;
-          ++it )
-    {
-        painter.drawLine( screenX( it->second->vertex( 0 )->pos().x ),
-                          screenY( it->second->vertex( 0 )->pos().y ),
-                          screenX( it->second->vertex( 1 )->pos().x ),
-                          screenY( it->second->vertex( 1 )->pos().y ) );
-    }
-
-    painter.setFont( M_player_font );
-    painter.setPen( Qt::red );
-    painter.setBackgroundMode( Qt::TransparentMode );
-
-    const int radius = scale( 0.7 );
-    int count = 0;
-    const std::list< rcsc::Formation::Snapshot >::const_iterator v_end
-        = ptr->trainingData().end();
-    for ( std::list< rcsc::Formation::Snapshot >::const_iterator it
-              = ptr->trainingData().begin();
-          it != v_end;
-          ++it )
-    {
-        int ix = screenX( it->ball_.x );
-        int iy = screenY( it->ball_.y );
-        //char buf[4];
-        //std::snprintf( buf, 4, "%2d", ++count );
-        painter.drawText( ix + radius, iy - radius,
-                          QString().sprintf( "%2d", ++count ) ); //QString::fromAscii( buf ) );
-    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -525,18 +596,18 @@ FEditCanvas::drawPlayers( QPainter & painter )
             if ( selection == it )
             {
                 painter.setPen( M_select_pen );
-                painter.setBrush( f->isMirrorType( unum )
-                                  ? M_mirror_brush
+                painter.setBrush( f->isSynmetryType( unum )
+                                  ? M_synmetry_brush
                                   : M_left_team_brush );
                 painter.drawEllipse( ix - selected_radius,
                                      iy - selected_radius,
                                      selected_radius * 2,
                                      selected_radius * 2 );
             }
-            else if ( f->isMirrorType( unum ) )
+            else if ( f->isSynmetryType( unum ) )
             {
                 painter.setPen( M_player_pen );
-                painter.setBrush( M_mirror_brush );
+                painter.setBrush( M_synmetry_brush );
                 painter.drawEllipse( ix - radius,
                                      iy - radius,
                                      diameter,
@@ -662,6 +733,7 @@ FEditCanvas::zoomIn()
 {
     M_field_scale *= 1.5;
     M_zoomed = true;
+    updateSize();
 
     this->update();
 }
@@ -675,6 +747,7 @@ FEditCanvas::zoomOut()
 {
     M_field_scale /= 1.5;
     M_zoomed = true;
+    updateSize();
 
     this->update();
 }
@@ -705,6 +778,29 @@ FEditCanvas::toggleEnlarge( bool on )
     this->update();
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditCanvas::toggleShowIndex( bool on )
+{
+    M_show_index = on;
+
+    this->update();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditCanvas::toggleShowCircumcircle( bool on )
+{
+    M_show_circumcircle = on;
+
+    this->update();
+}
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -813,8 +909,8 @@ FEditCanvas::mouseMoveEvent( QMouseEvent * event )
         boost::shared_ptr< FEditData > ptr = M_data_ptr.lock();
 
         if ( event->state() & Qt::ControlButton
-             || ( ptr
-                  && ptr->getSelectType() == FEditData::NO_SELECT )
+             //|| ( ptr
+             //&& ptr->getSelectType() == FEditData::NO_SELECT )
              )
         {
             int new_x = screenX( focusPoint().x );
@@ -824,9 +920,8 @@ FEditCanvas::mouseMoveEvent( QMouseEvent * event )
             setFocusPoint( QPoint( new_x, new_y ) );
             this->update();
         }
-
-        if ( ptr
-             && ptr->getSelectType() != FEditData::NO_SELECT )
+        else if ( ptr
+                  && ptr->getSelectType() != FEditData::NO_SELECT )
         {
             ptr->setObjectDragPoint( field_x, field_y );
 
