@@ -56,9 +56,6 @@ class FEditCanvas
 
 private:
 
-    //! parent frame
-    MainWindow * M_parent;
-
     //! weak reference pointer
     boost::weak_ptr< FEditData > M_data_ptr;
 
@@ -77,6 +74,12 @@ private:
     //! object enlarge status flag
     bool M_enlarged;
 
+    //! show/hide index number
+    bool M_show_index;
+
+    //! show/hide circumcircle of the current contained area if method type is DT
+    bool M_show_circumcircle;
+
     //! 0: left, 1: middle, 2: right
     MouseState M_mouse_state[3];
 
@@ -97,7 +100,7 @@ private:
     QPen M_select_pen;
     QBrush M_left_team_brush;
     QBrush M_right_team_brush;
-    QBrush M_mirror_brush;
+    QBrush M_synmetry_brush;
     QFont M_player_font;
 
 
@@ -175,6 +178,8 @@ public slots:
     void fitSize();
 
     void toggleEnlarge( bool on );
+    void toggleShowIndex( bool on );
+    void toggleShowCircumcircle( bool on );
 
 signals:
 
