@@ -39,6 +39,7 @@
 #include <rcsc/param/cmd_line_parser.h>
 
 #include <iostream>
+#include <cmath>
 
 const double FEditConfig::PITCH_LENGTH = 105.0;
 const double FEditConfig::PITCH_WIDTH = 68.0;
@@ -90,6 +91,9 @@ FEditConfig::~FEditConfig()
 void
 FEditConfig::init()
 {
+    M_initial_ball_x = 0.0;
+    M_initial_ball_y = 0.0;
+
     M_maximize = false;
     M_full_screen = false;
 
@@ -116,6 +120,9 @@ FEditConfig::parseCmdLine( int argc,
 
     bool help = false;
     bool version = false;
+    std::string geometry;
+    std::string ball_pos;
+
     system_options.add()
         ( "help", "h",
           rcsc::BoolSwitch( &help ),
@@ -132,12 +139,15 @@ FEditConfig::parseCmdLine( int argc,
         ( "data", "d",
           &M_data_file,
           "specifies the .dat file to be opened." )
+        ( "initial-ball-pos", "",
+          &ball_pos,
+          "specfies the initial ball position \"X:Y\". e.g. --initial-ball-pos=10.0:-8.3" )
         ( "auto-backup", "",
           &M_auto_backup,
           "make backup files automatically" )
-        ( "logging", "",
-          rcsc::BoolSwitch( &M_logging ),
-          "logging formation editor operation." )
+        //( "logging", "",
+        //  rcsc::BoolSwitch( &M_logging ),
+        //  "logging formation editor operation." )
         ;
 
     view_options.add()
@@ -147,18 +157,9 @@ FEditConfig::parseCmdLine( int argc,
         ( "full-screen", "",
           rcsc::BoolSwitch( &M_full_screen ),
           "start with a full screen window." )
-        ( "pos-x", "",
-          &M_pos_x,
-          "set left x position of a main window." )
-        ( "pos-y", "",
-          &M_pos_y,
-          "set top y position of a main window." )
-        ( "width", "",
-          &M_width,
-          "set width of a main window." )
-        ( "height", "",
-          &M_height,
-          "set height of a main window." )
+        ( "geometry", "",
+          &geometry,
+          "specifies the window geometry \"[WxH][+X+Y]\". e.g. --geometry=1024x768+0+0" )
         ;
 
     rcsc::CmdLineParser parser( argc, argv );
@@ -167,6 +168,9 @@ FEditConfig::parseCmdLine( int argc,
     parser.parse( editor_options );
     parser.parse( view_options );
 
+    //
+    // analyze input files
+    //
     for ( std::vector< std::string >::const_iterator it
               = parser.positionalOptions().begin();
           it != parser.positionalOptions().end();
@@ -183,8 +187,8 @@ FEditConfig::parseCmdLine( int argc,
             }
             M_conf_file = *it;
         }
-        else if( it->length() > 4
-             && it->compare( it->length() - 4, 4, ".dat" ) == 0 )
+        else if ( it->length() > 4
+                  && it->compare( it->length() - 4, 4, ".dat" ) == 0 )
         {
             if ( ! M_data_file.empty() )
             {
@@ -195,6 +199,9 @@ FEditConfig::parseCmdLine( int argc,
         }
     }
 
+    //
+    // help message
+    //
     if ( help
          || parser.failed()
          || parser.positionalOptions().size() > 2 )
@@ -208,6 +215,9 @@ FEditConfig::parseCmdLine( int argc,
         return false;
     }
 
+    //
+    // version message
+    //
     if ( version )
     {
         std::cout << "fedit" << " Version " << VERSION
@@ -215,5 +225,81 @@ FEditConfig::parseCmdLine( int argc,
         return false;
     }
 
+    //
+    // initial ball position
+    //
+    if ( ! ball_pos.empty() )
+    {
+        char delim;
+        double x, y;
+        if ( std::sscanf( ball_pos.c_str(),
+                          " %lf %c %lf " ,
+                          &x, &delim, &y ) == 3 )
+        {
+            if ( std::fabs( x ) < PITCH_LENGTH * 0.5 + 5.0
+                 && std::fabs( y ) < PITCH_WIDTH * 0.5 + 5.0 )
+            {
+                if ( delim == '-' && y >= 0.0 )
+                {
+                    y = -y;
+                }
+
+                M_initial_ball_x = x;
+                M_initial_ball_y = y;
+            }
+            else
+            {
+                std::cerr << "Initial ball position is over the range ["
+                          << ball_pos
+                          << "]" << std::endl;
+            }
+        }
+        else
+        {
+            std::cerr << "Illegal initial ball position [" << ball_pos
+                      << "]" << std::endl;
+        }
+    }
+
+    //
+    // window size and position
+    //
+    if ( ! geometry.empty() )
+    {
+        int w = -1, h = -1;
+        int x = -1, y = -1;
+
+        int num = std::sscanf( geometry.c_str(),
+                               " %d x %d %d %d " ,
+                               &w, &h, &x, &y );
+        if ( num == 4 || num == 2 )
+        {
+            if ( w <= 0 || h <= 0 )
+            {
+                std::cerr << "Illegal window size [" << geometry
+                          << "]" << std::endl;
+            }
+            else
+            {
+                M_width = w;
+                M_height = h;
+                M_pos_x = x;
+                M_pos_y = y;
+            }
+        }
+        else if ( std::sscanf( geometry.c_str(),
+                               " %d %d " ,
+                               &x, &y ) == 2 )
+        {
+            M_pos_x = x;
+            M_pos_y = y;
+        }
+        else
+        {
+            std::cerr << "Illegal geometry format [" << geometry
+                      << "]" << std::endl;
+        }
+    }
+
     return true;
 }
