@@ -72,6 +72,9 @@ private:
     std::string M_conf_file;
     std::string M_data_file;
 
+    double M_initial_ball_x;
+    double M_initial_ball_y;
+
     bool M_maximize;
     bool M_full_screen;
 
@@ -118,6 +121,18 @@ public:
           return M_data_file;
       }
 
+    const
+    double & initialBallX() const
+      {
+          return M_initial_ball_x;
+      }
+
+    const
+    double & initialBallY() const
+      {
+          return M_initial_ball_y;
+      }
+
     bool maximize() const
       {
           return M_maximize;
