@@ -37,11 +37,9 @@
 
 #include "fedit_config.h"
 
-#include <rcsc/formation/formation_bpn.h>
+#include <rcsc/formation/formation_factory.h>
 #include <rcsc/formation/formation_dt.h>
-#include <rcsc/formation/formation_ngnet.h>
-#include <rcsc/formation/formation_rbf.h>
-#include <rcsc/formation/formation_sbsp.h>
+#include <rcsc/formation/formation_knn.h>
 #include <rcsc/math_util.h>
 
 #include <algorithm>
@@ -67,14 +65,15 @@ FEditData::FEditData()
     , M_filepath_train( "" )
     , M_modified( false )
     , M_training_data_changed( false )
-    , M_delete_mode( false )
     , M_our_dragged( 11, 0 )
     , M_our_players( 11 )
     , M_opp_players( 11 )
+    , M_symmetric_mode( true )
     , M_select_type( NO_SELECT )
     , M_select_index( 0 )
     , M_ball_draggable( true )
     , M_player_auto_move( true )
+    , M_data_auto_select( true )
 {
     init();
 }
@@ -92,46 +91,6 @@ FEditData::~FEditData()
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
-boost::shared_ptr< rcsc::Formation >
-FEditData::create_formation( const std::string & type_name )
-{
-    boost::shared_ptr< rcsc::Formation > f;
-
-    if ( type_name == rcsc::FormationBPN::name() )
-    {
-        f = boost::shared_ptr< rcsc::Formation >( new rcsc::FormationBPN );
-    }
-    else if ( type_name == rcsc::FormationDT::name() )
-    {
-        f = boost::shared_ptr< rcsc::Formation >( new rcsc::FormationDT );
-    }
-    else if ( type_name == rcsc::FormationNGNet::name() )
-    {
-        f = boost::shared_ptr< rcsc::Formation >( new rcsc::FormationNGNet );
-    }
-    else if ( type_name == rcsc::FormationRBF::name() )
-    {
-        f = boost::shared_ptr< rcsc::Formation >( new rcsc::FormationRBF );
-    }
-    else if ( type_name == rcsc::FormationSBSP::name() )
-    {
-        f = boost::shared_ptr< rcsc::Formation >( new rcsc::FormationSBSP );
-    }
-    else
-    {
-        std::cerr << __FILE__ << ':' << __LINE__
-                  << " ***RRROR*** Unknown formation method name. ["
-                  << type_name << "]"
-                  << std::endl;
-    }
-
-    return f;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
 */
 void
 FEditData::init()
@@ -139,7 +98,9 @@ FEditData::init()
     M_modified = false;
     M_training_data_changed = false;
 
-    M_ball.assign( 0.0, 0.0 );
+    M_ball.assign( FEditConfig::instance().initialBallX(),
+                   FEditConfig::instance().initialBallY() );
+
     M_our_dragged.assign( 11, 0 );
     for ( int i = 1; i <= 11; ++i )
     {
@@ -183,7 +144,9 @@ FEditData::backup( const std::string & filepath )
         std::snprintf( time_str, 64, ".time-%ld", current );
     }
 
-    std::string backup_filepath = filepath + time_str;
+    std::string backup_filepath = ".";
+    backup_filepath += filepath;
+    backup_filepath += time_str;
 
     std::ifstream fin( filepath.c_str() );
     std::ofstream fout( backup_filepath.c_str() );
@@ -207,7 +170,7 @@ FEditData::backup( const std::string & filepath )
 void
 FEditData::createDefaultParam()
 {
-    M_formation = create_formation( M_training_type_name );
+    M_formation = rcsc::make_formation( M_training_type_name );
 
     if ( ! M_formation )
     {
@@ -244,7 +207,7 @@ FEditData::open( const std::string & filepath )
     {
         std::string temp, type;
         fin >> temp >> type; // read training method type name
-        M_formation = create_formation( type );
+        M_formation = rcsc::make_formation( type );
 
         if ( ! M_formation )
         {
@@ -329,7 +292,8 @@ FEditData::openTrainingData( const std::string & filepath )
 
     updateTriangulation();
 
-    moveBallTo( 0.0, 0.0 );
+    moveBallTo( FEditConfig::instance().initialBallX(),
+                FEditConfig::instance().initialBallY() );
     updatePlayerPosition();
 
     return true;
@@ -494,13 +458,6 @@ FEditData::updatePlayerPosition()
         return;
     }
 
-
-    if ( M_delete_mode )
-    {
-        M_delete_mode = false;
-        return;
-    }
-
     // update all players' position using formation param
 
     const rcsc::Vector2D & bpos = M_ball;
@@ -624,30 +581,70 @@ FEditData::reverseY()
 
     M_ball.y *= -1.0;
 
-    std::vector< rcsc::Vector2D > old_positions = M_our_players;
+    reverseY( M_our_players );
+
+    // TODO: right side players
+
+    //
+    // update index
+    //
+    if ( M_data_auto_select )
+    {
+        int index = 1;
+        const std::list< rcsc::Formation::Snapshot >::iterator end = M_training_data.end();
+        for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+              it != end;
+              ++it, ++index )
+        {
+            if ( it->ball_.dist2( M_ball ) < 1.0*1.0 )
+            {
+                M_ball = it->ball_;
+                M_current_index = index;
+                break;
+            }
+        }
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FEditData::reverseY( std::vector< rcsc::Vector2D > & our_players )
+{
+    if ( ! M_formation )
+    {
+        std::cerr << __FILE__ << ":" << __LINE__
+                  << " ***ERROR*** No formation!!"
+                  << std::endl;
+        return;
+    }
+
+    std::vector< rcsc::Vector2D > old_positions = our_players;
 
     int unum = 1;
-    for ( std::vector< rcsc::Vector2D >::iterator it = M_our_players.begin();
-          it != M_our_players.end();
+    for ( std::vector< rcsc::Vector2D >::iterator it = our_players.begin();
+          it != our_players.end();
           ++it )
     {
         if ( M_formation->isCenterType( unum ) )
         {
             it->y *= -1.0;
         }
-        else if ( M_formation->isMirrorType( unum ) )
+        else if ( M_formation->isSynmetryType( unum ) )
         {
-            int mirror_unum = M_formation->getMirrorNumber( unum );
-            if ( mirror_unum == 0 ) continue;
-            it->x = old_positions[mirror_unum - 1].x;
-            it->y = old_positions[mirror_unum - 1].y * -1.0;
+            int synmetry_unum = M_formation->getSynmetryNumber( unum );
+            if ( synmetry_unum == 0 ) continue;
+            it->x = old_positions[synmetry_unum - 1].x;
+            it->y = old_positions[synmetry_unum - 1].y * -1.0;
         }
         else if ( M_formation->isSideType( unum ) )
         {
             it->y *= -1.0;
             for ( int iunum = 1; iunum <= 11; ++iunum )
             {
-                if ( M_formation->getMirrorNumber( iunum ) == unum )
+                if ( M_formation->getSynmetryNumber( iunum ) == unum )
                 {
                     it->x = old_positions[iunum - 1].x;
                     it->y = old_positions[iunum - 1].y * -1.0;
@@ -656,12 +653,8 @@ FEditData::reverseY()
         }
         ++unum;
     }
-
-    // right side players
-
 }
 
-
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -682,6 +675,23 @@ FEditData::moveBallTo( const double & x,
         M_ball.y = 0.0;
     }
 
+    if ( M_data_auto_select )
+    {
+        int index = 1;
+        const std::list< rcsc::Formation::Snapshot >::iterator end = M_training_data.end();
+        for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+              it != end;
+              ++it, ++index )
+        {
+            if ( it->ball_.dist2( M_ball ) < 1.0*1.0 )
+            {
+                M_ball = it->ball_;
+                M_current_index = index;
+                break;
+            }
+        }
+    }
+
     updatePlayerPosition();
 }
 
@@ -796,6 +806,34 @@ FEditData::setObjectDragPoint( double x,
     case SELECT_OUR:
         M_our_dragged[M_select_index] = 1;
         M_our_players[M_select_index].assign( x, y );
+
+        if ( M_symmetric_mode
+             && M_ball.absY() < 0.1
+             && M_formation )
+        {
+            if ( M_formation->isSynmetryType( M_select_index + 1 ) )
+            {
+                int synmetry_unum = M_formation->getSynmetryNumber( M_select_index + 1 );
+                if ( synmetry_unum != 0 )
+                {
+                    M_our_players[synmetry_unum-1].x = x;
+                    M_our_players[synmetry_unum-1].y = -y;
+                }
+            }
+            else if ( M_formation->isSideType( M_select_index + 1 ) )
+            {
+                for ( int unum = 1; unum <= 11; ++unum )
+                {
+                    if ( M_formation->getSynmetryNumber( unum )
+                         == static_cast< int >( M_select_index + 1 ) )
+                    {
+                        M_our_players[unum-1].x = x;
+                        M_our_players[unum-1].y = -y;
+                    }
+                }
+            }
+        }
+
         break;
     case SELECT_OPP:
         M_opp_players[M_select_index].assign( x, y );
@@ -821,7 +859,7 @@ FEditData::setTrainingTypeName( const std::string & type_name )
 */
 void
 FEditData::updateRoleData( const int unum,
-                           const int mirror_unum,
+                           const int synmetry_unum,
                            const std::string & role_name )
 {
     if ( ! M_formation )
@@ -829,7 +867,7 @@ FEditData::updateRoleData( const int unum,
         return;
     }
 
-    if ( M_formation->updateRole( unum, mirror_unum, role_name ) )
+    if ( M_formation->updateRole( unum, synmetry_unum, role_name ) )
     {
         M_modified = true;
     }
@@ -846,7 +884,6 @@ FEditData::setBallPosition( const double & x,
     M_ball.assign( x, y );
 }
 
-
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -862,51 +899,6 @@ FEditData::setPlayerPosition( const int unum,
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
-std::string
-FEditData::recordTrainingData()
-{
-    if ( ! M_formation )
-    {
-        return std::string( "No formation data." );
-    }
-
-    if ( static_cast< int >( M_training_data.size() ) >= MAX_TRAINING_DATA_SIZE )
-    {
-        return std::string( "Too many recorded positin!!" );
-    }
-
-    for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
-          it != M_training_data.end();
-          ++it )
-    {
-        if ( it->ball_.dist( M_ball ) < 0.5 )
-        {
-            return std::string( "*** WARNING ***"
-                                " Exist too near recorded position!" );
-        }
-    }
-
-    M_training_data.push_back( rcsc::Formation::Snapshot( M_ball, M_our_players ) );
-    std::cerr << "Save positin. current data size = " << M_training_data.size()
-              << std::endl;
-
-    M_training_data_changed = true;
-
-    updateTriangulation();
-
-
-    if ( M_formation->methodName() == rcsc::FormationDT::name() )
-    {
-        train();
-    }
-
-    return std::string();
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-
 */
 bool
 FEditData::focusTrainingData( const int idx )
@@ -924,10 +916,13 @@ FEditData::focusTrainingData( const int idx )
         if ( idx == count )
         {
             M_ball = it->ball_;
+
             for ( std::size_t i = 0; i < 11; ++i )
             {
                 M_our_players[i] = it->players_[i];
             }
+
+            M_current_index = idx;
             return true;
         }
         ++count;
@@ -941,34 +936,265 @@ FEditData::focusTrainingData( const int idx )
 /*!
 
 */
-bool
-FEditData::replaceTrainingData( const int idx )
+std::string
+FEditData::recordTrainingData()
 {
-    if ( idx <= 0 )
+    return recordTrainingData( rcsc::Formation::Snapshot( M_ball, M_our_players ),
+                               M_symmetric_mode );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+std::string
+FEditData::recordTrainingData( const rcsc::Formation::Snapshot & snapshot,
+                               const bool symmetry )
+{
+    if ( ! M_formation )
+    {
+        return std::string( "No formation data." );
+    }
+
+    if ( static_cast< int >( M_training_data.size() ) >= MAX_TRAINING_DATA_SIZE )
+    {
+        return std::string( "Too many recorded positin!!" );
+    }
+
+    for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+          it != M_training_data.end();
+          ++it )
+    {
+        if ( it->ball_.dist( snapshot.ball_ ) < 0.5 )
+        {
+            return std::string( "*** WARNING ***"
+                                " Exist too near recorded position!" );
+        }
+    }
+
+    M_training_data.push_back( snapshot );
+    std::cerr << "Save positin. current data size = " << M_training_data.size()
+              << std::endl;
+
+    M_training_data_changed = true;
+
+    if ( symmetry )
+    {
+        recordSymmetricData( snapshot );
+    }
+    else
+    {
+        M_ball = snapshot.ball_;
+        M_our_players = snapshot.players_;
+    }
+
+    updateTriangulation();
+
+    if ( M_formation->methodName() == rcsc::FormationDT::name()
+         || M_formation->methodName() == rcsc::FormationKNN::name() )
+    {
+        train();
+    }
+
+    return std::string();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+FEditData::recordSymmetricData( const rcsc::Formation::Snapshot & snapshot )
+{
+    if ( snapshot.ball_.absY() < 0.5 )
     {
         return false;
     }
 
+    const rcsc::Vector2D ball( snapshot.ball_.x, - snapshot.ball_.y );
+
+    for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+          it != M_training_data.end();
+          ++it )
+    {
+        if ( it->ball_.dist( ball ) < 0.5 )
+        {
+            std::cerr << "***WARNING*** recordSymmetricData() exist too near data."
+                      << std::endl;
+            return false;
+        }
+    }
+
+    rcsc::Formation::Snapshot reversed = snapshot;
+
+    reversed.ball_.y *= -1.0;
+    reverseY( reversed.players_ );
+
+    M_training_data.push_back( reversed );
+    std::cerr << "Save symmetric positin. current data size = "
+              << M_training_data.size()
+              << std::endl;
+
+    M_ball = reversed.ball_;
+    M_our_players = reversed.players_;
+
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+std::string
+FEditData::insertTrainingData( const int idx )
+{
+    return insertTrainingData( idx,
+                               rcsc::Formation::Snapshot( M_ball, M_our_players ) );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+std::string
+FEditData::insertTrainingData( const int idx,
+                               const rcsc::Formation::Snapshot & snapshot )
+{
+    if ( static_cast< int >( M_training_data.size() ) >= MAX_TRAINING_DATA_SIZE )
+    {
+        return std::string( "Too many recorded positin!!" );
+    }
+
+    if ( idx < 0
+         || static_cast< int >( M_training_data.size() ) < idx )
+    {
+        return std::string( "Index is over the range." );
+    }
+
     std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+    for ( int i = 0; i < idx; ++ i )
+    {
+        ++it;
+    }
+
+    M_training_data.insert( it, snapshot );
+    std::cerr << "Inserted. current data size = "
+              << M_training_data.size()
+              << std::endl;
+
+    updateTriangulation();
+
+    if ( M_formation->methodName() == rcsc::FormationDT::name()
+         || M_formation->methodName() == rcsc::FormationKNN::name() )
+    {
+        train();
+    }
+
+    return std::string();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+FEditData::replaceTrainingData( const int idx )
+{
+    if ( idx <= 0
+         || static_cast< int >( M_training_data.size() ) < idx )
+    {
+        return false;
+    }
+
+    return replaceTrainingData( idx,
+                                rcsc::Formation::Snapshot( M_ball, M_our_players ),
+                                M_symmetric_mode );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+FEditData::replaceTrainingData( const int idx,
+                                const rcsc::Formation::Snapshot & snapshot,
+                                const bool symmetry )
+{
     int count = 1;
-    while ( it != M_training_data.end() )
+    for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+          it != M_training_data.end();
+          ++it, ++count )
     {
         if ( idx == count )
         {
-            *it = rcsc::Formation::Snapshot( M_ball, M_our_players );
+            *it = snapshot;
             M_training_data_changed = true;
+
+            std::cerr << "Replaced data. index = " << idx
+                      << std::endl;
+
+            if ( symmetry )
+            {
+                replaceSymmetricData( snapshot );
+            }
+            else
+            {
+                M_ball = snapshot.ball_;
+                M_our_players = snapshot.players_;
+            }
+
             updateTriangulation();
 
             if ( M_formation
-                 && M_formation->methodName() == rcsc::FormationDT::name() )
+                 && ( M_formation->methodName() == rcsc::FormationDT::name()
+                      || M_formation->methodName() == rcsc::FormationKNN::name() )
+                 )
             {
                 train();
             }
 
             return true;
         }
-        ++count;
-        ++it;
+    }
+
+    return false;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+FEditData::replaceSymmetricData( const rcsc::Formation::Snapshot & snapshot )
+{
+    if ( snapshot.ball_.absY() < 0.5 )
+    {
+        return false;
+    }
+
+    const rcsc::Vector2D ball( snapshot.ball_.x, - snapshot.ball_.y );
+
+    int index = 1;
+
+    for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+          it != M_training_data.end();
+          ++it, ++index )
+    {
+        if ( it->ball_.dist( ball ) < 0.1 )
+        {
+            rcsc::Formation::Snapshot reversed = snapshot;
+
+            reversed.ball_.y *= -1.0;
+            reverseY( reversed.players_ );
+
+            *it = reversed;
+            std::cerr << "Replaced symmetric data. index = " << index
+                      << std::endl;
+
+            M_ball = reversed.ball_;
+            M_our_players = reversed.players_;
+            return true;
+        }
     }
 
     return false;
@@ -981,34 +1207,39 @@ FEditData::replaceTrainingData( const int idx )
 bool
 FEditData::deleteTrainingData( const int idx )
 {
-    if ( idx <= 0 )
+    if ( idx <= 0
+         || static_cast< int >( M_training_data.size() ) < idx )
     {
         return false;
     }
 
-    std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+    bool deleted = false;
     int count = 1;
-    while ( it != M_training_data.end() )
+    for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_training_data.begin();
+          it != M_training_data.end();
+          ++it, ++count )
     {
         if ( idx == count )
         {
             M_training_data.erase( it );
             M_training_data_changed = true;
-            M_delete_mode = true;
+            deleted = true;
             break;
         }
-        ++count;
-        ++it;
     }
 
-    if ( M_delete_mode )
+    if ( deleted )
     {
+        M_current_index = 0;
         updateTriangulation();
 
         if ( M_formation
-             && M_formation->methodName() == rcsc::FormationDT::name() )
+             && ( M_formation->methodName() == rcsc::FormationDT::name()
+                  || M_formation->methodName() == rcsc::FormationKNN::name() )
+             )
         {
-            train();
+            M_formation->train( M_training_data );
+            M_modified = true;
         }
     }
 
