@@ -76,9 +76,6 @@ private:
     //! flag to check whether any training data are changed
     bool M_training_data_changed;
 
-    //! flag to keep the delete action status
-    bool M_delete_mode;
-
     //----------------------------------------
     // field status
 
@@ -100,22 +97,30 @@ private:
     //----------------------------------------
     // interaction info
 
+    //! symmetrically handle the data or not
+    bool M_symmetric_mode;
+
     //! object selection information
     SelectType M_select_type;
 
     //! selected player index, usualy unum-1
     std::size_t M_select_index;
 
-    //! status flag whether ball is draggable or not
+    //! ball is draggable or not
     bool M_ball_draggable;
 
-    //! status flag whether player is auto move mode or not.
+    //! player is automatically moved or not.
     bool M_player_auto_move;
 
+    //! exist data is automatically selected or not when ball is moved
+    bool M_data_auto_select;
 
     //! stored training data
     std::list< rcsc::Formation::Snapshot > M_training_data;
 
+    //! current data index
+    int M_current_index;
+
     //----------------------------------------
     //! editingformation parameters
     boost::shared_ptr< rcsc::Formation > M_formation;
@@ -126,15 +131,6 @@ public:
 
 		~FEditData();
 
-    /*!
-      \brief create new formation instance according to the training method name
-      \param type_name training method name
-      \return new formation parameter
-     */
-    static
-    boost::shared_ptr< rcsc::Formation >
-    create_formation( const std::string & type_name );
-
 private:
 
     void init();
@@ -220,6 +216,21 @@ public:
           return M_training_data;
       }
 
+    int currentIndex() const
+      {
+          return M_current_index;
+      }
+
+    void setSymmetricMode( bool on )
+      {
+          M_symmetric_mode = on;
+      }
+
+    bool symmetricMode() const
+      {
+          return M_symmetric_mode;
+      }
+
     /*!
       \brief get type of current selected object type
       \return object selection type
@@ -258,6 +269,16 @@ public:
           return M_player_auto_move;
       }
 
+    void setDataAutoSelect( bool on )
+      {
+          M_data_auto_select = on;
+      }
+
+    bool isDataAutoSelect() const
+      {
+          return M_data_auto_select;
+      }
+
     /*!
       \brief get formation param pointer
       \return pointer to the formation paramter instance
@@ -297,6 +318,7 @@ private:
 public:
 
     void reverseY();
+    void reverseY( std::vector< rcsc::Vector2D > & our_players );
 
     /*!
       \brief move the ball to the specified position
@@ -335,25 +357,39 @@ public:
     void setTrainingTypeName( const std::string & type_name );
 
     void updateRoleData( const int unum,
-                         const int mirror_unum,
+                         const int synmetry_unum,
                          const std::string & role_name );
 
     void setBallPosition( const double & x,
                           const double & y );
-
     void setPlayerPosition( const int unum,
                             const double & x,
                             const double & y );
 
-    std::string recordTrainingData();
-
     bool focusTrainingData( const int idx );
 
+    std::string recordTrainingData();
+    std::string recordTrainingData( const rcsc::Formation::Snapshot & snapshot,
+                                    const bool symmetry );
+
+    std::string insertTrainingData( const int idx );
+    std::string insertTrainingData( const int idx,
+                                    const rcsc::Formation::Snapshot & snapshot );
+
     bool replaceTrainingData( const int idx );
+    bool replaceTrainingData( const int idx,
+                              const rcsc::Formation::Snapshot & snapshot,
+                              const bool symmetry );
 
     bool deleteTrainingData( const int idx );
 
     void train();
+
+private:
+
+    bool recordSymmetricData( const rcsc::Formation::Snapshot & snapshot );
+
+    bool replaceSymmetricData( const rcsc::Formation::Snapshot & snapshot );
 };
 
 #endif
