@@ -43,9 +43,12 @@
 
 #include <rcsc/formation/formation_bpn.h>
 #include <rcsc/formation/formation_dt.h>
+#include <rcsc/formation/formation_knn.h>
 #include <rcsc/formation/formation_ngnet.h>
+//#include <rcsc/formation/formation_sbsp.h>
 #include <rcsc/formation/formation_rbf.h>
-#include <rcsc/formation/formation_sbsp.h>
+//#include <rcsc/formation/formation_static.h>
+//#include <rcsc/formation/formation_uva.h>
 
 #include <string>
 #include <iostream>
@@ -61,9 +64,11 @@
 #include "xpm/open.xpm"
 #include "xpm/train.xpm"
 #include "xpm/record.xpm"
+#include "xpm/insert.xpm"
 #include "xpm/replace.xpm"
 #include "xpm/reverse.xpm"
 #include "xpm/save.xpm"
+#include "xpm/symmetry.xpm"
 
 #ifndef PACKAGENAME
 #define PACKAGENAME "soccerwindow2"
@@ -100,7 +105,7 @@ MainWindow::MainWindow()
                   ? FEditConfig::instance().frameHeight()
                   : 480 );
     this->move( FEditConfig::instance().framePosX() > 0
-                ? FEditConfig::instance().framePosX() > 0
+                ? FEditConfig::instance().framePosX()
                 : this->x(),
                 FEditConfig::instance().framePosY() > 0
                 ? FEditConfig::instance().framePosY()
@@ -120,6 +125,8 @@ MainWindow::MainWindow()
              M_editor_canvas, SLOT( update() ) );
     connect( M_editor_canvas, SIGNAL( objectMoved() ),
              M_editor_dialog, SLOT( updateData() ) );
+    connect( M_editor_canvas, SIGNAL( objectMoved() ),
+             this, SLOT( updateDataIndex() ) );
     connect( M_editor_dialog, SIGNAL( shown( bool ) ),
              M_show_edit_dialog_act, SLOT( setOn( bool ) ) );
 }
@@ -149,7 +156,6 @@ MainWindow::init()
 //     M_editor_dialog->setMinimumSize( size );
 //     M_editor_dialog->setMaximumSize( size );
 
-    bool conf_opened = false;
     if ( ! FEditConfig::instance().confFile().empty() )
     {
         if ( ! FEditConfig::instance().dataFile().empty() )
@@ -315,7 +321,7 @@ MainWindow::createActionsMode()
                                           tr( "&Ball Drag" ),
                                           QKeySequence(),
                                           this );
-    M_toggle_ball_drag_act->setAccel( tr( "Ctrl+B" ) );
+    M_toggle_ball_drag_act->setAccel( Qt::Key_B );
     M_toggle_ball_drag_act->setStatusTip( tr( "Toggle ball drag mode." ) );
     M_toggle_ball_drag_act->setToggleAction( true );
     M_toggle_ball_drag_act->setOn( true );
@@ -326,13 +332,35 @@ MainWindow::createActionsMode()
                                                  tr( "&Auto Move" ),
                                                  QKeySequence(),
                                                  this );
-    M_toggle_player_auto_move_act->setAccel( tr( "Ctrl+P" ) );
+    //M_toggle_player_auto_move_act->setAccel( tr( "Ctrl+P" ) );
+    M_toggle_player_auto_move_act->setAccel( Qt::Key_A );
     M_toggle_player_auto_move_act->setStatusTip( tr( "Toggle player auto move mode." ) );
     M_toggle_player_auto_move_act->setToggleAction( true );
     M_toggle_player_auto_move_act->setOn( true );
     connect( M_toggle_player_auto_move_act, SIGNAL( toggled( bool ) ),
              this, SLOT( togglePlayerAutoMove( bool ) ) );
     //
+    M_toggle_data_auto_select_act = new QAction( tr( "&Data Auto Select" ),
+                                                 QKeySequence(),
+                                                 this );
+    M_toggle_data_auto_select_act->setAccel( Qt::Key_D );
+    M_toggle_data_auto_select_act->setStatusTip( tr( "Toggle data is automatically select or not when ball is moved." ) );
+    M_toggle_data_auto_select_act->setToggleAction( true );
+    M_toggle_data_auto_select_act->setOn( true );
+    connect( M_toggle_data_auto_select_act, SIGNAL( toggled( bool ) ),
+             this, SLOT( toggleDataAutoSelect( bool ) ) );
+    //
+    M_toggle_symmetric_mode_act = new QAction( QIconSet( QPixmap( symmetry_xpm ) ),
+                                               tr( "Symmetry" ),
+                                               QKeySequence(),
+                                               this );
+    M_toggle_symmetric_mode_act->setAccel( Qt::Key_S );
+    M_toggle_symmetric_mode_act->setStatusTip( tr( "Toggle symmetrical mode." ) );
+    M_toggle_symmetric_mode_act->setToggleAction( true );
+    M_toggle_symmetric_mode_act->setOn( true );
+    connect( M_toggle_symmetric_mode_act, SIGNAL( toggled( bool ) ),
+             this, SLOT( toggleSymmetricMode( bool ) ) );
+    //
     M_show_edit_dialog_act = new QAction( tr( "Show Edit Dialog" ),
                                           QKeySequence(),
                                           this );
@@ -351,6 +379,14 @@ MainWindow::createActionsMode()
 void
 MainWindow::createActionsData()
 {
+    M_insert_data_act = new QAction( QIconSet( QPixmap( insert_xpm ) ),
+                                      tr( "Insert" ),
+                                      QKeySequence(),
+                                      this );
+    M_insert_data_act->setStatusTip( tr( "Insert the screen data after the current index" ) );
+    connect( M_insert_data_act, SIGNAL( activated() ),
+             this, SLOT( insertData() ) );
+    //
     M_replace_data_act = new QAction( QIconSet( QPixmap( replace_xpm ) ),
                                       tr( "Replace" ),
                                       QKeySequence(),
@@ -373,7 +409,7 @@ MainWindow::createActionsData()
                                    tr( "ReverseY" ),
                                    QKeySequence(),
                                    this );
-    M_reverse_y_act->setAccel( tr( "Ctrl+R" ) );
+    M_reverse_y_act->setAccel( Qt::Key_R );
     M_reverse_y_act->setStatusTip( tr( "Reverse Y positions." ) );
     connect( M_reverse_y_act, SIGNAL( activated() ),
              this, SLOT( reverseY() ) );
@@ -428,15 +464,32 @@ MainWindow::createActionsView()
              M_editor_canvas, SLOT( fitSize() ) );
 
     M_toggle_enlarge_act = new QAction( tr( "Toggle Enlarge" ),
-                                  QKeySequence(),
-                                  this );
+                                        QKeySequence(),
+                                        this );
     M_toggle_enlarge_act->setAccel( Qt::Key_E );
     M_toggle_enlarge_act->setStatusTip( tr( "Toggle Enlarge Status" ) );
     M_toggle_enlarge_act->setToggleAction( true );
-    M_toggle_enlarge_act->setOn( true );
     connect( M_toggle_enlarge_act, SIGNAL( toggled( bool ) ),
              M_editor_canvas, SLOT( toggleEnlarge( bool ) ) );
+    M_toggle_enlarge_act->setOn( true );
 
+    M_toggle_show_index_act = new QAction( tr( "Show Index" ),
+                                           QKeySequence(),
+                                           this );
+    M_toggle_show_index_act->setStatusTip( tr( "Show/Hide Index" ) );
+    M_toggle_show_index_act->setToggleAction( true );
+    connect( M_toggle_show_index_act, SIGNAL( toggled( bool ) ),
+             M_editor_canvas, SLOT( toggleShowIndex( bool ) ) );
+    M_toggle_show_index_act->setOn( true );
+
+    M_toggle_show_circumcircle_act = new QAction( tr( "Show Circumcircle" ),
+                                                  QKeySequence(),
+                                                  this );
+    M_toggle_show_circumcircle_act->setStatusTip( tr( "Show/Hide Circumcircle" ) );
+    M_toggle_show_circumcircle_act->setToggleAction( true );
+    connect( M_toggle_show_circumcircle_act, SIGNAL( toggled( bool ) ),
+             M_editor_canvas, SLOT( toggleShowCircumcircle( bool ) ) );
+    M_toggle_show_circumcircle_act->setOn( false );
 
 }
 
@@ -509,11 +562,21 @@ MainWindow::createMenuEdit()
 {
     QPopupMenu * menu = new QPopupMenu( this );
 
+
+    M_record_data_act->addTo( menu );
+    M_insert_data_act->addTo( menu );
     M_replace_data_act->addTo( menu );
+    M_train_act->addTo( menu );
+
+    menu->insertSeparator();
+
     M_delete_data_act->addTo( menu );
 
+    menu->insertSeparator();
+
     M_reverse_y_act->addTo( menu );
 
+
     menuBar()->insertItem( tr( "&Edit" ), menu );
 }
 
@@ -528,6 +591,8 @@ MainWindow::createMenuMode()
 
     M_toggle_ball_drag_act->addTo( menu );
     M_toggle_player_auto_move_act->addTo( menu );
+    M_toggle_data_auto_select_act->addTo( menu );
+    M_toggle_symmetric_mode_act->addTo( menu );
 
     menu->insertSeparator();
 
@@ -552,6 +617,8 @@ MainWindow::createMenuView()
     menu->insertSeparator();
 
     M_toggle_enlarge_act->addTo( menu );
+    M_toggle_show_index_act->addTo( menu );
+    M_toggle_show_circumcircle_act->addTo( menu );
 
     menuBar()->insertItem( tr( "&View" ), menu );
 }
@@ -579,12 +646,12 @@ MainWindow::createToolBars()
     M_tool_bar = new QToolBar( this );
 
     M_save_all_act->addTo( M_tool_bar );
-    M_toggle_ball_drag_act->addTo( M_tool_bar );
+    //M_toggle_ball_drag_act->addTo( M_tool_bar );
     M_toggle_player_auto_move_act->addTo( M_tool_bar );
+    M_toggle_symmetric_mode_act->addTo( M_tool_bar );
 
     M_tool_bar->addSeparator();
 
-    M_replace_data_act->addTo( M_tool_bar );
     M_delete_data_act->addTo( M_tool_bar );
     M_reverse_y_act->addTo( M_tool_bar );
 
@@ -599,6 +666,8 @@ MainWindow::createToolBars()
     M_tool_bar->addSeparator();
 
     M_train_act->addTo( M_tool_bar );
+    M_replace_data_act->addTo( M_tool_bar );
+    M_insert_data_act->addTo( M_tool_bar );
     M_record_data_act->addTo( M_tool_bar );
 }
 
@@ -696,7 +765,7 @@ MainWindow::wheelEvent( QWheelEvent * event )
 
     int idx = M_index_spin_box->value();
 
-    if ( event->delta() < 0 )
+    if ( event->delta() > 0 )
     {
         --idx;
         if ( idx < 1 )
@@ -890,6 +959,7 @@ MainWindow::newFile()
 
     QStringList names;
     names.push_back( QString::fromAscii( rcsc::FormationDT::name().c_str() ) );
+    names.push_back( QString::fromAscii( rcsc::FormationKNN::name().c_str() ) );
     names.push_back( QString::fromAscii( rcsc::FormationBPN::name().c_str() ) );
     names.push_back( QString::fromAscii( rcsc::FormationRBF::name().c_str() ) );
     names.push_back( QString::fromAscii( rcsc::FormationNGNet::name().c_str() ) );
@@ -1337,7 +1407,7 @@ MainWindow::saveTrainingDataAs()
 void
 MainWindow::toggleBallDrag( bool on )
 {
-    std::cerr << "toggle ball drag " << on << std::endl;
+    //std::cerr << "toggle ball drag " << on << std::endl;
 
     if ( M_editor_data )
     {
@@ -1352,7 +1422,7 @@ MainWindow::toggleBallDrag( bool on )
 void
 MainWindow::togglePlayerAutoMove( bool on )
 {
-    std::cerr << "toggle player auto move " << on << std::endl;
+    //std::cerr << "toggle player auto move " << on << std::endl;
 
     if ( M_editor_data )
     {
@@ -1363,6 +1433,36 @@ MainWindow::togglePlayerAutoMove( bool on )
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+MainWindow::toggleDataAutoSelect( bool on )
+{
+    //std::cerr << "toggle player auto move " << on << std::endl;
+
+    if ( M_editor_data )
+    {
+        M_editor_data->setDataAutoSelect( on );
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+MainWindow::toggleSymmetricMode( bool on )
+{
+    //std::cerr << "toggle symmetric mode " << std::endl;
+
+    if ( M_editor_data )
+    {
+        M_editor_data->setSymmetricMode( on );
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 MainWindow::showEditDialog( bool on )
@@ -1408,6 +1508,39 @@ MainWindow::recordData()
     }
 
     setTrainingDataSize();
+    M_index_spin_box->setValue( M_editor_data->trainingData().size() );
+
+    emit viewUpdated();
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+MainWindow::insertData()
+{
+    if ( ! M_editor_data )
+    {
+        return;
+    }
+
+    int cur = M_index_spin_box->value();
+
+    std::string msg = M_editor_data->insertTrainingData( cur );
+
+    if ( ! msg.empty() )
+    {
+        QMessageBox::warning( this,
+                              tr( "Warning" ),
+                              QString::fromAscii( msg.c_str() ),
+                              QMessageBox::Ok,
+                              QMessageBox::NoButton );
+        return;
+    }
+
+    setTrainingDataSize();
+    M_index_spin_box->setValue( cur + 1 );
 
     emit viewUpdated();
 }
@@ -1444,6 +1577,7 @@ MainWindow::deleteData()
 
     if ( M_editor_data->deleteTrainingData( M_index_spin_box->value() ) )
     {
+        M_index_spin_box->setValue( 0 );
         setTrainingDataSize();
         emit viewUpdated();
     }
@@ -1459,6 +1593,7 @@ MainWindow::reverseY()
     if ( M_editor_data )
     {
         M_editor_data->reverseY();
+        updateDataIndex();
         emit viewUpdated();
     }
 }
@@ -1487,7 +1622,7 @@ MainWindow::setTrainingDataSize()
     if ( M_editor_data
          && ! M_editor_data->trainingData().empty() )
     {
-        M_index_spin_box->setRange( 1, M_editor_data->trainingData().size() );
+        M_index_spin_box->setRange( 0, M_editor_data->trainingData().size() );
     }
 }
 
@@ -1512,3 +1647,23 @@ MainWindow::changeDataIndex( int idx )
         emit viewUpdated();
     }
 }
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+MainWindow::updateDataIndex()
+{
+    if ( M_editor_data
+         && M_editor_data->isPlayerAutoMove() )
+    {
+        int idx = M_editor_data->currentIndex();
+        if ( M_index_spin_box->value() != idx
+             && 0 < idx
+             && idx <= M_index_spin_box->maxValue() )
+        {
+            M_index_spin_box->setValue( idx );
+        }
+    }
+}
