@@ -80,10 +80,13 @@ private:
     // mode actions
     QAction * M_toggle_ball_drag_act;
     QAction * M_toggle_player_auto_move_act;
+    QAction * M_toggle_data_auto_select_act;
+    QAction * M_toggle_symmetric_mode_act;
 
     QAction * M_show_edit_dialog_act;
 
     // edit actions
+    QAction * M_insert_data_act;
     QAction * M_replace_data_act;
     QAction * M_delete_data_act;
     QAction * M_reverse_y_act;
@@ -95,6 +98,8 @@ private:
     QAction * M_zoom_out_act;
     QAction * M_fit_act;
     QAction * M_toggle_enlarge_act;
+    QAction * M_toggle_show_index_act;
+    QAction * M_toggle_show_circumcircle_act;
 
     // help actions
     QAction * M_about_act;
@@ -175,10 +180,13 @@ public slots:
 
     void toggleBallDrag( bool on );
     void togglePlayerAutoMove( bool on );
+    void toggleDataAutoSelect( bool on );
+    void toggleSymmetricMode( bool on );
 
     void showEditDialog( bool on );
 
     void recordData();
+    void insertData();
     void replaceData();
     void deleteData();
     void reverseY();
@@ -186,6 +194,7 @@ public slots:
 
     void setTrainingDataSize();
     void changeDataIndex( int idx );
+    void updateDataIndex();
 
 signals:
     void viewUpdated();
