@@ -47,6 +47,7 @@
 
 #include <iostream>
 #include <cmath>
+#include <cstdio>
 
 
 const int AppConfig::MIN_SCORE_BOARD_HEIGHT = 20;
@@ -71,8 +72,70 @@ AppConfig::instance()
 
 */
 AppConfig::AppConfig()
+    // monitor client options
+    : M_connect( false )
+    , M_host( "localhost" )
+    , M_port( 6000 )
+    , M_client_version( 3 )
+    , M_wait_seconds( 5 )
+    , M_auto_quit_mode( false )
+    , M_kill_server( false )
+    , M_server_pid( 0 )
+    , M_server_path( "rcssserver" )
+    , M_time_shift_replay( true )
+      // logplayer options
+    , M_game_log_file_path( "" )
+    , M_game_log_dir( "" )
+    , M_auto_loop_mode( false )
+    , M_timer_interval( DEFAULT_TIMER_INTERVAL )
+      // debug server options
+    , M_debug_server_mode( false )
+    , M_debug_server_port( 6000 + 32 )
+    , M_debug_log_dir( "" )
+      // window options
+    , M_pos_x( -1 )
+    , M_pos_y( -1 )
+    , M_width( -1 )
+    , M_height( -1 )
+    , M_maximize( false )
+    , M_full_screen( false )
+    , M_canvas_width( -1 )
+    , M_canvas_height( -1 )
+    , M_tool_bar_area( "top" )
+    , M_hide_menu_bar( false )
+    , M_hide_tool_bar( false )
+    , M_hide_status_bar( false )
+      // view options
+    , M_anonymous_mode( false )
+    , M_draw_type( "default" )
+    , M_field_grass_type( "mono" )
+    , M_keepaway( false )
+
+    , M_show_score_board( true )
+    , M_show_team_logo( true )
+
+    , M_anti_aliasing( true )
+    , M_gradient( false )
+
+    , M_reverse_side( false )
+    , M_player_reverse_draw( false )
+
+    , M_show_player_number( true )
+    , M_show_player_type( false )
+    , M_show_view_cone( true )
+    , M_show_stamina( true )
+
+    , M_enlarged_ball_size( 0.35 )
+    , M_fixed_player_size( 0.0 )
+      // image save options
+    , M_auto_image_save( false )
+    , M_image_save_dir( "" )
+    , M_image_name_prefix( "image-" )
+    , M_image_save_format( "PNG" )
+      // other options
+    , M_monitor_client_mode( false )
 {
-    init();
+
 }
 
 /*-------------------------------------------------------------------*/
@@ -84,65 +147,6 @@ AppConfig::~AppConfig()
 
 }
 
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-void
-AppConfig::init()
-{
-
-    M_game_log_file_path = "";
-    M_game_log_dir = "";
-    M_debug_log_dir = "";
-
-    M_time_shift_replay = true;
-    M_auto_loop_mode = false;
-    M_replay_speed_ratio = 1.0;
-
-    M_connect = false;
-    M_host = "localhost";
-    M_port = 6000;
-    M_client_version = 2;
-    M_wait_seconds = 5;
-    M_auto_quit_mode = false;
-    M_kill_server = false;
-    M_server_pid = 0;
-    M_server_path = "rcssserver";
-    M_anonymous_mode = false;
-
-    M_maximize = false;
-    M_full_screen = false;
-
-    M_pos_x = -1;
-    M_pos_y = -1;
-    M_width = -1;
-    M_height = -1;
-
-    M_hide_menu_bar = false;
-    M_hide_tool_bar = false;
-    M_hide_status_bar = false;
-
-    M_reverse_side = false;
-    M_player_reverse_draw = false;
-
-    M_show_player_number = true;
-    M_show_player_type = false;
-    M_show_view_cone = true;
-    M_show_stamina = true;
-
-    M_field_grass_type = "mono";
-
-    M_enlarged_ball_size = 0.35;
-
-    M_keepaway = false;
-
-    M_debug_server_mode = false;
-    M_debug_server_port = 6000 + 32;
-
-    M_monitor_client_mode = false;
-}
-
 /*-------------------------------------------------------------------*/
 /*!
   analyze command line options
@@ -155,10 +159,15 @@ AppConfig::parseCmdLine( int argc,
     rcsc::ParamMap client_options( "Monitor Client Options" );
     rcsc::ParamMap logplayer_options( "Log Player Options" );
     rcsc::ParamMap debug_server_options( "Debug Server Options" );
+    rcsc::ParamMap window_options( "Window Options" );
     rcsc::ParamMap view_options( "View Preference Options" );
+    rcsc::ParamMap image_options( "Image Save Options" );
 
     bool help = false;
     bool version = false;
+    std::string geometry;
+    std::string canvas_size;
+
     system_options.add()
         ( "help", "h",
           rcsc::BoolSwitch( &help ),
@@ -169,6 +178,9 @@ AppConfig::parseCmdLine( int argc,
         ;
 
     client_options.add()
+        ( "connect", "c",
+          rcsc::BoolSwitch( &M_connect ),
+          "start as a soccer monitor." )
         ( "host", "",
           &M_host,
           "set host name to be connected." )
@@ -193,30 +205,24 @@ AppConfig::parseCmdLine( int argc,
         ( "server-path", "",
           &M_server_path,
           "set a rcssserver command line." )
-        ( "anonymous-mode", "",
-          rcsc::BoolSwitch( &M_anonymous_mode ),
-          "hide team names." )
-        ( "connect", "c",
-          rcsc::BoolSwitch( &M_connect ),
-          "start as a soccer monitor." )
         ( "time-shift-replay", "",
           &M_time_shift_replay,
           "enable time shift replay mode." )
         ;
 
     logplayer_options.add()
+        ( "game-log", "l",
+          &M_game_log_file_path,
+          "set the path to Game Log file(.rcg) to be loaded.")
         ( "game-log-dir", "",
           &M_game_log_dir,
           "set a default path where game log files exist." )
         ( "auto-loop-mode", "",
           rcsc::BoolSwitch( &M_auto_loop_mode ),
           "enable automatic replay loop." )
-        ( "replay-speed-ratio", "",
-          &M_replay_speed_ratio,
-          "set a logplayer's replay speed ratio." )
-        ( "game-log", "l",
-          &M_game_log_file_path,
-          "set the path to Game Log file(.rcg) to be loaded.")
+        ( "timer-interval", "",
+          &M_timer_interval,
+          "set the logplayer timer interval." )
         ;
 
     debug_server_options.add()
@@ -231,14 +237,74 @@ AppConfig::parseCmdLine( int argc,
           "set a default path where debug log files exist." )
         ;
 
+    window_options.add()
+        ( "geometry", "",
+          &geometry,
+          "specifies the window geometry ([WxH][+X+Y]). e.g. --geometry=1024x768+1+1" )
+//         ( "pos-x", "",
+//           &M_pos_x,
+//           "set left x position of the main window." )
+//         ( "pos-y", "",
+//           &M_pos_y,
+//           "set top y position of the main window." )
+//         ( "width", "",
+//           &M_width,
+//           "set width of the main window." )
+//         ( "height", "",
+//           &M_height,
+//           "set height of the main window." )
+        ( "maximize", "",
+          rcsc::BoolSwitch( &M_maximize ),
+          "start with a maximized frame." )
+        ( "full-screen", "",
+          rcsc::BoolSwitch( &M_full_screen ),
+          "start with a full screen frame." )
+        ( "canvas-size", "",
+          &canvas_size,
+          "specifies the canvas size(WxH). e.g. --canvas-size=1024x768" )
+        ( "tool-bar-area", "",
+          &M_tool_bar_area,
+          "specify the initial tool bar position {top,bottom,left,right}." )
+        ( "hide-menu-bar", "",
+          rcsc::BoolSwitch( &M_hide_menu_bar ),
+          "start without a menu bar (available only by Qt3 version)." )
+        ( "hide-tool-bar", "",
+          rcsc::BoolSwitch( &M_hide_tool_bar ),
+          "start without a tool bar." )
+        ( "hide-status-bar", "",
+          rcsc::BoolSwitch( &M_hide_status_bar ),
+          "start without a status bar." )
+        ;
+
     view_options.add()
+        ( "anonymous-mode", "",
+          rcsc::BoolSwitch( &M_anonymous_mode ),
+          "hide team names." )
+        ( "draw-type", "",
+          &M_draw_type,
+          "set a draw style type {default,rcssmonitor}." )
         ( "field-grass-type", "",
           &M_field_grass_type,
           "set a field grass type {mono,lines,checker}." )
-        ("reverse-side", "",
+        ( "keepaway", "",
+          rcsc::BoolSwitch( &M_keepaway ),
+          "start as a keepaway mode monitor." )
+        ( "show-score-board", "",
+          &M_show_score_board,
+          "show score board." )
+        ( "show-team-logo", "",
+          &M_show_team_logo,
+          "show team logo." )
+        ( "anti-aliasing", "",
+          &M_anti_aliasing,
+          "set an anti-aliasing draw mode (only for Qt4 version)." )
+        ( "gradient", "",
+          &M_gradient,
+          "set a gradient draw mode (only for Qt4 version)." )
+        ( "reverse-side", "",
           rcsc::BoolSwitch( &M_reverse_side ),
           "reverse left<->right." )
-        ("player-reverse-draw", "",
+        ( "player-reverse-draw", "",
           rcsc::BoolSwitch( &M_player_reverse_draw ),
           "reverse the player draw order." )
         ( "show-player-number", "",
@@ -256,38 +322,25 @@ AppConfig::parseCmdLine( int argc,
         ( "enlarged-ball-size", "",
           &M_enlarged_ball_size,
           "set a ball radius in enlarge mode." )
-        ( "keepaway", "",
-          rcsc::BoolSwitch( &M_keepaway ),
-          "start as a keepaway mode monitor" )
-        ( "maximize", "",
-          rcsc::BoolSwitch( &M_maximize ),
-          "start with a maximized frame." )
-        ( "full-screen", "",
-          rcsc::BoolSwitch( &M_full_screen ),
-          "start with a full screen frame." )
-        ( "hide-menu-bar", "",
-          rcsc::BoolSwitch( &M_hide_menu_bar ),
-          "start without a menu bar (available only by Qt3 version)." )
-        ( "hide-tool-bar", "",
-          rcsc::BoolSwitch( &M_hide_tool_bar ),
-          "start without a tool bar." )
-        ( "hide-status-bar", "",
-          rcsc::BoolSwitch( &M_hide_status_bar ),
-          "start without a status bar." )
-        ( "pos-x", "",
-          &M_pos_x,
-          "set left x position of a main frame." )
-        ( "pos-y", "",
-          &M_pos_y,
-          "set top y position of a main frame." )
-        ( "width", "",
-          &M_width,
-          "set width of a main frame." )
-        ( "height", "",
-          &M_height,
-          "set height of a main frame." )
+        ( "fixed-player-size", "",
+          &M_fixed_player_size,
+          "set a fixed player radius in enlarge mode." )
         ;
 
+    image_options.add()
+        ( "auto-image-save", "",
+          rcsc::BoolSwitch( &M_auto_image_save ),
+          "automatically saved image and quit application." )
+        ( "image-save-dir", "",
+          &M_image_save_dir,
+          "set a default path where image files are saved." )
+        ( "image-name-prefix", "",
+          &M_image_name_prefix,
+          "set a default prefix of the image file name." )
+        ( "image-save-format", "",
+          &M_image_save_format,
+          "set a default image format type." )
+        ;
 
     rcsc::CmdLineParser parser( argc, argv );
 
@@ -295,7 +348,9 @@ AppConfig::parseCmdLine( int argc,
     parser.parse( client_options );
     parser.parse( logplayer_options );
     parser.parse( debug_server_options );
+    parser.parse( window_options );
     parser.parse( view_options );
+    parser.parse( image_options );
 
 
     if ( help
@@ -308,7 +363,9 @@ AppConfig::parseCmdLine( int argc,
         client_options.printHelp( std::cout );
         logplayer_options.printHelp( std::cout );
         debug_server_options.printHelp( std::cout );
+        window_options.printHelp( std::cout );
         view_options.printHelp( std::cout );
+        image_options.printHelp( std::cout );
         return false;
     }
 
@@ -326,6 +383,92 @@ AppConfig::parseCmdLine( int argc,
         M_game_log_file_path = parser.positionalOptions().front();
     }
 
+    if ( M_timer_interval < 0 )
+    {
+        std::cerr << "Illegal timer interval " << M_timer_interval
+                  << ". set default value." << std::endl;
+        M_timer_interval = DEFAULT_TIMER_INTERVAL;
+    }
+
+    if ( M_timer_interval < 5 )
+    {
+        std::cerr << "Too small timer interval " << M_timer_interval
+                  << ".  replaced by 5." << std::endl;
+        M_timer_interval = 5;
+    }
+
+    if ( M_timer_interval > 5000 )
+    {
+        std::cerr << "Too huge timer interval " << M_timer_interval
+                  << ".  replaced by 5000." << std::endl;
+        M_timer_interval = 5000;
+    }
+
+    if ( ! geometry.empty() )
+    {
+        int w = -1, h = -1;
+        int x = -1, y = -1;
+
+        int num = std::sscanf( geometry.c_str(),
+                               " %d x %d %d %d " ,
+                               &w, &h, &x, &y );
+        //std::cerr << "geometry = " << geometry
+        //          << "  param_num=" << num
+        //          << " width=" << w << " height=" << h
+        //          << " x=" << x << " y=" << y
+        //          << std::endl;
+        if ( num == 4 || num == 2 )
+        {
+            if ( w <= 0 || h <= 0 )
+            {
+                std::cerr << "Illegal window size [" << geometry
+                          << "]" << std::endl;
+            }
+            else
+            {
+                M_width = w;
+                M_height = h;
+                M_pos_x = x;
+                M_pos_y = y;
+            }
+        }
+        else if ( std::sscanf( geometry.c_str(),
+                               " %d %d " ,
+                               &x, &y ) == 2 )
+        {
+            //std::cerr << "only pos = "
+            //          << " x=" << x
+            //          << " y=" << y
+            //          << std::endl;
+            M_pos_x = x;
+            M_pos_y = y;
+        }
+        else
+        {
+            std::cerr << "Illegal geometry format [" << geometry
+                      << "]" << std::endl;
+        }
+    }
+
+    if ( ! canvas_size.empty() )
+    {
+        int w = -1, h = -1;
+        if ( std::sscanf( canvas_size.c_str(),
+                          " %d x %d ",
+                          &w, &h ) == 2
+             && w > 1
+             && h > 1 )
+        {
+            M_canvas_width = w;
+            M_canvas_height = h;
+        }
+        else
+        {
+            std::cerr << "Illegal canvas size format [" << canvas_size
+                      << "]" << std::endl;
+        }
+    }
+
     return true;
 }
 
@@ -482,18 +625,3 @@ AppConfig::parseCmdLine( int argc,
     return true;
 }
 #endif
-
-/*-------------------------------------------------------------------*/
-/*!
-
-*/
-int
-AppConfig::defaultTimerInterval() const
-{
-    int interval
-        = static_cast< int >( rint( DEFAULT_TIMER_INTERVAL
-                                    / replaySpeedRatio() ) );
-    if ( interval < 5 ) interval = 5;
-    if ( 5000 < interval ) interval = 5000;
-    return interval;
-}
