@@ -48,14 +48,9 @@ public:
 
 private:
 
-    std::string M_game_log_file_path;
-    std::string M_game_log_dir; //!< default dir to search game log
-    std::string M_debug_log_dir; //!< default dir to search debug log
-
-    bool M_time_shift_replay;
-    bool M_auto_loop_mode;
-    double M_replay_speed_ratio; //!< logplayer's speed ratio. 1.0 means timer step is 100ms
-
+    //
+    // monitor client options
+    //
     bool M_connect;
     std::string M_host;
     int M_port;
@@ -65,37 +60,73 @@ private:
     bool M_kill_server;
     long M_server_pid;
     std::string M_server_path; //!< rcssserver command line path
-    bool M_anonymous_mode;
+    bool M_time_shift_replay;
 
+    //
+    // logplayer options
+    //
+    std::string M_game_log_file_path;
+    std::string M_game_log_dir; //!< default dir to search game log
+    bool M_auto_loop_mode;
+    int M_timer_interval; //!< logplayer's timer interval. default 100[ms]
+
+    //
+    // debug server options
+    //
+    bool M_debug_server_mode;
+    long M_debug_server_port;
+    std::string M_debug_log_dir; //!< default dir to search debug log
+
+    //
+    // window options
+    //
+    int M_pos_x;
+    int M_pos_y;
+    int M_width;
+    int M_height;
     bool M_maximize;
     bool M_full_screen;
 
-    long M_pos_x;
-    long M_pos_y;
-    long M_width;
-    long M_height;
+    int M_canvas_width;
+    int M_canvas_height;
 
+    std::string M_tool_bar_area;
     bool M_hide_menu_bar;
     bool M_hide_tool_bar;
     bool M_hide_status_bar;
 
-    bool M_reverse_side;
+    //
+    // view options
+    //
+    bool M_anonymous_mode;
+    std::string M_draw_type;
+    std::string M_field_grass_type;
+    bool M_keepaway;
 
+    bool M_show_score_board;
+    bool M_show_team_logo;
+
+    bool M_anti_aliasing;
+    bool M_gradient;
+
+    bool M_reverse_side;
     bool M_player_reverse_draw;
 
     bool M_show_player_number;
     bool M_show_player_type;
     bool M_show_view_cone;
     bool M_show_stamina;
-    std::string M_field_grass_type;
 
     double M_enlarged_ball_size;
+    double M_fixed_player_size;
 
-    bool M_keepaway;
-
-    bool M_debug_server_mode;
-    long M_debug_server_port;
-
+    //
+    // image save options
+    //
+    bool M_auto_image_save;
+    std::string M_image_save_dir;
+    std::string M_image_name_prefix;
+    std::string M_image_save_format;
 
     // not a command line option
 
@@ -110,8 +141,6 @@ private:
     //! noncopyable
     AppConfig & operator=( const AppConfig & );
 
-    void init();
-
 public:
     ~AppConfig();
 
@@ -152,14 +181,27 @@ public:
       }
 
     const
-    double & replaySpeedRatio() const
+    std::string & imageSaveDir() const
       {
-          return M_replay_speed_ratio;
+          return M_image_save_dir;
       }
 
+    const
+    std::string & imageNamePrefix() const
+      {
+          return M_image_name_prefix;
+      }
 
-    int defaultTimerInterval() const;
+    const
+    std::string & imageSaveFormat() const
+      {
+          return M_image_save_format;
+      }
 
+    int timerInterval() const
+      {
+          return M_timer_interval;
+      }
 
     bool connect() const
       {
@@ -255,6 +297,22 @@ public:
           return M_height;
       }
 
+    int canvasWidth() const
+      {
+          return M_canvas_width;
+      }
+
+    int canvasHeight() const
+      {
+          return M_canvas_height;
+      }
+
+    const
+    std::string & toolBarArea() const
+      {
+          return M_tool_bar_area;
+      }
+
     bool hideMenuBar() const
       {
           return M_hide_menu_bar;
@@ -270,6 +328,16 @@ public:
           return M_hide_status_bar;
       }
 
+    bool antiAliasing() const
+      {
+          return M_anti_aliasing;
+      }
+
+    bool gradient() const
+      {
+          return M_gradient;
+      }
+
     bool reverseSide() const
       {
           return M_reverse_side;
@@ -312,11 +380,27 @@ public:
           return M_enlarged_ball_size;
       }
 
+    const
+    double & fixedPlayerSize() const
+      {
+          return M_fixed_player_size;
+      }
+
     bool keepaway() const
       {
           return M_keepaway;
       }
 
+    bool showScoreBoard() const
+      {
+          return M_show_score_board;
+      }
+
+    bool showTeamLogo() const
+      {
+          return M_show_team_logo;
+      }
+
     bool debugServerMode() const
       {
           return M_debug_server_mode;
@@ -338,7 +422,16 @@ public:
           M_debug_log_dir = dir;
       }
 
+    const
+    std::string & drawType() const
+      {
+          return M_draw_type;
+      }
 
+    bool autoImageSave() const
+      {
+          return M_auto_image_save;
+      }
 
     bool monitorClientMode() const
       {
