@@ -373,26 +373,26 @@ DebugClientParser::parseBall( const char * tok,
     while ( &tok != '\0' && *tok == ' ' ) ++tok;
     while ( &tok != '\0' && *tok != ' ' ) ++tok; // skip 'b'
 
-    const float x = std::strtof( tok, &next );
-    if ( x == -HUGE_VALF || x == HUGE_VALF ) return 0;
+    const double x = std::strtod( tok, &next );
+    if ( x == -HUGE_VAL || x == HUGE_VAL ) return 0;
     tok = next;
-    const float y = std::strtof( tok, &next );
-    if ( y == -HUGE_VALF || y == HUGE_VALF ) return 0;
+    const double y = std::strtod( tok, &next );
+    if ( y == -HUGE_VAL || y == HUGE_VAL ) return 0;
     tok = next;
 
     while ( &tok != '\0' && *tok == ' ' ) ++tok;
 
-    float vx = HUGE_VALF;
-    float vy = HUGE_VALF;
+    double vx = HUGE_VAL;
+    double vy = HUGE_VAL;
     if ( std::isdigit( *tok )
          || *tok == '-'
          || *tok == '.' )
     {
-        vx = std::strtof( tok, &next );
-        if ( vx == -HUGE_VALF || vx == HUGE_VALF ) return 0;
+        vx = std::strtod( tok, &next );
+        if ( vx == -HUGE_VAL || vx == HUGE_VAL ) return 0;
         tok = next;
-        vy = std::strtof( tok, &next );
-        if ( vy == -HUGE_VALF || vy == HUGE_VALF ) return 0;
+        vy = std::strtod( tok, &next );
+        if ( vy == -HUGE_VAL || vy == HUGE_VAL ) return 0;
         tok = next;
 
         while ( &tok != '\0' && *tok == ' ' ) ++tok;
@@ -428,15 +428,20 @@ DebugClientParser::parseBall( const char * tok,
 #endif
     // create new instance
     boost::shared_ptr< DebugViewData::BallT >
-        ball( new DebugViewData::BallT( x, y ) );
-    if ( vx != HUGE_VALF )
+        ball( new DebugViewData::BallT( static_cast< float >( x ),
+                                        static_cast< float >( y ) ) );
+
+    if ( vx != HUGE_VAL )
     {
-        ball->setVel( vx, vy );
+        ball->setVel( static_cast< float >( vx ),
+                      static_cast< float >( vy ) );
     }
+
     if ( comment[0] != '\0' )
     {
         ball->comment_.assign( comment );
     }
+
     debug_view->setBall( ball );
 
     return tok - start;
@@ -471,23 +476,23 @@ DebugClientParser::parseSelf( const char * tok,
     const long unum = std::strtol( tok, &next, 10 );
     if ( unum == LONG_MIN || unum == LONG_MAX ) return 0;
     tok = next;
-    float x = std::strtof( tok, &next );
-    if ( x == -HUGE_VALF || x == HUGE_VALF ) return 0;
+    double x = std::strtod( tok, &next );
+    if ( x == -HUGE_VAL || x == HUGE_VAL ) return 0;
     tok = next;
-    float y = std::strtof( tok, &next );
-    if ( y == -HUGE_VALF || y == HUGE_VALF ) return 0;
+    double y = std::strtod( tok, &next );
+    if ( y == -HUGE_VAL || y == HUGE_VAL ) return 0;
     tok = next;
-    float vx = std::strtof( tok, &next );
-    if ( vx == -HUGE_VALF || vx == HUGE_VALF ) return 0;
+    double vx = std::strtod( tok, &next );
+    if ( vx == -HUGE_VAL || vx == HUGE_VAL ) return 0;
     tok = next;
-    float vy = std::strtof( tok, &next );
-    if ( vy == -HUGE_VALF || vy == HUGE_VALF ) return 0;
+    double vy = std::strtod( tok, &next );
+    if ( vy == -HUGE_VAL || vy == HUGE_VAL ) return 0;
     tok = next;
-    float body = std::strtof( tok, &next );
-    if ( body == -HUGE_VALF || body == HUGE_VALF ) return 0;
+    double body = std::strtod( tok, &next );
+    if ( body == -HUGE_VAL || body == HUGE_VAL ) return 0;
     tok = next;
-    float neck = std::strtof( tok, &next );
-    if ( neck == -HUGE_VALF || neck == HUGE_VALF ) return 0;
+    double neck = std::strtod( tok, &next );
+    if ( neck == -HUGE_VAL || neck == HUGE_VAL ) return 0;
     tok = next;
 
     while ( *tok != '\0' && *tok == ' ' ) ++tok;
@@ -532,9 +537,12 @@ DebugClientParser::parseSelf( const char * tok,
     boost::shared_ptr< DebugViewData::SelfT >
         self( new DebugViewData::SelfT( M_side,
                                         M_unum,
-                                        x, y,
-                                        vx, vy,
-                                        body, neck,
+                                        static_cast< float >( x ),
+                                        static_cast< float >( y ),
+                                        static_cast< float >( vx ),
+                                        static_cast< float >( vy ),
+                                        static_cast< float >( body ),
+                                        static_cast< float >( neck ),
                                         comment ) );
     debug_view->setSelf( self );
     return tok - start;
@@ -580,11 +588,11 @@ DebugClientParser::parsePlayer( const char * tok,
         if ( unum == LONG_MIN || unum == LONG_MAX ) return 0;
         tok = next;
     }
-    const float x = std::strtof( tok, &next );
-    if ( x == -HUGE_VALF || x == HUGE_VALF ) return 0;
+    const double x = std::strtod( tok, &next );
+    if ( x == -HUGE_VAL || x == HUGE_VAL ) return 0;
     tok = next;
-    const float y = std::strtof( tok, &next );
-    if ( y == -HUGE_VALF || y == HUGE_VALF ) return 0;
+    const double y = std::strtod( tok, &next );
+    if ( y == -HUGE_VAL || y == HUGE_VAL ) return 0;
     tok = next;
 
     while ( *tok != '\0' && *tok == ' ' ) ++tok;
@@ -628,7 +636,11 @@ DebugClientParser::parsePlayer( const char * tok,
     while ( *tok != '\0' && ( *tok == ' ' || *tok == ')' ) ) ++tok;
 
     boost::shared_ptr< DebugViewData::PlayerT >
-        player( new DebugViewData::PlayerT( unum, x, y, body, comment ) );
+        player( new DebugViewData::PlayerT( unum,
+                                            static_cast< float >( x ),
+                                            static_cast< float >( y ),
+                                            body,
+                                            comment ) );
 
     switch ( recog_type ) {
     case DebugViewData::TEAMMATE:
@@ -671,17 +683,17 @@ DebugClientParser::parseLine( const char * tok,
     while ( &tok != '\0' && *tok == ' ' ) ++tok;
     while ( &tok != '\0' && *tok != ' ' ) ++tok; // skip 'line'
 
-    const float x1 = std::strtof( tok, &next );
-    if ( x1 == -HUGE_VALF || x1 == HUGE_VALF ) return 0;
+    const double x1 = std::strtod( tok, &next );
+    if ( x1 == -HUGE_VAL || x1 == HUGE_VAL ) return 0;
     tok = next;
-    const float y1 = std::strtof( tok, &next );
-    if ( y1 == -HUGE_VALF || y1 == HUGE_VALF ) return 0;
+    const double y1 = std::strtod( tok, &next );
+    if ( y1 == -HUGE_VAL || y1 == HUGE_VAL ) return 0;
     tok = next;
-    const float x2 = std::strtof( tok, &next );
-    if ( x2 == -HUGE_VALF || x2 == HUGE_VALF ) return 0;
+    const double x2 = std::strtod( tok, &next );
+    if ( x2 == -HUGE_VAL || x2 == HUGE_VAL ) return 0;
     tok = next;
-    const float y2 = std::strtof( tok, &next );
-    if ( y2 == -HUGE_VALF || y2 == HUGE_VALF ) return 0;
+    const double y2 = std::strtod( tok, &next );
+    if ( y2 == -HUGE_VAL || y2 == HUGE_VAL ) return 0;
     tok = next;
 
     while ( *tok != '\0' && *tok != ')' ) ++tok;
@@ -695,7 +707,10 @@ DebugClientParser::parseLine( const char * tok,
               << " y2=" << y2
               << std::endl;
 #endif
-    debug_view->addLine( x1, y1, x2, y2 );
+    debug_view->addLine( static_cast< float >( x1 ),
+                         static_cast< float >( y1 ),
+                         static_cast< float >( x2 ),
+                         static_cast< float >( y2 ) );
 
     return tok - start;
 }
@@ -715,30 +730,35 @@ DebugClientParser::parseTriangle( const char * tok,
     while ( &tok != '\0' && *tok == ' ' ) ++tok;
     while ( &tok != '\0' && *tok != ' ' ) ++tok; // skip 'tri'
 
-    const float x1 = std::strtof( tok, &next );
-    if ( x1 == -HUGE_VALF || x1 == HUGE_VALF ) return 0;
+    const double x1 = std::strtod( tok, &next );
+    if ( x1 == -HUGE_VAL || x1 == HUGE_VAL ) return 0;
     tok = next;
-    const float y1 = std::strtof( tok, &next );
-    if ( y1 == -HUGE_VALF || y1 == HUGE_VALF ) return 0;
+    const double y1 = std::strtod( tok, &next );
+    if ( y1 == -HUGE_VAL || y1 == HUGE_VAL ) return 0;
     tok = next;
-    const float x2 = std::strtof( tok, &next );
-    if ( x2 == -HUGE_VALF || x2 == HUGE_VALF ) return 0;
+    const double x2 = std::strtod( tok, &next );
+    if ( x2 == -HUGE_VAL || x2 == HUGE_VAL ) return 0;
     tok = next;
-    const float y2 = std::strtof( tok, &next );
-    if ( y2 == -HUGE_VALF || y2 == HUGE_VALF ) return 0;
+    const double y2 = std::strtod( tok, &next );
+    if ( y2 == -HUGE_VAL || y2 == HUGE_VAL ) return 0;
     tok = next;
-    const float x3 = std::strtof( tok, &next );
-    if ( x3 == -HUGE_VALF || x3 == HUGE_VALF ) return 0;
+    const double x3 = std::strtod( tok, &next );
+    if ( x3 == -HUGE_VAL || x3 == HUGE_VAL ) return 0;
     tok = next;
-    const float y3 = std::strtof( tok, &next );
-    if ( y3 == -HUGE_VALF || y3 == HUGE_VALF ) return 0;
+    const double y3 = std::strtod( tok, &next );
+    if ( y3 == -HUGE_VAL || y3 == HUGE_VAL ) return 0;
     tok = next;
 
     while ( *tok != '\0' && *tok != ')' ) ++tok;
     // skip this token
     while ( *tok != '\0' && ( *tok == ' ' || *tok == ')' ) ) ++tok;
 
-    debug_view->addTriangle( x1, y1, x2, y2, x3, y3 );
+    debug_view->addTriangle( static_cast< float >( x1 ),
+                             static_cast< float >( y1 ),
+                             static_cast< float >( x2 ),
+                             static_cast< float >( y2 ),
+                             static_cast< float >( x3 ),
+                             static_cast< float >( y3 ) );
 
     return tok - start;
 }
@@ -758,24 +778,27 @@ DebugClientParser::parseRectangle( const char * tok,
     while ( &tok != '\0' && *tok == ' ' ) ++tok;
     while ( &tok != '\0' && *tok != ' ' ) ++tok; // skip 'rect'
 
-    const float x1 = std::strtof( tok, &next );
-    if ( x1 == -HUGE_VALF || x1 == HUGE_VALF ) return 0;
+    const double x1 = std::strtod( tok, &next );
+    if ( x1 == -HUGE_VAL || x1 == HUGE_VAL ) return 0;
     tok = next;
-    const float y1 = std::strtof( tok, &next );
-    if ( y1 == -HUGE_VALF || y1 == HUGE_VALF ) return 0;
+    const double y1 = std::strtod( tok, &next );
+    if ( y1 == -HUGE_VAL || y1 == HUGE_VAL ) return 0;
     tok = next;
-    const float x2 = std::strtof( tok, &next );
-    if ( x2 == -HUGE_VALF || x2 == HUGE_VALF ) return 0;
+    const double x2 = std::strtod( tok, &next );
+    if ( x2 == -HUGE_VAL || x2 == HUGE_VAL ) return 0;
     tok = next;
-    const float y2 = std::strtof( tok, &next );
-    if ( y2 == -HUGE_VALF || y2 == HUGE_VALF ) return 0;
+    const double y2 = std::strtod( tok, &next );
+    if ( y2 == -HUGE_VAL || y2 == HUGE_VAL ) return 0;
     tok = next;
 
     while ( *tok != '\0' && *tok != ')' ) ++tok;
     // skip this token
     while ( *tok != '\0' && ( *tok == ' ' || *tok == ')' ) ) ++tok;
 
-    debug_view->addRectangle( x1, y1, x2, y2 );
+    debug_view->addRectangle( static_cast< float >( x1 ),
+                              static_cast< float >( y1 ),
+                              static_cast< float >( x2 ),
+                              static_cast< float >( y2 ) );
 
     return tok - start;
 }
@@ -796,21 +819,23 @@ DebugClientParser::parseCircle( const char * tok,
     while ( &tok != '\0' && *tok == ' ' ) ++tok;
     while ( &tok != '\0' && *tok != ' ' ) ++tok; // skip 'rect'
 
-    const float x = std::strtof( tok, &next );
-    if ( x == -HUGE_VALF || x == HUGE_VALF ) return 0;
+    const double x = std::strtod( tok, &next );
+    if ( x == -HUGE_VAL || x == HUGE_VAL ) return 0;
     tok = next;
-    const float y = std::strtof( tok, &next );
-    if ( y == -HUGE_VALF || y == HUGE_VALF ) return 0;
+    const double y = std::strtod( tok, &next );
+    if ( y == -HUGE_VAL || y == HUGE_VAL ) return 0;
     tok = next;
-    const float r = std::fabs( std::strtof( tok, &next ) );
-    if ( r == -HUGE_VALF || r == HUGE_VALF ) return 0;
+    const double r = std::fabs( std::strtod( tok, &next ) );
+    if ( r == -HUGE_VAL || r == HUGE_VAL ) return 0;
     tok = next;
 
     while ( *tok != '\0' && *tok != ')' ) ++tok;
     // skip this token
     while ( *tok != '\0' && ( *tok == ' ' || *tok == ')' ) ) ++tok;
 
-    debug_view->addCircle( x, y, r );
+    debug_view->addCircle( static_cast< float >( x ),
+                           static_cast< float >( y ),
+                           static_cast< float >( r ) );
 
     return tok - start;
 }
