@@ -90,7 +90,7 @@ MainData::clear()
 
 */
 bool
-MainData::loadRCG( const std::string & file_path )
+MainData::openRCG( const std::string & file_path )
 {
 #ifdef HAVE_LIBRCSC_GZ
     rcsc::gzifstream fin( file_path.c_str() );
@@ -107,14 +107,14 @@ MainData::loadRCG( const std::string & file_path )
     // clear all data
     clear();
 
-    // create rcg loader
-    rcsc::rcg::Loader loader( M_view_holder );
+    // create rcg reader
+    rcsc::rcg::Reader reader( M_view_holder );
     // create rcg parser
     rcsc::rcg::ParserPtr parser = rcsc::rcg::make_parser( fin );
 
     // do parse & handle data
     if ( ! parser
-         || ! parser->parse( fin, loader ) )
+         || ! parser->parse( fin, reader ) )
     {
         std::cerr << "failed to parse [" << file_path << "]." << std::endl;
         fin.close();
@@ -200,7 +200,8 @@ MainData::update( const int width,
     {
         if ( viewConfig().focusType() == ViewConfig::FOCUS_BALL )
         {
-            M_view_config.updateFocusPoint( view->ball().x(), view->ball().y() );
+            M_view_config.updateFocusPoint( view->ball().x() * viewConfig().reverseValue(),
+                                            view->ball().y() * viewConfig().reverseValue() );
         }
         else if ( viewConfig().focusType() == ViewConfig::FOCUS_PLAYER
                   && viewConfig().selectedNumber() != 0 )
@@ -215,7 +216,8 @@ MainData::update( const int width,
             const Player & p = view->players()[id];
             if ( p.isAlive() )
             {
-                M_view_config.updateFocusPoint( p.x(), p.y() );
+                M_view_config.updateFocusPoint( p.x() * viewConfig().reverseValue(),
+                                                p.y() * viewConfig().reverseValue() );
             }
         }
         else
