@@ -32,18 +32,19 @@
 #ifndef SOCCERWINDOW2_MAIN_DATA_H
 #define SOCCERWINDOW2_MAIN_DATA_H
 
+#include "debug_log_holder.h"
+#include "trainer_data.h"
 #include "view_config.h"
 #include "view_holder.h"
-#include "debug_log_holder.h"
 
-
-//! abstraction data class
 class MainData {
 private:
 
     //! field canvas configuration
     ViewConfig M_view_config;
 
+    TrainerData M_trainer_data;
+
     //! view data holder
     ViewHolder M_view_holder;
 
@@ -64,7 +65,7 @@ public:
 
     void clear();
 
-    bool loadRCG( const std::string & file_path );
+    bool openRCG( const std::string & file_path );
 
     bool saveRCG( const std::string & file_path );
 
@@ -80,6 +81,18 @@ public:
           return M_view_config;
       }
 
+    TrainerData & getTrainerData()
+      {
+          return M_trainer_data;
+      }
+
+    const
+    TrainerData & trainerData() const
+      {
+          return M_trainer_data;
+      }
+
+
     ViewHolder & getViewHolder()
       {
           return M_view_holder;
@@ -120,8 +133,6 @@ private:
 
     void selectBallNearestPlayer( MonitorViewConstPtr view );
 
-    void startDebugServer();
-
 public:
 
     bool setViewDataIndexFirst();
