@@ -2,7 +2,7 @@
 
 /*!
   \file team.h
-  \brief team data class Header File.
+  \brief team data wrapper class Header File.
 */
 
 /*
@@ -35,45 +35,64 @@
 #include <rcsc/rcg/types.h>
 #include <string>
 
-//! team data class.
+/*
+   \class Team
+   \brief team info wrapper class.
+ */
 class Team {
 private:
-    std::string M_team_name;
-    int M_score;
+    rcsc::rcg::TeamT M_data;
 public:
-    //! default constructor
+
     Team()
-        : M_team_name( "" )
-        , M_score( 0 )
       { }
 
-    //! construct from log data
+    explicit
     Team( const rcsc::rcg::team_t & team );
 
-    //! assign from log data
+    explicit
+    Team( const rcsc::rcg::TeamT & team );
+
     void assign( const rcsc::rcg::team_t & team );
 
-    //! assign directly
-    void assign( const short score )
-      {
-          M_score = static_cast< int >( score );
-      }
+    void assign( const rcsc::rcg::TeamT & team );
 
-    //! convert data to the log format
     void convertTo( rcsc::rcg::team_t & team ) const;
 
-    //! get team name const reference
+    // accessor
+
+    const
+    rcsc::rcg::TeamT & data() const
+      {
+          return M_data;
+      }
+
     const
     std::string & name() const
       {
-          return M_team_name;
+          return M_data.name_;
       }
 
-    //! get score
     int score() const
       {
-          return M_score;
+          return M_data.score_;
       }
+
+    int penScore() const
+      {
+          return M_data.pen_score_;
+      }
+
+    int penMiss() const
+      {
+          return M_data.pen_miss_;
+      }
+
+    int penTrial() const
+      {
+          return M_data.pen_score_ + M_data.pen_miss_;
+      }
+
 };
 
 #endif
