@@ -51,11 +51,25 @@ const double ViewConfig::ZOOM_RATIO = 1.5;
 ViewConfig::ViewConfig()
     : M_canvas_width( 640 )
     , M_canvas_height( 480 )
+    , M_anti_aliasing( true )
+    , M_gradient( false )
+    , M_cursor_hide( true )
     , M_reverse_side( false )
     , M_grass_type( GRASS_NORMAL )
+    , M_draw_type( DRAW_DEFAULT )
+    , M_show_grid_coord( true )
 {
     const AppConfig & conf = AppConfig::instance();
 
+    M_anti_aliasing = conf.antiAliasing();
+    M_gradient = conf.gradient();
+
+    M_ball_size = conf.enlargedBallSize();
+    if ( M_ball_size <= 0.001 ) M_ball_size = 0.001;
+
+    M_player_size = conf.fixedPlayerSize();
+    if ( M_player_size < 0.0 ) M_player_size = 0.0;
+
     if ( conf.fieldGrassType() == "mono" )
     {
         M_grass_type = GRASS_NORMAL;
@@ -70,9 +84,24 @@ ViewConfig::ViewConfig()
     }
     else
     {
-        std::cerr << "Invalid grass type name ["
-                  << conf.fieldGrassType()
-                  << "]"
+        std::cerr << "Unsupported grass type name ["
+                  << conf.fieldGrassType() << "]"
+                  << std::endl;
+    }
+
+    if ( conf.drawType() == "default"
+         || conf.drawType() == "soccerwindow2" )
+    {
+        M_draw_type = DRAW_DEFAULT;
+    }
+    else if ( conf.drawType() == "rcssmonitor" )
+    {
+        M_draw_type = DRAW_RCSSMONITOR;
+    }
+    else
+    {
+        std::cerr << "Unsupported draw type name ["
+                  << conf.drawType() << "]"
                   << std::endl;
     }
 
@@ -93,22 +122,26 @@ ViewConfig::reset()
 
     M_field_center.x = 0;
     M_field_center.y = 0;
+
+    M_grid_step = 0;
+
+    //    M_score_board_auto_fit = true;
     M_score_board_font_size = 11;
     M_reverse_side = AppConfig::instance().reverseSide();
     M_player_reverse_draw = AppConfig::instance().playerReverseDraw();
     M_zoomed = false;
     M_enlarge = true;
-    M_show_score_board = true;
+
+    M_anonymous_mode = AppConfig::instance().anonymousMode();
+    M_show_score_board = AppConfig::instance().showScoreBoard();
+    M_show_team_logo = AppConfig::instance().showTeamLogo();
     M_show_ball = true;
     M_show_players = true;
-    //M_show_player_number = true;
     M_show_player_number = AppConfig::instance().showPlayerNumber();
-    //M_show_stamina = true;
     M_show_stamina = AppConfig::instance().showStamina();
-    //M_show_hetero_number = false;
     M_show_hetero_number = AppConfig::instance().showPlayerType();
-    //M_show_view_cone = true;
     M_show_view_cone = AppConfig::instance().showViewCone();
+    M_show_body_shadow = true;
     M_show_control_area = false;
     M_show_flags = false;
     M_show_offside_line = false;
@@ -142,7 +175,7 @@ ViewConfig::reset()
     M_show_debug_view_target = true;
     M_show_debug_view_message = true;
 
-    M_show_debug_log_view = true;
+    M_show_debug_log_objects = true;
 
     int temp_width = M_canvas_width;
     M_canvas_width += 1;
@@ -158,15 +191,18 @@ ViewConfig::updateFieldSize( const int canvas_width,
                              const int canvas_height )
 {
     static bool s_score_board = true;
+    static DrawType s_draw_type = DRAW_DEFAULT;
 
     if ( M_canvas_width != canvas_width
          || M_canvas_height != canvas_height
-         || isShownScoreBoard() != s_score_board )
+         || isShownScoreBoard() != s_score_board
+         || drawType() != s_draw_type )
     {
         M_canvas_width = canvas_width;
         M_canvas_height = canvas_height;
 
         s_score_board = isShownScoreBoard();
+        s_draw_type = drawType();
         // adjust score board size
         updateScoreBoardSize( canvas_width, canvas_height );
 
@@ -194,6 +230,8 @@ ViewConfig::updateFieldSize( const int canvas_width,
             {
                 M_field_scale = MIN_FIELD_SCALE;
             }
+
+            M_field_scale = rint( M_field_scale * 100.0 ) / 100.0;
         }
     }
 
@@ -226,7 +264,11 @@ void
 ViewConfig::updateScoreBoardSize( const int canvas_width,
                                   const int canvas_height )
 {
-    if ( isShownScoreBoard() )
+    if ( drawType() == DRAW_RCSSMONITOR )
+    {
+        M_score_board_height = 0;
+    }
+    else if ( isShownScoreBoard() )
     {
         M_score_board_height = rcsc::bound( AppConfig::MIN_SCORE_BOARD_HEIGHT,
                                             canvas_height / 16,
@@ -329,19 +371,19 @@ ViewConfig::setFocusPoint( const int screen_x,
     M_focus_point.y = fieldY( screen_y );
 }
 
-/*-------------------------------------------------------------------*/
-/*!
+// /*-------------------------------------------------------------------*/
+// /*!
 
-*/
-void
-ViewConfig::setFocusPointReal( const double & field_x,
-                               const double & field_y )
-{
-    M_focus_type = ViewConfig::FOCUS_POINT;
+// */
+// void
+// ViewConfig::setFocusPointReal( const double & field_x,
+//                                const double & field_y )
+// {
+//     M_focus_type = ViewConfig::FOCUS_POINT;
 
-    M_focus_point.x = field_x;
-    M_focus_point.y = field_y;
-}
+//     M_focus_point.x = field_x;
+//     M_focus_point.y = field_y;
+// }
 
 /*-------------------------------------------------------------------*/
 /*!
