@@ -29,19 +29,16 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef SOCCERWINDOW2_QT_VIEW_CONFIG_H
-#define SOCCERWINDOW2_QT_VIEW_CONFIG_H
+#ifndef SOCCERWINDOW2_MODEL_VIEW_CONFIG_H
+#define SOCCERWINDOW2_MODEL_VIEW_CONFIG_H
+
+#include "point.h"
 
 #include <rcsc/geom/vector_2d.h>
 #include <rcsc/types.h>
 
 #include <cmath>
 
-struct Point {
-    int x;
-    int y;
-};
-
 //! drawing parameter holder
 class ViewConfig {
 public:
@@ -51,6 +48,11 @@ public:
         GRASS_NORMAL,
     };
 
+    enum DrawType {
+        DRAW_DEFAULT,
+        DRAW_RCSSMONITOR,
+    };
+
     enum PlayerSelectType {
         SELECT_FIX,
         SELECT_AUTO_LEFT,
@@ -80,37 +82,52 @@ private:
     int M_canvas_width; //!< pixel of draw area width
     int M_canvas_height; //!< pixel of draw area height
 
+    bool M_anti_aliasing;
+    bool M_gradient; //!< use gradient mode
+
+    bool M_cursor_hide; //!< automatic cursor hide or not
+
     Point M_field_center; //!< the screen point of field center
     double M_field_scale; //!< field scale rate
 
     bool M_reverse_side; //!< reverse left/right
     bool M_player_reverse_draw; //!< reverse the order of player draw
 
+    //    bool M_score_board_auto_fit;
     int M_score_board_font_size;
     int M_score_board_height; //!< screen height of score board
 
     // zoom
     bool M_zoomed; //!< true if canvas scale is changed.
+
+    // object size
     bool M_enlarge; //!< true if enlarge mode
+    double M_ball_size; //!< enlarged ball size
+    double M_player_size; //!< enlarged and fixed player size
 
     // players detail
     bool M_show_player_number; //!< true if uniform number is drawn
     bool M_show_hetero_number; //!< true if hetero ID is drawon
     bool M_show_stamina; //!< true if stamina value is drawn
     bool M_show_view_cone; //!< true if player's view cone is drawn
+    bool M_show_body_shadow;
     bool M_show_control_area; //!< true if control area is drawn
 
     // show/hide
+    bool M_anonymous_mode;
     bool M_show_score_board; //!< true if score board is drawon
+    bool M_show_team_logo;
     bool M_show_ball; //!< true if ball is drawin
     bool M_show_players; //!< true if player is drawin
     bool M_show_flags; //!< true if marker flags are drawn
     bool M_show_offside_line; //!< true if offside lines are drawn
 
-    // field grass
+    // field
     GrassType M_grass_type; //!< field grass type
-
+    DrawType M_draw_type;
     bool M_keepaway_mode;
+    bool M_show_grid_coord;
+    int M_grid_step;
 
     // computational geometry
     bool M_show_voronoi_diagram; //!< true if voronoi diagram is drawn
@@ -156,8 +173,8 @@ private:
     bool M_show_debug_view_target;
     bool M_show_debug_view_message;
 
-    // debug log view
-    bool M_show_debug_log_view;
+    // debug log objects
+    bool M_show_debug_log_objects;
 
 public:
     //! constructor
@@ -195,6 +212,42 @@ public:
           return M_field_center;
       }
 
+    void toggleAntiAliasing()
+      {
+          M_anti_aliasing = ! M_anti_aliasing;
+      }
+    bool antiAliasing() const
+      {
+          return M_anti_aliasing;
+      }
+
+    void toggleGradient()
+      {
+          M_gradient = ! M_gradient;
+      }
+    bool gradient() const
+      {
+          return M_gradient;
+      }
+
+    void toggleCursorHide()
+      {
+          M_cursor_hide = ! M_cursor_hide;
+      }
+    bool cursorHide() const
+      {
+          return M_cursor_hide;
+      }
+
+//     bool scoreBoardAutoFit() const
+//       {
+//           return M_score_board_auto_fit;
+//       }
+//     void toggleScoreBoardAutoFit()
+//       {
+//           M_score_board_auto_fit = ! M_score_board_auto_fit;
+//       }
+
     int scoreBoardFontSize() const
       {
           return M_score_board_font_size;
@@ -247,6 +300,28 @@ public:
           M_enlarge = ! M_enlarge;
       }
 
+    const
+    double & ballSize() const
+      {
+          return M_ball_size;
+      }
+    void setBallSize( const double & size )
+      {
+          if ( size <= 0.001 ) return;
+          M_ball_size = size;
+      }
+
+    const
+    double & playerSize() const
+      {
+          return M_player_size;
+      }
+    void setPlayerSize( const double & size )
+      {
+          if ( size < 0.0 ) return;
+          M_player_size = size;
+      }
+
     void setFieldScale( const double & scale );
     const
     double & fieldScale() const
@@ -265,8 +340,6 @@ public:
 
     void setFocusPoint( const int screen_x,
                         const int screen_y );
-    void setFocusPointReal( const double & field_x,
-                            const double & field_y );
     void updateFocusPoint( const double & x,
                            const double & y )
       {
@@ -326,6 +399,15 @@ public:
           return M_show_view_cone;
       }
 
+    void toggleShowBodyShadow()
+      {
+          M_show_body_shadow = ! M_show_body_shadow;
+      }
+    bool isShownBodyShadow() const
+      {
+          return M_show_body_shadow;
+      }
+
     void toggleShowControlArea()
       {
           M_show_control_area = ! M_show_control_area;
@@ -337,6 +419,15 @@ public:
 
     // show/hide field objects
 
+    void toggleAnonymousMode()
+      {
+          M_anonymous_mode = ! M_anonymous_mode;
+      }
+    bool anonymousMode() const
+      {
+          return M_anonymous_mode;
+      }
+
     void toggleShowScoreBoard()
       {
           M_show_score_board = ! M_show_score_board;
@@ -346,6 +437,15 @@ public:
           return M_show_score_board;
       }
 
+    void toggleShowTeamLogo()
+      {
+          M_show_team_logo = ! M_show_team_logo;
+      }
+    bool isShownTeamLogo() const
+      {
+          return M_show_team_logo;
+      }
+
     void toggleShowBall()
       {
           M_show_ball = ! M_show_ball;
@@ -445,6 +545,15 @@ public:
           return M_grass_type;
       }
 
+    void setDrawType( DrawType type )
+      {
+          M_draw_type = type;
+      }
+    DrawType drawType() const
+      {
+          return M_draw_type;
+      }
+
     void toggleKeepawayMode()
       {
           M_keepaway_mode = ! M_keepaway_mode;
@@ -454,6 +563,24 @@ public:
           return M_keepaway_mode;
       }
 
+    void toggleShowGridCoord()
+      {
+          M_show_grid_coord = ! M_show_grid_coord;
+      }
+    bool isShownGridCoord() const
+      {
+          return M_show_grid_coord;
+      }
+
+    void setGridStep( const int step )
+      {
+          M_grid_step = step;
+      }
+    int gridStep() const
+      {
+          return M_grid_step;
+      }
+
     void setFocusType( const ViewConfig::FocusType type )
       {
           M_focus_type = type;
@@ -643,13 +770,13 @@ public:
     //////////////////////////////////////////////////////////
     // debug log view options
 
-    void toggleShowDebugLogView()
+    void toggleShowDebugLogObjects()
       {
-          M_show_debug_log_view = ! M_show_debug_log_view;
+          M_show_debug_log_objects = ! M_show_debug_log_objects;
       }
-    bool isShownDebugLogView() const
+    bool isShownDebugLogObjects() const
       {
-          return M_show_debug_log_view;
+          return M_show_debug_log_objects;
       }
 
 
@@ -670,21 +797,44 @@ public:
 
     /*!
       \brief convert 'x' to the screen coordinate X.
-      \param x real point
+      \param abs_x real point
+      \return screen point
+    */
+    int absScreenX( const double & abs_x ) const
+      {
+          return fieldCenter().x + scale( abs_x );
+      }
+    /*!
+      \brief convert 'x' to the screen coordinate X with reverse mode.
+      \param x real point (may be reversed)
       \return screen point
     */
     int screenX( const double & x ) const
       {
-          return fieldCenter().x + scale( x );
+          return ( M_reverse_side
+                   ? fieldCenter().x + scale( -x )
+                   : fieldCenter().x + scale( x ) );
       }
+
     /*!
       \brief convert 'y' to the screen coordinate X.
       \param y real point
       \return screen point
     */
+    int absScreenY( const double & abs_y ) const
+      {
+          return fieldCenter().y + scale( abs_y );
+      }
+    /*!
+      \brief convert 'y' to the screen coordinate X.
+      \param y real point (may be reversed)
+      \return screen point
+    */
     int screenY( const double & y ) const
       {
-          return fieldCenter().y + scale( y );
+          return ( M_reverse_side
+                   ? fieldCenter().y + scale( -y )
+                   : fieldCenter().y + scale( y ) );
       }
 
     /*!
