@@ -36,6 +36,9 @@
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
+#ifdef HAVE_WINDOWS_H
+#include <windows.h>
+#endif
 
 #include "view_holder.h"
 
@@ -46,7 +49,6 @@
 #include <rcsc/common/server_param.h>
 #include <rcsc/rcg/serializer.h>
 #include <rcsc/rcg/factory.h>
-#include <rcsc/types.h>
 
 #include <iterator>
 #include <sstream>
@@ -64,8 +66,10 @@ const std::string DEFAULT_DEBUG_VIEW_EXTENSION = ".log";
 */
 ViewHolder::ViewHolder()
     : M_last_playmode( rcsc::PM_Null )
+    , M_default_type( rcsc::ServerParam::i() )
 {
-    M_player_types.assign( 1, rcsc::PlayerType( rcsc::ServerParam::i() ) );
+    M_player_types.insert( std::pair< int, rcsc::PlayerType >
+                           ( 0, M_default_type ) );
 
     M_monitor_view_cont.reserve( 1024 * 8 );
 }
@@ -89,10 +93,8 @@ ViewHolder::clear()
 {
     M_last_playmode = rcsc::PM_Null;
 
-    std::memset( M_last_team_left.name, '\0', 16 );
-    M_last_team_left.score = 0;
-    std::memset( M_last_team_right.name, '\0', 16 );
-    M_last_team_right.score = 0;
+    M_last_team_left.clear();
+    M_last_team_right.clear();
 
     M_score_change_indexes.clear();
     M_penalty_scores_left.clear();
@@ -104,7 +106,13 @@ ViewHolder::clear()
     M_left_debug_view.clear();
     M_right_debug_view.clear();
 
-    M_player_types.assign( 1, rcsc::PlayerType( rcsc::ServerParam::i() ) );
+    M_default_type = rcsc::PlayerType( rcsc::ServerParam::i() );
+    M_player_types.clear();
+    M_player_types.insert( std::pair< int, rcsc::PlayerType >
+                           ( 0, M_default_type ) );
+
+    M_team_graphic_left.clear();
+    M_team_graphic_right.clear();
 }
 
 /*-------------------------------------------------------------------*/
@@ -119,33 +127,30 @@ ViewHolder::saveRCG( std::ostream & os ) const
 
     if ( ! serializer )
     {
+        std::cerr << "Failed to create the RCG serializer version " << logVersion()
+                  << std::endl;
         return os;
     }
 
     // header
     serializer->serializeHeader( os );
 
-    rcsc::rcg::dispinfo_t2 disp2;
+    // params
 
-    // server param
-    rcsc::ServerParam::i().convertTo( disp2.body.sparams );
-    serializer->serialize( os, disp2.body.sparams );
-
-    // player param
-    rcsc::PlayerParam::i().convertTo( disp2.body.pparams );
-    serializer->serialize( os, disp2.body.pparams );
-
-    // player types
-    for ( std::vector< rcsc::PlayerType >::const_iterator it
+    serializer->serializeParam( os, rcsc::ServerParam::i().toStr() );
+    serializer->serializeParam( os, rcsc::PlayerParam::i().toStr() );
+    for ( std::map< int, rcsc::PlayerType >::const_iterator it
               = playerTypeCont().begin();
           it != playerTypeCont().end();
           ++it )
     {
-        it->convertTo( disp2.body.ptinfo );
-        serializer->serialize( os, disp2.body.ptinfo );
+        serializer->serializeParam( os, it->second.toStr() );
     }
 
-    // view data, team data, playmode ...
+    // playmode, team, show
+
+    rcsc::rcg::DispInfoT disp;
+
     const std::vector< MonitorViewPtr >::const_iterator end
         = monitorViewCont().end();
     for ( std::vector< MonitorViewPtr >::const_iterator it
@@ -153,11 +158,44 @@ ViewHolder::saveRCG( std::ostream & os ) const
           it != end;
           ++it )
     {
-        (*it)->convertTo( disp2.body.show );
+        (*it)->convertTo( disp );
 
-        serializer->serialize( os, disp2.body.show );
+        serializer->serialize( os, disp );
     }
 
+//     rcsc::rcg::dispinfo_t2 disp2;
+
+//     // server param
+//     rcsc::ServerParam::i().convertTo( disp2.body.sparams );
+//     serializer->serialize( os, disp2.body.sparams );
+
+//     // player param
+//     rcsc::PlayerParam::i().convertTo( disp2.body.pparams );
+//     serializer->serialize( os, disp2.body.pparams );
+
+//     // player types
+//     for ( std::map< int, rcsc::PlayerType >::const_iterator it
+//               = playerTypeCont().begin();
+//           it != playerTypeCont().end();
+//           ++it )
+//     {
+//         it->second.convertTo( disp2.body.ptinfo );
+//         serializer->serialize( os, disp2.body.ptinfo );
+//     }
+
+//     // view data, team data, playmode ...
+//     const std::vector< MonitorViewPtr >::const_iterator end
+//         = monitorViewCont().end();
+//     for ( std::vector< MonitorViewPtr >::const_iterator it
+//               = monitorViewCont().begin();
+//           it != end;
+//           ++it )
+//     {
+//         (*it)->convertTo( disp2.body.show );
+
+//         serializer->serialize( os, disp2.body.show );
+//     }
+
     return os;
 }
 
@@ -274,7 +312,7 @@ ViewHolder::saveDebugView( const std::string & dir_path,
 
 */
 void
-ViewHolder::loadDebugView( const std::string & dir_path )
+ViewHolder::openDebugView( const std::string & dir_path )
 {
     if ( dir_path.empty() )
     {
@@ -298,9 +336,9 @@ ViewHolder::loadDebugView( const std::string & dir_path )
     {
         for ( int unum = 1; unum <= 11; ++unum )
         {
-            if ( loadDebugView( dir_path, left_team, unum ) )
+            if ( openDebugView( dir_path, left_team, unum ) )
             {
-                std::cerr << "loaded debug view data : "
+                std::cerr << "read debug view data : "
                           << left_team << "-" << unum
                           << std::endl;
             }
@@ -313,9 +351,9 @@ ViewHolder::loadDebugView( const std::string & dir_path )
     {
         for ( int unum = 1; unum <= 11; ++unum )
         {
-            if ( loadDebugView( dir_path, right_team, unum ) )
+            if ( openDebugView( dir_path, right_team, unum ) )
             {
-                std::cerr << "loaded debug view data : "
+                std::cerr << "read debug view data : "
                           << right_team << "-" << unum
                           << std::endl;
             }
@@ -328,7 +366,7 @@ ViewHolder::loadDebugView( const std::string & dir_path )
 
 */
 bool
-ViewHolder::loadDebugView( const std::string & dir_path,
+ViewHolder::openDebugView( const std::string & dir_path,
                            const std::string & team_name,
                            const int unum )
 {
@@ -434,6 +472,322 @@ ViewHolder::addShortShowInfo2( const rcsc::rcg::short_showinfo_t2 & show2 )
     return true;
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+  push back new data
+*/
+bool
+ViewHolder::addMsgInfo( const rcsc::rcg::Int16 board,
+                        const std::string & msg )
+{
+    //std::cerr << "ViewHolder::addMsgInfo" << std::endl;
+    //std::cout << "recv msginfo_t: message = [" << msg << ']'
+    //          << std::endl;
+
+    //(team_graphic_l (6 0 "8 8 2 1" "@    c #FF5D5D" "#   c #FF0000" "@#######" "########" "########" "########" "########" "########" "########" "########")
+
+    if ( ! std::strncmp( msg.c_str(),
+                         "(team_graphic_",
+                         std::strlen( "(team_graphic_" ) ) )
+    {
+        return analyzeTeamGraphic( msg );
+    }
+
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+  push back new data
+*/
+bool
+ViewHolder::addDrawInfo( const rcsc::rcg::drawinfo_t & msg )
+{
+    std::cout << "recv drawinfo_t: mode = " << msg.mode
+              << std::endl;
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+  push back new data
+*/
+bool
+ViewHolder::addPlayMode( const char pmode )
+{
+    rcsc::PlayMode playmode = static_cast< rcsc::PlayMode >( pmode );
+
+    if ( M_last_playmode != playmode )
+    {
+        if ( playmode == rcsc::PM_PenaltyScore_Left
+             || playmode == rcsc::PM_PenaltyMiss_Left )
+        {
+            long cycle = ( M_latest_view_data
+                           ? M_latest_view_data->cycle()
+                           : 0 );
+            M_penalty_scores_left.push_back( std::make_pair( cycle, playmode ) );
+        }
+        else if ( playmode == rcsc::PM_PenaltyScore_Right
+                  || playmode == rcsc::PM_PenaltyMiss_Right )
+        {
+            long cycle = ( M_latest_view_data
+                           ? M_latest_view_data->cycle()
+                           : 0 );
+            M_penalty_scores_right.push_back( std::make_pair( cycle, playmode ) );
+        }
+    }
+
+    M_last_playmode = playmode;
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+  push back new data
+*/
+bool
+ViewHolder::addTeamInfo( const rcsc::rcg::team_t & team_l,
+                         const rcsc::rcg::team_t & team_r )
+{
+    rcsc::rcg::UInt16 score_l = static_cast< rcsc::rcg::UInt16 >( ntohs( team_l.score ) );
+    rcsc::rcg::UInt16 score_r = static_cast< rcsc::rcg::UInt16 >( ntohs( team_r.score ) );
+
+    if ( M_last_team_left.score_ != score_l
+         || M_last_team_right.score_ != score_r )
+    {
+        M_score_change_indexes.push_back( M_monitor_view_cont.size() );
+    }
+
+    char buf[18];
+
+    std::memset( buf, '\0', 18 );
+    std::strncpy( buf, team_l.name, 16 );
+    M_last_team_left.name_ = buf;
+    M_last_team_left.score_ = score_l;
+
+    std::memset( buf, '\0', 18 );
+    std::strncpy( buf, team_r.name, 16 );
+    M_last_team_right.name_ = team_r.name;
+    M_last_team_right.score_ = score_r;
+
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+  add new hetero player param
+*/
+bool
+ViewHolder::addPlayerType( const rcsc::rcg::player_type_t & param )
+{
+    //std::cerr << "ViewHolder::addPlayerType" << std::endl;
+
+    int id = static_cast< int >( htons( param.id ) );
+    if ( id < 0 )
+    {
+        std::cerr << "ViewHolder::addPlayerType(). illegal player type id" << std::endl;
+        return false;
+    }
+
+    if ( M_player_types.find( id ) != M_player_types.end() )
+    {
+        M_player_types[id] = rcsc::PlayerType( rcsc::ServerParam::i(), param );
+    }
+    else
+    {
+        M_player_types.insert( std::pair< int, rcsc::PlayerType >
+                               ( id,
+                                 rcsc::PlayerType( rcsc::ServerParam::i(), param ) ) );
+    }
+
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+  set server param
+*/
+bool
+ViewHolder::addServerParam( const rcsc::rcg::server_params_t & param )
+{
+    //std::cerr << "ViewHolder::addServerParam" << std::endl;
+    rcsc::ServerParam::instance().convertFrom( param );
+    M_default_type = rcsc::PlayerType( rcsc::ServerParam::i() );
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+  set player param
+*/
+bool
+ViewHolder::addPlayerParam( const rcsc::rcg::player_params_t & param )
+{
+    //std::cerr << "ViewHolder::addPlayerParam" << std::endl;
+    rcsc::PlayerParam::instance().convertFrom( param );
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+ViewHolder::addShow( const int time,
+                     const rcsc::rcg::ShowInfoT & show )
+{
+    if ( M_monitor_view_cont.size() > RCG_SIZE_LIMIT )
+    {
+        return false;
+    }
+
+    MonitorViewPtr ptr( new MonitorViewData( show,
+                                             M_last_playmode,
+                                             M_last_team_left,
+                                             M_last_team_right ) );
+    addMonitorViewData( ptr );
+
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+ViewHolder::addMsg( const int time,
+                    const int board,
+                    const char * msg )
+{
+    if ( ! std::strncmp( msg,
+                         "(team_graphic_",
+                         std::strlen( "(team_graphic_" ) ) )
+    {
+        return analyzeTeamGraphic( msg );
+    }
+    else if ( ! std::strncmp( msg,
+                              "(change_player_type",
+                              std::strlen( "(change_player_type" ) ) )
+    {
+        return true;
+    }
+
+    std::cerr << "ViewHolder::addMsg [" << msg << "]" << std::endl;
+
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+ViewHolder::addPlayMode( const int time,
+                         const rcsc::PlayMode pm )
+{
+    //std::cerr << "ViewHolder::addPlayMode " << time << " " << pm << std::endl;
+    if ( M_last_playmode != pm )
+    {
+        if ( pm == rcsc::PM_PenaltyScore_Left
+             || pm == rcsc::PM_PenaltyMiss_Left )
+        {
+            long cycle = ( M_latest_view_data
+                           ? M_latest_view_data->cycle()
+                           : 0 );
+            M_penalty_scores_left.push_back( std::make_pair( cycle, pm ) );
+        }
+        else if ( pm == rcsc::PM_PenaltyScore_Right
+                  || pm == rcsc::PM_PenaltyMiss_Right )
+        {
+            long cycle = ( M_latest_view_data
+                           ? M_latest_view_data->cycle()
+                           : 0 );
+            M_penalty_scores_right.push_back( std::make_pair( cycle, pm ) );
+        }
+    }
+
+    M_last_playmode = pm;
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+ViewHolder::addTeam( const int time,
+                     const rcsc::rcg::TeamT & team_l,
+                     const rcsc::rcg::TeamT & team_r )
+{
+    if ( M_last_team_left.score_ != team_l.score_
+         || M_last_team_right.score_ != team_r.score_ )
+    {
+        M_score_change_indexes.push_back( M_monitor_view_cont.size() );
+    }
+
+    M_last_team_left = team_l;
+    M_last_team_right = team_r;
+
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+ViewHolder::addServerParam( const std::string & msg )
+{
+    //std::cerr << "ViewHolder::addServerParam" << std::endl;
+    rcsc::ServerParam::instance().parse( msg.c_str(), 999.0 );
+    M_default_type = rcsc::PlayerType( rcsc::ServerParam::i() );
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+ViewHolder::addPlayerParam( const std::string & msg )
+{
+    //std::cerr << "ViewHolder::addPlayerParam" << std::endl;
+    rcsc::PlayerParam::instance().parse( msg.c_str(), 999.0 );
+    return true;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+ViewHolder::addPlayerType( const std::string & msg )
+{
+    rcsc::PlayerType player_type( rcsc::ServerParam::i(),
+                                  msg.c_str(),
+                                  999.0 );
+
+    //std::cerr << "ViewHolder::addPlayerType " << player_type.id() << std::endl;
+    if ( player_type.id() < 0 )
+    {
+        std::cerr << "ViewHolder::addPlayerType(). illegal player type id = "
+                  << player_type.id()
+                  << std::endl;
+        return false;
+    }
+
+    if ( M_player_types.find( player_type.id() ) != M_player_types.end() )
+    {
+        M_player_types[player_type.id()] = player_type;
+    }
+    else
+    {
+        M_player_types.insert( std::pair< int, rcsc::PlayerType >( player_type.id(), player_type ) );
+    }
+
+    return true;
+}
+
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -476,7 +830,7 @@ ViewHolder::addMonitorViewData( MonitorViewPtr ptr )
 
 /*-------------------------------------------------------------------*/
 /*!
-  this methos should be called just after finish to load rcg file.
+  this methos should be called just after finish to open rcg file.
 */
 void
 ViewHolder::pushBackLatestViewData()
@@ -487,134 +841,6 @@ ViewHolder::pushBackLatestViewData()
     }
 }
 
-/*-------------------------------------------------------------------*/
-/*!
-  push back new data
-*/
-bool
-ViewHolder::addMsgInfo( const rcsc::rcg::Int16 board,
-                        const std::string & msg )
-{
-    //std::cerr << "ViewHolder::addMsgInfo" << std::endl;
-    std::cout << "recv msginfo_t: message = [" << msg << ']'
-              << std::endl;
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-  push back new data
-*/
-bool
-ViewHolder::addDrawInfo( const rcsc::rcg::drawinfo_t & msg )
-{
-    std::cout << "recv drawinfo_t: mode = " << msg.mode
-              << std::endl;
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-  push back new data
-*/
-bool
-ViewHolder::addPlayMode( const char pmode )
-{
-    rcsc::PlayMode playmode = static_cast< rcsc::PlayMode >( pmode );
-
-    if ( M_last_playmode != playmode )
-    {
-        if ( playmode == rcsc::PM_PenaltyScore_Left
-             || playmode == rcsc::PM_PenaltyMiss_Left )
-        {
-            long cycle = ( M_latest_view_data
-                           ? M_latest_view_data->cycle()
-                           : 0 );
-            M_penalty_scores_left.push_back( std::make_pair( cycle, playmode ) );
-        }
-        else if(  playmode == rcsc::PM_PenaltyScore_Right
-                  || playmode == rcsc::PM_PenaltyMiss_Right )
-        {
-            long cycle = ( M_latest_view_data
-                           ? M_latest_view_data->cycle()
-                           : 0 );
-            M_penalty_scores_right.push_back( std::make_pair( cycle, playmode ) );
-        }
-    }
-
-    M_last_playmode = playmode;
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-  push back new data
-*/
-bool
-ViewHolder::addTeamInfo( const rcsc::rcg::team_t & team_l,
-                         const rcsc::rcg::team_t & team_r )
-{
-    if ( M_last_team_left.score != team_l.score
-         || M_last_team_right.score != team_r.score )
-    {
-        M_score_change_indexes.push_back( M_monitor_view_cont.size() );
-    }
-
-    M_last_team_left = team_l;
-    M_last_team_right = team_r;
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-  add new hetero player param
-*/
-bool
-ViewHolder::addPlayerType( const rcsc::rcg::player_type_t & param )
-{
-    //std::cerr << "ViewHolder::addPlayerType" << std::endl;
-
-    int id = static_cast< int >( htons( param.id ) );
-    if ( id < 0 )
-    {
-        std::cerr << "addPlayerType. over the array size" << std::endl;
-        return false;
-    }
-
-    if ( id + 1 >= static_cast< int >( M_player_types.size() ) )
-    {
-        M_player_types.resize( id + 1, rcsc::PlayerType( rcsc::ServerParam::i() ) );
-    }
-
-    M_player_types[id] = rcsc::PlayerType( rcsc::ServerParam::i(),
-                                           param );
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-  set server param
-*/
-bool
-ViewHolder::addServerParam( const rcsc::rcg::server_params_t & param )
-{
-    //std::cerr << "ViewHolder::addServerParam" << std::endl;
-    rcsc::ServerParam::instance().convertFrom( param );
-    return true;
-}
-
-/*-------------------------------------------------------------------*/
-/*!
-  set player param
-*/
-bool
-ViewHolder::addPlayerParam( const rcsc::rcg::player_params_t & param )
-{
-    //std::cerr << "ViewHolder::addPlayerParam" << std::endl;
-    rcsc::PlayerParam::instance().convertFrom( param );
-    return true;
-}
-
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -731,17 +957,54 @@ ViewHolder::getIndexOf( const int cycle ) const
 */
 const
 rcsc::PlayerType &
-ViewHolder::playerType( const std::size_t id ) const
+ViewHolder::playerType( const int id ) const
 {
-    try
+    std::map< int, rcsc::PlayerType >::const_iterator it
+        = M_player_types.find( id );
+
+    if ( it == M_player_types.end() )
     {
-        return M_player_types.at( id );
-    }
-    catch ( std::exception & e )
-    {
-        std::cerr << "Exception caught! " << e.what()
-                  << "invalid player type index " << id
-                  << std::endl;
-        return M_player_types.front();
+        return M_default_type;
     }
+
+    return it->second;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+bool
+ViewHolder::analyzeTeamGraphic( const std::string & msg )
+{
+    char side = '?';
+    int x = -1, y = -1;
+
+    if ( std::sscanf( msg.c_str(),
+                      "(team_graphic_%c ( %d %d ",
+                      &side, &x, &y ) != 3
+         || ( side != 'l' && side != 'r' )
+         || x < 0
+         || y < 0 )
+    {
+        std::cerr << "Illegal team_graphic message ["
+                  << msg << "]" << std::endl;
+        return false;
+    }
+
+    if ( side == 'l' )
+    {
+        //std::cerr << "recv: team_graphic_l (" << x << ',' << y << ')'
+        //          << std::endl;
+        return M_team_graphic_left.parse( msg.c_str() );
+    }
+
+    if ( side == 'r' )
+    {
+        //std::cerr << "recv team_graphic_r (" << x << ',' << y << ')'
+        //          << std::endl;
+        return M_team_graphic_right.parse( msg.c_str() );
+    }
+
+    return false;
 }
