@@ -29,13 +29,14 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef SOCCERWINDOW2_QT_VIEW_HOLDER_H
-#define SOCCERWINDOW2_QT_VIEW_HOLDER_H
+#ifndef SOCCERWINDOW2_MODEL_VIEW_HOLDER_H
+#define SOCCERWINDOW2_MODEL_VIEW_HOLDER_H
 
 #include "monitor_view_data.h"
 #include "debug_view_data.h"
 
 #include <rcsc/common/player_type.h>
+#include <rcsc/common/team_graphic.h>
 #include <rcsc/rcg/holder.h>
 
 #include <map>
@@ -49,9 +50,9 @@ private:
     //! last changed playmode
     rcsc::PlayMode M_last_playmode;
     //! last changed left team info
-    rcsc::rcg::team_t M_last_team_left;
+    rcsc::rcg::TeamT M_last_team_left;
     //! last changed right team info
-    rcsc::rcg::team_t M_last_team_right;
+    rcsc::rcg::TeamT M_last_team_right;
 
     //! the record of score change
     std::vector< std::size_t > M_score_change_indexes;
@@ -60,8 +61,10 @@ private:
     std::vector< std::pair< long, rcsc::PlayMode > > M_penalty_scores_left;
     std::vector< std::pair< long, rcsc::PlayMode > > M_penalty_scores_right;
 
+    // default type
+    rcsc::PlayerType M_default_type;
     //! player_type set
-    std::vector< rcsc::PlayerType > M_player_types;
+    std::map< int, rcsc::PlayerType > M_player_types;
 
     //! last received view data
     MonitorViewPtr M_latest_view_data;
@@ -76,6 +79,12 @@ private:
     std::map< long, DebugViewCont > M_right_debug_view;
 
 
+    //! left team graphic
+    rcsc::TeamGraphic M_team_graphic_left;
+
+    //! right team graphic
+    rcsc::TeamGraphic M_team_graphic_right;
+
     //! nocopyable
     ViewHolder( const ViewHolder & );
     //! nocopyable
@@ -97,42 +106,49 @@ public:
     void saveDebugView( const std::string & dir_path ) const;
 
     //! load debug view data from directory
-    void loadDebugView( const std::string & dir_path );
+    void openDebugView( const std::string & dir_path );
 
     //--------------------------------------------------
     // override methods.
 
+    // rcg v3 or older
+
     //! register showinfo_t (rcg v2, monitor v1)
     bool addShowInfo( const rcsc::rcg::showinfo_t & show );
     //! register showinfo_t (monitor v2 only)
     bool addShowInfo2( const rcsc::rcg::showinfo_t2 & show2 );
     //! register showinfo_t (rcg v3 only)
     bool addShortShowInfo2( const rcsc::rcg::short_showinfo_t2 & show2 );
-
-    void pushBackLatestViewData();
-
-    //! register msginfo_t
     bool addMsgInfo( const rcsc::rcg::Int16 board,
                      const std::string & msg );
-
-    //! register drawinfo_t
     bool addDrawInfo( const rcsc::rcg::drawinfo_t & draw );
-
-    //! register playmode
     bool addPlayMode( const char pmode );
-    //! register team_t * 2
     bool addTeamInfo( const rcsc::rcg::team_t & team_l,
                       const rcsc::rcg::team_t & team_r );
-
-    //! register server_params_t
     bool addServerParam( const rcsc::rcg::server_params_t & sparams );
-    //! register player_params_t
     bool addPlayerParam( const rcsc::rcg::player_params_t & pparams );
-    //! register player_type_t
     bool addPlayerType( const rcsc::rcg::player_type_t & ptinfo );
 
+    // monitor v3 & rcg v4
+
+    bool addShow( const int time,
+                  const rcsc::rcg::ShowInfoT & show );
+    bool addMsg( const int time,
+                 const int board,
+                 const char * msg );
+    bool addPlayMode( const int time,
+                      const rcsc::PlayMode pm );
+    bool addTeam( const int time,
+                  const rcsc::rcg::TeamT & team_l,
+                  const rcsc::rcg::TeamT & team_r );
+    bool addServerParam( const std::string & msg );
+    bool addPlayerParam( const std::string & msg );
+    bool addPlayerType( const std::string & msg );
+
     //--------------------------------------------------
 
+    void pushBackLatestViewData();
+
     //! set debug view data
     void addDebugView( const long & cycle,
                        const char side,
@@ -167,13 +183,13 @@ public:
       }
 
     const
-    std::vector< rcsc::PlayerType > & playerTypeCont() const
+    std::map< int, rcsc::PlayerType > & playerTypeCont() const
       {
           return M_player_types;
       }
 
     const
-    rcsc::PlayerType & playerType( const std::size_t id ) const;
+    rcsc::PlayerType & playerType( const int id ) const;
 
     const
     std::vector< std::size_t > & scoreChangeIndexes() const
@@ -202,17 +218,31 @@ public:
 
     std::size_t getIndexOf( const int cycle ) const;
 
+    const
+    rcsc::TeamGraphic & teamGraphicLeft() const
+      {
+          return M_team_graphic_left;
+      }
+
+    const
+    rcsc::TeamGraphic & teamGraphicRight() const
+      {
+          return M_team_graphic_right;
+      }
+
 private:
     bool saveDebugView( const std::string & dir_path,
                         const std::string & team_name,
                         const int unum,
                         const std::map< long, DebugViewCont > & data ) const;
 
-    bool loadDebugView( const std::string & dir_path,
+    bool openDebugView( const std::string & dir_path,
                         const std::string & team_name,
                         const int unum );
 
     void addMonitorViewData( MonitorViewPtr ptr );
+
+    bool analyzeTeamGraphic( const std::string & msg );
 };
 
 #endif
