@@ -75,12 +75,12 @@ BallPainter::draw( QPainter & painter )
     const int ball_radius
         = std::max( 1,
                     ( vconf.isEnlarged()
-                      ? vconf.scale( AppConfig::instance().enlargedBallSize() )
+                      ? vconf.scale( vconf.ballSize() )
                       : vconf.scale( rcsc::ServerParam::i().ballSize() ) )
                     );
     const int ball_diameter = ball_radius * 2;
-    const int ix = vconf.screenX( view->ball().x() * vconf.reverseValue() );
-    const int iy = vconf.screenY( view->ball().y() * vconf.reverseValue() );
+    const int ix = vconf.screenX( view->ball().x() );
+    const int iy = vconf.screenY( view->ball().y() );
 
 
     // set GDI objects
@@ -155,32 +155,38 @@ BallPainter::drawFutureState( QPainter & painter ) const
     rcsc::Vector2D bvel( view->ball().deltaX(),
                          view->ball().deltaY() );
 
-    QPoint first_point( vconf.screenX( bpos.x * vconf.reverseValue() ),
-                        vconf.screenY( bpos.y * vconf.reverseValue() ) );
-    QPoint last_point = first_point;
-    const int last = vconf.ballFutureCycle();
+    bpos *= vconf.reverseValue();
+    bvel *= vconf.reverseValue();
+
+    QPoint first_point( vconf.absScreenX( bpos.x ),
+                        vconf.absScreenY( bpos.y ) );
+
+    painter.save();
+    painter.translate( first_point.x(), first_point.y() );
+    painter.rotate( bvel.th().degree() );
 
     painter.setPen( dconf.ballPen() );
     painter.setBrush( dconf.transparentBrush() );
 
-    for ( int i = 0; i < last; ++i )
+    double travel = 0.0;
+    double speed = bvel.r();
+    int last_x = 0;
+    const int max_loop = vconf.ballFutureCycle();
+    for ( int i = 0; i < max_loop; ++i )
     {
-        bpos += bvel;
-        bvel *= sparam.ballDecay();
+        travel += speed;
+        speed *= sparam.ballDecay();
 
-        QPoint pt( vconf.screenX( bpos.x * vconf.reverseValue() ),
-                   vconf.screenY( bpos.y * vconf.reverseValue() ) );
-        if ( std::abs( last_point.x() - pt.x() ) < 1
-             && std::abs( last_point.y() - pt.y() ) < 1 )
+        int x = vconf.scale( travel );
+        if ( std::abs( last_x - x ) < 1 )
         {
             break;
         }
-        last_point = pt;
-        painter.drawEllipse( pt.x() - 1,
-                             pt.y() - 1,
-                             3,
-                             3 );
+        last_x = x;
+        painter.drawEllipse( x - 1, -1, 3, 3 );
     }
 
-    painter.drawLine( first_point, last_point );
+    painter.drawLine( 0, 0, last_x, 0 );
+
+    painter.restore();
 }
