@@ -116,8 +116,8 @@ BallTracePainter::draw( QPainter & painter )
     black_dot_pen.setStyle( Qt::DotLine );
 
     std::size_t i = first;
-    int prev_x = vconf.screenX( vc[i]->ball().x() * vconf.reverseValue() );
-    int prev_y = vconf.screenY( vc[i]->ball().y() * vconf.reverseValue() );
+    int prev_x = vconf.screenX( vc[i]->ball().x() );
+    int prev_y = vconf.screenY( vc[i]->ball().y() );
     ++i;
     for ( ; i <= last; ++i )
     {
@@ -139,8 +139,8 @@ BallTracePainter::draw( QPainter & painter )
             break;
         }
 
-        int ix = vconf.screenX( vc[i]->ball().x() * vconf.reverseValue() );
-        int iy = vconf.screenY( vc[i]->ball().y() * vconf.reverseValue() );
+        int ix = vconf.screenX( vc[i]->ball().x() );
+        int iy = vconf.screenY( vc[i]->ball().y() );
 
         if ( line_trace )
         {
