@@ -33,68 +33,27 @@
 #define SOCCERWINDOW2_QT3_COLOR_SETTING_DIALOG_H
 
 #include <qdialog.h>
-#include <qpushbutton.h>
 
-#include <map>
+#include <vector>
 
+class QListBox;
 class QPen;
 class QBrush;
 
-class ColorButton;
-class ColorSettingDialog;
+struct ColorEntry {
+    QColor default_color_;
+    QColor color_;
+    QPen * pen_;
+    QBrush * brush_;
 
-class ColorButton
-    : public QPushButton {
+    ColorEntry( QPen * pen,
+                QBrush * brush );
 
-    Q_OBJECT
-
-private:
-    QString M_name;
-    QColor M_default_color;
-    QColor M_color;
-    QPen * M_pen;
-    QBrush * M_brush;
-
-public:
-
-    ColorButton( const QString & name,
-                 QPen * pen,
-                 QBrush * brush,
-                 ColorSettingDialog * parent );
-    const
-    QString & name() const
-      {
-          return M_name;
-      }
-
-    const
-    QColor & defaultColor() const
-      {
-          return M_default_color;
-      }
-
-    const
-    QColor & color() const
-      {
-          return M_color;
-      }
-
-    void setColor( const QColor & color );
-
-    void revert();
-    void updateIcon();
-    void checkColor();
-
-private slots:
-
-    void colorDialog();
-
-signals:
-
-    void colorChanged();
+    bool setColor( const QColor & color );
+    bool revert();
+    bool checkColor();
 };
 
-
 /*-------------------------------------------------------------------*/
 
 /*!
@@ -108,7 +67,9 @@ class ColorSettingDialog
 
 private:
 
-    std::map< QString, ColorButton * > M_color_buttons;
+    QListBox * M_list_box;
+
+    std::vector< ColorEntry > M_color_entries;
 
 public:
 
@@ -120,6 +81,10 @@ private:
 
     void createControls();
 
+    void addEntry( const QString & name,
+                   QPen * pen,
+                   QBrush * brush );
+
     QLayout * createColorButtons();
     QLayout * createAnswerButtons();
 
@@ -129,6 +94,8 @@ private slots:
 
     void setDefaultColors();
 
+    void selectEntry();
+
 public slots:
 
     virtual
