@@ -125,7 +125,8 @@ QWidget *
 DebugLogDirDialog::createSideSelectionBox()
 {
     // create side selection buttons
-    QHGroupBox * selection_box = new QHGroupBox( tr( "Side Selection" ), this );
+    QHButtonGroup * selection_box = new QHButtonGroup( tr( "Side Selection" ),
+                                                       this );
 
     //QHBoxLayout * layout = new QHBoxLayout( selection_box );
 
@@ -159,7 +160,7 @@ DebugLogDirDialog::createDirSelectionBox()
     QString dir_str;
     if ( AppConfig::instance().debugLogDir().empty() )
     {
-        dir_str = QDir::current().absPath();
+        dir_str = QDir::homeDirPath();
     }
     else
     {
