@@ -44,7 +44,6 @@
 #include "app_config.h"
 
 #include <cassert>
-#include <cstdlib> // getenv
 #include <iostream>
 
 #include "xpm/debug_view_all.xpm"
@@ -113,7 +112,7 @@ DebugMessageWindow::DebugMessageWindow( QWidget * parent,
     createActions();
     createWindows();
 
-    loadSettings();
+    readSettings();
 
     this->resize( 640, 480 );
 }
@@ -133,7 +132,7 @@ DebugMessageWindow::~DebugMessageWindow()
 
 */
 void
-DebugMessageWindow::loadSettings()
+DebugMessageWindow::readSettings()
 {
     QSettings settings( QSettings::Ini );
     settings.insertSearchPath( QSettings::Unix,
@@ -141,7 +140,40 @@ DebugMessageWindow::loadSettings()
 
     settings.beginGroup( "/.soccerwindow2-qt3./DebugMessageWindow" );
 
-    // read debug switch status
+    // read debug view switch statis
+    {
+        bool ok = false;
+        bool enable = false;
+
+        enable = settings.readBoolEntry( tr( "debug_view_all" ), true, &ok );
+        if ( ok ) M_show_debug_view_all_act->setOn( enable );
+
+        enable = settings.readBoolEntry( tr( "debug_view_self" ), true, &ok );
+        if ( ok ) M_show_debug_view_self_act->setOn( enable );
+
+        enable = settings.readBoolEntry( tr( "debug_view_ball" ), true, &ok );
+        if ( ok ) M_show_debug_view_ball_act->setOn( enable );
+
+        enable = settings.readBoolEntry( tr( "debug_view_players" ), true, &ok );
+        if ( ok ) M_show_debug_view_players_act->setOn( enable );
+
+        enable = settings.readBoolEntry( tr( "debug_view_comment" ), true, &ok );
+        if ( ok ) M_show_debug_view_comment_act->setOn( enable );
+
+        enable = settings.readBoolEntry( tr( "debug_view_figures" ), true, &ok );
+        if ( ok ) M_show_debug_view_figure_act->setOn( enable );
+
+        enable = settings.readBoolEntry( tr( "debug_view_target" ), true, &ok );
+        if ( ok ) M_show_debug_view_target_act->setOn( enable );
+
+        enable = settings.readBoolEntry( tr( "debug_view_message" ), true, &ok );
+        if ( ok ) M_show_debug_view_message_act->setOn( enable );
+
+        enable = settings.readBoolEntry( tr( "debug_log_objects" ), true, &ok );
+        if ( ok ) M_show_debug_log_objects_act->setOn( enable );
+    }
+
+    // read debug level switch status
     for ( int i = 0; i < 16; ++i )
     {
         char key[32];
@@ -159,9 +191,13 @@ DebugMessageWindow::loadSettings()
 
             M_debug_level_act[i]->setOn( enable );
         }
+        else
+        {
+            M_debug_level_act[i]->setOn( true );
+        }
     }
 
-    // read debug text string
+    // read debug level text string
     for ( int i = 0; i < 16; ++i )
     {
         char key[32];
@@ -196,6 +232,18 @@ DebugMessageWindow::saveSettings()
 
     settings.beginGroup( "/.soccerwindow2-qt3./DebugMessageWindow" );
 
+    // save debug view switches
+    settings.writeEntry( tr( "debug_view_all" ),  M_show_debug_view_all_act->isOn() );
+    settings.writeEntry( tr( "debug_view_self" ), M_show_debug_view_self_act->isOn() );
+    settings.writeEntry( tr( "debug_view_ball" ), M_show_debug_view_ball_act->isOn() );
+    settings.writeEntry( tr( "debug_view_players" ), M_show_debug_view_players_act->isOn() );
+    settings.writeEntry( tr( "debug_view_comment" ), M_show_debug_view_comment_act->isOn() );
+    settings.writeEntry( tr( "debug_view_figures" ), M_show_debug_view_figure_act->isOn() );
+    settings.writeEntry( tr( "debug_view_target" ), M_show_debug_view_target_act->isOn() );
+    settings.writeEntry( tr( "debug_view_message" ), M_show_debug_view_message_act->isOn() );
+    settings.writeEntry( tr( "debug_log_objects" ), M_show_debug_log_objects_act->isOn() );
+
+    // save debug level switches
     for ( int i = 0; i < 16; ++i )
     {
         char key[32];
@@ -205,6 +253,7 @@ DebugMessageWindow::saveSettings()
                              M_debug_level_act[i]->isOn() );
     }
 
+    // save debug level text
     for ( int i = 0; i < 16; ++i )
     {
         if ( ! M_debug_text[i].isEmpty() )
@@ -316,17 +365,17 @@ DebugMessageWindow::createActions()
              this, SLOT( toggleShowDebugViewMessage( bool ) ) );
 
     //////////////////////////////////////////////
-    // debug log view
-    M_show_debug_log_view_act
+    // debug log object
+    M_show_debug_log_objects_act
         = new QAction( QIconSet( QPixmap( debug_log_view_xpm ) ),
-                       tr( "Toggle debug log view" ),
+                       tr( "Toggle debug log objects" ),
                        QKeySequence(),
                        this );
-    M_show_debug_log_view_act->setStatusTip( tr( "Show/Hide debug log view" ) );
-    M_show_debug_log_view_act->setToggleAction( true );
-    M_show_debug_log_view_act->setOn( true );
-    connect( M_show_debug_log_view_act, SIGNAL( toggled( bool ) ),
-             this, SLOT( toggleShowDebugLogView( bool ) ) );
+    M_show_debug_log_objects_act->setStatusTip( tr( "Show/Hide debug log objects" ) );
+    M_show_debug_log_objects_act->setToggleAction( true );
+    M_show_debug_log_objects_act->setOn( true );
+    connect( M_show_debug_log_objects_act, SIGNAL( toggled( bool ) ),
+             this, SLOT( toggleShowDebugLogObjects( bool ) ) );
 
     //////////////////////////////////////////////
     // dir selection
@@ -335,6 +384,7 @@ DebugMessageWindow::createActions()
                        tr( "Open log dir..." ),
                        QKeySequence(),
                        this );
+    M_open_debug_log_dir_act->setAccel( tr( "Ctrl+O" ) );
     M_open_debug_log_dir_act->setStatusTip( tr( "Open the debug log directory" ) );
     connect( M_open_debug_log_dir_act, SIGNAL( activated() ),
              this, SLOT( showDebugLogDirDialog() ) );
@@ -346,6 +396,7 @@ DebugMessageWindow::createActions()
                        tr( "Sync" ),
                        QKeySequence(),
                        this );
+    M_sync_act->setAccel( tr( "Ctrl+S" ) );
     M_sync_act->setStatusTip( tr( "Synchronize with field canvas" ) );
     connect( M_sync_act, SIGNAL( activated() ),
              this, SLOT( syncCycle() ) );
@@ -355,6 +406,7 @@ DebugMessageWindow::createActions()
                        tr( "Decrement" ),
                        QKeySequence(),
                        this );
+    M_decrement_act->setAccel( Qt::CTRL + Qt::Key_Left );
     M_decrement_act->setStatusTip( tr( "Decrement message cycle" ) );
     connect( M_decrement_act, SIGNAL( activated() ),
              this, SLOT( decrementCycle() ) );
@@ -364,6 +416,7 @@ DebugMessageWindow::createActions()
                        tr( "Increment" ),
                        QKeySequence(),
                        this );
+    M_decrement_act->setAccel( Qt::CTRL + Qt::Key_Right );
     M_increment_act->setStatusTip( tr( "Increment message cycle" ) );
     connect( M_increment_act, SIGNAL( activated() ),
              this, SLOT( incrementCycle() ) );
@@ -394,6 +447,7 @@ DebugMessageWindow::createActions()
                  debug_level_mapper, SLOT( map() ) );
         debug_level_mapper->setMapping( M_debug_level_act[i], i + 1 );
     }
+
 }
 
 
@@ -432,7 +486,7 @@ void
 DebugMessageWindow::createToolBar()
 {
     {
-        QToolBar * tbar = new QToolBar();
+        QToolBar * tbar = new QToolBar( this );
 
         M_open_debug_log_dir_act->addTo( tbar );
 
@@ -444,12 +498,18 @@ DebugMessageWindow::createToolBar()
 
         tbar->addSeparator();
 
-        QLabel * find_label = new QLabel( tr( "Find: " ), tbar );
+        new QLabel( tr( "Find: " ), tbar );
         M_find_box = new QLineEdit( tbar );
         connect( M_find_box, SIGNAL( returnPressed() ),
                  this, SLOT( findExistString() ) );
         connect( M_find_box, SIGNAL( textChanged( const QString & ) ),
                  this, SLOT( findString( const QString & ) ) );
+        // short cut
+        {
+            QAccel * accel = new QAccel( this );
+            accel->connectItem( accel->insertItem( tr( "Ctrl+F" ) ),
+                                M_find_box, SLOT( setFocus() ) );
+        }
         //QToolTip::add( M_find_box, tr( "Find the matched string from the below window" ) );
 
         QHButtonGroup * btn_group = new QHButtonGroup( tbar );
@@ -468,7 +528,7 @@ DebugMessageWindow::createToolBar()
     }
 
     {
-        QToolBar * tbar = new QToolBar();
+        QToolBar * tbar = new QToolBar( this );
 
         M_show_debug_view_all_act->addTo( tbar );
         M_show_debug_view_self_act->addTo( tbar );
@@ -481,7 +541,7 @@ DebugMessageWindow::createToolBar()
 
         tbar->addSeparator();
 
-        M_show_debug_log_view_act->addTo( tbar );
+        M_show_debug_log_objects_act->addTo( tbar );
 
          for ( int i = 0; i < 16; ++i )
          {
@@ -498,8 +558,8 @@ DebugMessageWindow::createToolBar()
 
 */
 void
-DebugMessageWindow::loadDebugLogDir( const rcsc::SideID side,
-                                    const std::string & dir_path )
+DebugMessageWindow::openDebugLogDir( const rcsc::SideID side,
+                                     const std::string & dir_path )
 {
     MonitorViewConstPtr ptr = M_main_data.getViewData( M_main_data.viewIndex() );
     if ( ! ptr )
@@ -668,11 +728,11 @@ DebugMessageWindow::toggleShowDebugViewMessage( bool checked )
 
 */
 void
-DebugMessageWindow::toggleShowDebugLogView( bool checked )
+DebugMessageWindow::toggleShowDebugLogObjects( bool checked )
 {
-    if ( M_main_data.viewConfig().isShownDebugLogView() != checked )
+    if ( M_main_data.viewConfig().isShownDebugLogObjects() != checked )
     {
-        M_main_data.getViewConfig().toggleShowDebugLogView();
+        M_main_data.getViewConfig().toggleShowDebugLogObjects();
         emit configured();
     }
 }
@@ -703,7 +763,7 @@ DebugMessageWindow::showDebugLogDirDialog()
 
     AppConfig::instance().setDebugLogDir( dir_path_std );
 
-    loadDebugLogDir( side, dir_path_std );
+    openDebugLogDir( side, dir_path_std );
 }
 
 /*-------------------------------------------------------------------*/
@@ -786,11 +846,24 @@ DebugMessageWindow::findExistString()
 void
 DebugMessageWindow::findString( const QString & expr )
 {
-    M_message[ M_tab_widget->currentPageIndex() ]
-        ->find( expr,
-                false, // case insentive
-                false, // no whole word
-                M_find_forward_rb->isOn() );
+    QTextEdit * edit = M_message[ M_tab_widget->currentPageIndex() ];
+    bool forward = M_find_forward_rb->isOn();
+
+    if ( ! edit->find( expr,
+                       false, // case insentive
+                       false, // no whole word
+                       forward ) )
+    {
+        int para = 0;
+        int index = 0;
+        if ( ! M_find_forward_rb->isOn() )
+        {
+            para = edit->paragraphs();
+            index = std::max( 0, edit->paragraphLength( para - 1 ) - 1 );
+        }
+
+        edit->find( expr, false, false, forward, &para, &index );
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -868,7 +941,6 @@ DebugMessageWindow::updateMessage()
     int n_line = 0;
 
     int show_para = 0;
-    int show_index = 0;
     const DebugLogHolder::DataList::const_iterator data_end = data_list->end();
     for ( DebugLogHolder::DataList::const_iterator data_it = data_list->begin();
           data_it != data_end;
