@@ -79,7 +79,7 @@ private:
     QAction * M_show_debug_view_target_act;
     QAction * M_show_debug_view_message_act;
 
-    QAction * M_show_debug_log_view_act;
+    QAction * M_show_debug_log_objects_act;
 
     QAction * M_open_debug_log_dir_act;
 
@@ -88,7 +88,6 @@ private:
     QAction * M_increment_act;
 
     QString M_debug_text[16];
-    QActionGroup * M_debug_level_act_group;
     QAction * M_debug_level_act[16];
 
     //! not used
@@ -107,14 +106,14 @@ public:
 
 private:
 
-    void loadSettings();
+    void readSettings();
     void saveSettings();
 
     void createActions();
     void createWindows();
     void createToolBar();
 
-    void loadDebugLogDir( const rcsc::SideID side,
+    void openDebugLogDir( const rcsc::SideID side,
                           const std::string & dir_path );
 
 private slots:
@@ -130,7 +129,7 @@ private slots:
     void toggleShowDebugViewTarget( bool checked );
     void toggleShowDebugViewMessage( bool checked );
 
-    void toggleShowDebugLogView( bool checked );
+    void toggleShowDebugLogObjects( bool checked );
 
     void showDebugLogDirDialog();
 
