@@ -66,10 +66,10 @@ DebugPainter::draw( QPainter & painter )
         return;
     }
 
-    const rcsc::SideID player_side = ( number < 0 ? rcsc::RIGHT : rcsc::LEFT );
+    const rcsc::SideID self_side = ( number < 0 ? rcsc::RIGHT : rcsc::LEFT );
 
     const std::map< long, DebugViewCont > & view_map
-        = ( player_side == rcsc::RIGHT
+        = ( self_side == rcsc::RIGHT
             ? M_main_data.viewHolder().rightDebugView()
             : M_main_data.viewHolder().leftDebugView() );
 
@@ -113,36 +113,41 @@ DebugPainter::draw( QPainter & painter )
     // draw self
     if ( vconf.isShownDebugViewSelf() )
     {
-        drawSelf( painter, player_side, *view );
+        drawSelf( painter, self_side, *view );
     }
 
     // draw players
     if ( vconf.isShownDebugViewPlayers() )
     {
         drawPlayers( painter,
-                     player_side,
+                     self_side,
+                     *view,
                      view->teammates(),
                      ( vconf.isShownDebugViewTarget()
                        ? view->targetTeammate()
                        : -1 ),
                      dconf.debugTeammateBrush() );
         drawPlayers( painter,
-                     player_side,
+                     self_side,
+                     *view,
                      view->opponents(),
                      -1,
                      dconf.debugOpponentBrush() );
         drawPlayers( painter,
-                     player_side,
+                     self_side,
+                     *view,
                      view->unknownTeammates(),
                      -1,
                      dconf.debugUnknownTeammateBrush() );
         drawPlayers( painter,
-                     player_side,
+                     self_side,
+                     *view,
                      view->unknownOpponents(),
                      -1,
                      dconf.debugUnknownOpponentBrush() );
         drawPlayers( painter,
-                     player_side,
+                     self_side,
+                     *view,
                      view->unknownPlayers(),
                      -1,
                      dconf.debugUnknownPlayerBrush() );
@@ -152,16 +157,16 @@ DebugPainter::draw( QPainter & painter )
     if ( vconf.isShownDebugViewBall()
          && view->ball() )
     {
-        drawBall( painter, player_side, *view );
+        drawBall( painter, self_side, *view );
     }
 
     // draw lines
     if ( vconf.isShownDebugViewFigure() )
     {
-        drawLines( painter, player_side, *view );
-        drawTriangles( painter, player_side, *view );
-        drawRectangles( painter, player_side, *view );
-        drawCircles( painter, player_side, *view );
+        drawLines( painter, self_side, *view );
+        drawTriangles( painter, self_side, *view );
+        drawRectangles( painter, self_side, *view );
+        drawCircles( painter, self_side, *view );
     }
 
     if ( vconf.isShownDebugViewMessage()
@@ -177,7 +182,7 @@ DebugPainter::draw( QPainter & painter )
 */
 void
 DebugPainter::drawSelf( QPainter & painter,
-                        const rcsc::SideID player_side,
+                        const rcsc::SideID self_side,
                         const DebugViewData & view ) const
 {
     const boost::shared_ptr< DebugViewData::SelfT > self = view.self();
@@ -190,11 +195,9 @@ DebugPainter::drawSelf( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( vconf.reverseValue()
-                             * ( player_side == rcsc::LEFT
-                                 ? 1.0
-                                 : -1.0 )
-                             );
+    const double reverse = ( self_side == rcsc::LEFT
+                             ? 1.0
+                             : -1.0 );
 
     const int ix = vconf.screenX( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
     const int iy = vconf.screenY( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
@@ -222,7 +225,7 @@ DebugPainter::drawSelf( QPainter & painter,
     // draw body half circle
     double body_start_dir = - ( (double)self->body_ + 90.0 );
     if ( vconf.reverseSide() ) body_start_dir += 180.0;
-    if ( player_side == rcsc::RIGHT ) body_start_dir -= 180.0;
+    if ( self_side == rcsc::RIGHT ) body_start_dir -= 180.0;
 
     painter.setPen( dconf.transparentPen() );
     painter.setBrush( dconf.debugSelfBrush() );
@@ -264,7 +267,7 @@ DebugPainter::drawSelf( QPainter & painter,
 */
 void
 DebugPainter::drawBall( QPainter & painter,
-                        const rcsc::SideID player_side,
+                        const rcsc::SideID self_side,
                         const DebugViewData & view ) const
 {
     const boost::shared_ptr< DebugViewData::BallT > & ball = view.ball();
@@ -277,11 +280,9 @@ DebugPainter::drawBall( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( vconf.reverseValue()
-                             * ( player_side == rcsc::LEFT
-                                 ? 1.0
-                                 : -1.0 )
-                             );
+    const double reverse = ( self_side == rcsc::LEFT
+                             ? 1.0
+                             : -1.0 );
 
     rcsc::Vector2D bpos( (double)ball->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse,
                          (double)ball->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
@@ -343,7 +344,8 @@ DebugPainter::drawBall( QPainter & painter,
 */
 void
 DebugPainter::drawPlayers( QPainter & painter,
-                           const rcsc::SideID player_side,
+                           const rcsc::SideID self_side,
+                           const DebugViewData & view,
                            const DebugViewData::PlayerCont & players,
                            const int target_number,
                            const QBrush & body_brush ) const
@@ -351,8 +353,9 @@ DebugPainter::drawPlayers( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( vconf.reverseValue()
-                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
+    const double reverse = ( self_side == rcsc::RIGHT
+                             ? -1.0
+                             : 1.0 );
 
     const bool comment = vconf.isShownDebugViewComment();
     const int r = std::max( 2,
@@ -372,7 +375,7 @@ DebugPainter::drawPlayers( QPainter & painter,
         {
             double body_start_dir = - ( (double)(*it)->body_ + 90.0 );
             if ( vconf.reverseSide() ) body_start_dir += 180.0;
-            if ( player_side == rcsc::RIGHT ) body_start_dir -= 180.0;
+            if ( self_side == rcsc::RIGHT ) body_start_dir -= 180.0;
             //double body_end_dir = body_start_dir + 180.0;
             // draw body half circle
             painter.setPen( dconf.transparentPen() );
@@ -400,13 +403,22 @@ DebugPainter::drawPlayers( QPainter & painter,
             painter.setPen( dconf.debugCommentFontPen() );
 
             painter.drawText( ix + r, iy + 4,
-            QString::number( (*it)->unum_ ) );
+                              QString::number( (*it)->unum_ ) );
         }
 
         if ( target_number == (*it)->unum_ )
         {
             painter.setPen( dconf.debugTargetPen() );
             painter.setBrush( dconf.transparentBrush() );
+
+            const boost::shared_ptr< DebugViewData::SelfT > self = view.self();
+            if ( self )
+            {
+                const int sx = vconf.screenX( (double)self->x_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+                const int sy = vconf.screenY( (double)self->y_ / rcsc::rcg::SHOWINFO_SCALE2 * reverse );
+                painter.drawLine( sx, sy, ix, iy );
+            }
+
             int rr = r + 2;
             painter.drawEllipse( ix - rr, iy - rr,
                                  rr * 2, rr * 2 );
@@ -432,7 +444,7 @@ DebugPainter::drawPlayers( QPainter & painter,
 */
 void
 DebugPainter::drawLines( QPainter & painter,
-                         const rcsc::SideID player_side,
+                         const rcsc::SideID self_side,
                          const DebugViewData & view ) const
 {
     if ( view.lines().empty() )
@@ -443,8 +455,9 @@ DebugPainter::drawLines( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( vconf.reverseValue()
-                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
+    const double reverse = ( self_side == rcsc::RIGHT
+                             ? -1.0
+                             : 1.0 );
 
     painter.setPen( dconf.debugFigurePen() );
     painter.setBrush( dconf.transparentBrush() );
@@ -467,7 +480,7 @@ DebugPainter::drawLines( QPainter & painter,
 */
 void
 DebugPainter::drawTriangles( QPainter & painter,
-                             const rcsc::SideID player_side,
+                             const rcsc::SideID self_side,
                              const DebugViewData & view ) const
 {
     if ( view.triangles().empty() )
@@ -478,8 +491,9 @@ DebugPainter::drawTriangles( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( vconf.reverseValue()
-                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
+    const double reverse = ( self_side == rcsc::RIGHT
+                             ? -1.0
+                             : 1.0 );
 
     painter.setPen( dconf.debugFigurePen() );
     painter.setBrush( dconf.transparentBrush() );
@@ -511,7 +525,7 @@ DebugPainter::drawTriangles( QPainter & painter,
 */
 void
 DebugPainter::drawRectangles( QPainter & painter,
-                              const rcsc::SideID player_side,
+                              const rcsc::SideID self_side,
                               const DebugViewData & view ) const
 {
     if ( view.rectangles().empty() )
@@ -522,8 +536,9 @@ DebugPainter::drawRectangles( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( vconf.reverseValue()
-                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
+    const double reverse = ( self_side == rcsc::RIGHT
+                             ? -1.0
+                             : 1.0 );
 
     painter.setPen( dconf.debugFigurePen() );
     painter.setBrush( dconf.transparentBrush() );
@@ -551,7 +566,7 @@ DebugPainter::drawRectangles( QPainter & painter,
 */
 void
 DebugPainter::drawCircles( QPainter & painter,
-                           const rcsc::SideID player_side,
+                           const rcsc::SideID self_side,
                            const DebugViewData & view ) const
 {
     if ( view.circles().empty() )
@@ -562,8 +577,9 @@ DebugPainter::drawCircles( QPainter & painter,
     const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    const double reverse = ( vconf.reverseValue()
-                             * ( player_side == rcsc::RIGHT ? -1.0 : 1.0 ) );
+    const double reverse = ( self_side == rcsc::RIGHT
+                             ? -1.0
+                             : 1.0 );
 
     painter.setPen( dconf.debugFigurePen() );
     painter.setBrush( dconf.transparentBrush() );
