@@ -57,33 +57,34 @@ public:
 private:
 
     void drawSelf( QPainter & painter,
-                   const rcsc::SideID player_side,
+                   const rcsc::SideID self_side,
                    const DebugViewData & view ) const;
 
     void drawBall( QPainter & painter,
-                   const rcsc::SideID player_side,
+                   const rcsc::SideID self_side,
                    const DebugViewData & view ) const;
 
-    void drawPlayers( QPainter &painter,
-                      const rcsc::SideID player_side,
+    void drawPlayers( QPainter & painter,
+                      const rcsc::SideID self_side,
+                      const DebugViewData & view,
                       const DebugViewData::PlayerCont & players,
                       const int target_number,
                       const QBrush & body_brush ) const;
 
     void drawLines( QPainter & painter,
-                    const rcsc::SideID player_side,
+                    const rcsc::SideID self_side,
                     const DebugViewData & view ) const;
 
     void drawTriangles( QPainter & painter,
-                        const rcsc::SideID player_side,
+                        const rcsc::SideID self_side,
                         const DebugViewData & view ) const;
 
     void drawRectangles( QPainter & painter,
-                         const rcsc::SideID player_side,
+                         const rcsc::SideID self_side,
                          const DebugViewData & view ) const;
 
     void drawCircles( QPainter & painter,
-                      const rcsc::SideID player_side,
+                      const rcsc::SideID self_side,
                         const DebugViewData & view ) const;
 
     void drawMessage( QPainter & painter,
