@@ -108,43 +108,34 @@ DetailDialog::createBallLabels()
     QGridLayout * layout = new QGridLayout( top_layout );
     layout->setMargin( 5 );
     layout->setSpacing( 0 );
-    // set minimal column width (qt4: setColumnMinimumWidth())
-    layout->setColSpacing( 1,
-                           this->fontMetrics().width( tr( " -12.345 -12.345" ) ) );
+    layout->setColSpacing( 0, this->fontMetrics().width( tr( "AttentionTo " ) ) );
+    layout->setColSpacing( 1, this->fontMetrics().width( tr( " -12.34, -12.34" ) ) );
+    layout->setColSpacing( 2, this->fontMetrics().width( tr( " (123.456, -123.4)" ) ) );
 
     int row = 0;
 
     layout->addWidget( new QLabel( tr( "Pos " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_ball_pos = new QLabel( tr( " 000.00, 000.00" ), group_box );
+    M_ball_pos = new QLabel( tr( "   0.00,   0.00" ), group_box );
     layout->addWidget( M_ball_pos, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Vel " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_ball_vel = new QLabel( tr( " 000.00, 000.00" ), group_box );
+    M_ball_vel = new QLabel( tr( "   0.00,   0.00" ), group_box );
     layout->addWidget( M_ball_vel, row, 1, Qt::AlignRight );
-    ++row;
-
-    layout->addWidget( new QLabel( tr( "PolarVel " ), group_box ),
-                       row, 0, Qt::AlignRight );
-    M_ball_polar_vel = new QLabel( tr( " 000.00, 000.00" ), group_box );
-    layout->addWidget( M_ball_polar_vel, row, 1, Qt::AlignRight );
+    M_ball_polar_vel = new QLabel( tr( " (  0.000,    0.0)" ), group_box );
+    layout->addWidget( M_ball_polar_vel, row, 2, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "LastMove " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_ball_last_move = new QLabel( tr( " 000.00, 000.00" ), group_box );
+    M_ball_last_move = new QLabel( tr( "   0.00,   0.00" ), group_box );
     layout->addWidget( M_ball_last_move, row, 1, Qt::AlignRight );
+    M_ball_last_polar_move = new QLabel( tr( " (  0.000,    0.0)" ), group_box );
+    layout->addWidget( M_ball_last_polar_move, row, 2, Qt::AlignRight );
     ++row;
 
-    layout->addWidget( new QLabel( tr( "LastPolar " ), group_box ),
-                       row, 0, Qt::AlignRight );
-    M_ball_last_polar_move = new QLabel( tr( " 000.00, 000.00" ), group_box );
-    layout->addWidget( M_ball_last_polar_move, row, 1, Qt::AlignRight );
-    ++row;
-
-    //group_box->setLayout( layout ); // qt4
     return group_box;
 }
 
@@ -164,9 +155,9 @@ DetailDialog::createPlayerLabels()
     QGridLayout * layout = new QGridLayout( top_layout );
     layout->setMargin( 5 );
     layout->setSpacing( 0 );
-    // set minimal column width (qt4: setColumnMinimumWidth())
-    layout->setColSpacing( 1,
-                           this->fontMetrics().width( tr( " -12.345 -12.345" ) ) );
+    layout->setColSpacing( 0, this->fontMetrics().width( tr( "AttentionTo " ) ) );
+    layout->setColSpacing( 1, this->fontMetrics().width( tr( " -12.34, -12.34" ) ) );
+    layout->setColSpacing( 2, this->fontMetrics().width( tr( " (123.456, -123.4)" ) ) );
 
     int row = 0;
 
@@ -184,55 +175,59 @@ DetailDialog::createPlayerLabels()
 
     layout->addWidget( new QLabel( tr( "Pos " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_player_pos = new QLabel( tr( " 000.00, 000.00" ), group_box );
+    M_player_pos = new QLabel( tr( "   0.00,   0.00" ), group_box );
     layout->addWidget( M_player_pos, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Vel " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_player_vel= new QLabel( tr( " 000.00, 000.00" ), group_box );
+    M_player_vel= new QLabel( tr( "   0.00,   0.00" ), group_box );
     layout->addWidget( M_player_vel, row, 1, Qt::AlignRight );
-    ++row;
-
-    layout->addWidget( new QLabel( tr( "Polar " ), group_box ),
-                       row, 0, Qt::AlignRight );
-    M_player_polar_vel = new QLabel( tr( " 000.00, 000.00" ), group_box );
-    layout->addWidget( M_player_polar_vel, row, 1, Qt::AlignRight );
+    M_player_polar_vel = new QLabel( tr( " (  0.000,    0.0)" ), group_box );
+    layout->addWidget( M_player_polar_vel, row, 2, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "MaxTurn " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_max_turn_moment = new QLabel( tr( " 180.00" ), group_box );
+    M_max_turn_moment = new QLabel( tr( "   0.00" ), group_box );
     layout->addWidget( M_max_turn_moment, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "LastMove " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_player_last_move = new QLabel( tr( " 000.00, 000.00" ), group_box );
+    M_player_last_move = new QLabel( tr( "   0.00,   0.00" ), group_box );
     layout->addWidget( M_player_last_move, row, 1, Qt::AlignRight );
-    ++row;
-
-    layout->addWidget( new QLabel( tr( "Polar " ), group_box ),
-                       row, 0, Qt::AlignRight );
-    M_player_last_polar_move = new QLabel( tr( " 000.00, 000.00" ), group_box );
-    layout->addWidget( M_player_last_polar_move, row, 1, Qt::AlignRight );
+    M_player_last_polar_move = new QLabel( tr( " (  0.000,    0.0)" ), group_box );
+    layout->addWidget( M_player_last_polar_move, row, 2, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Body " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_player_body = new QLabel( tr( " 000.0" ), group_box );
+    M_player_body = new QLabel( tr( "   0.0" ), group_box );
     layout->addWidget( M_player_body, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Head " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_player_head = new QLabel( tr( " 000.0" ), group_box );
+    M_player_head = new QLabel( tr( "   0.0" ), group_box );
     layout->addWidget( M_player_head, row, 1, Qt::AlignRight );
     ++row;
 
+    layout->addWidget( new QLabel( tr( "PointToPos " ), group_box ),
+                       row, 0, Qt::AlignRight );
+    M_player_pointto_pos = new QLabel( tr( "      -,      -" ), group_box );
+    layout->addWidget( M_player_pointto_pos, row, 1, Qt::AlignRight );
+    ++row;
+
+    layout->addWidget( new QLabel( tr( "Focus " ), group_box ),
+                       row, 0, Qt::AlignRight );
+    M_player_focus_target = new QLabel( tr( "      -,      -" ), group_box );
+    layout->addWidget( M_player_focus_target, row, 1, Qt::AlignRight );
+    ++row;
+
     layout->addWidget( new QLabel( tr( "Stamina " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_stamina = new QLabel( tr( " 0000.0" ), group_box );
+    M_stamina = new QLabel( tr( "    0.0" ), group_box );
     layout->addWidget( M_stamina, row, 1, Qt::AlignRight );
     ++row;
 
@@ -250,71 +245,84 @@ DetailDialog::createPlayerLabels()
 
     layout->addWidget( new QLabel( tr( "Kick " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_kick_count = new QLabel( tr( " 00000" ), group_box );
+    M_kick_count = new QLabel( tr( "     0" ), group_box );
     layout->addWidget( M_kick_count, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Dash " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_dash_count = new QLabel( tr( " 00000" ), group_box );
+    M_dash_count = new QLabel( tr( "     0" ), group_box );
     layout->addWidget( M_dash_count, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Turn " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_turn_count = new QLabel( tr( " 00000" ), group_box );
+    M_turn_count = new QLabel( tr( "     0" ), group_box );
     layout->addWidget( M_turn_count, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Say " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_say_count = new QLabel( tr( " 00000" ), group_box );
+    M_say_count = new QLabel( tr( "     0" ), group_box );
     layout->addWidget( M_say_count, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "TurnNeck " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_turn_neck_count = new QLabel( tr( " 00000" ), group_box );
+    M_turn_neck_count = new QLabel( tr( "     0" ), group_box );
     layout->addWidget( M_turn_neck_count, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Catch " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_catch_count = new QLabel( tr( " 00000" ), group_box );
+    M_catch_count = new QLabel( tr( "     0" ), group_box );
     layout->addWidget( M_catch_count, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "Move " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_move_count = new QLabel( tr( " 00000" ), group_box );
+    M_move_count = new QLabel( tr( "     0" ), group_box );
     layout->addWidget( M_move_count, row, 1, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "ChbView " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_change_view_count = new QLabel( tr( " 00000" ), group_box );
+    M_change_view_count = new QLabel( tr( "     0" ), group_box );
     layout->addWidget( M_change_view_count, row, 1, Qt::AlignRight );
     ++row;
 
+    layout->addWidget( new QLabel( tr( "Tackle " ), group_box ),
+                       row, 0, Qt::AlignRight );
+    M_tackle_count = new QLabel( tr( "     0" ), group_box );
+    layout->addWidget( M_tackle_count, row, 1, Qt::AlignRight );
+    ++row;
+
+    layout->addWidget( new QLabel( tr( "PointTo " ), group_box ),
+                       row, 0, Qt::AlignRight );
+    M_pointto_count = new QLabel( tr( "     0" ), group_box );
+    layout->addWidget( M_pointto_count, row, 1, Qt::AlignRight );
+    ++row;
+
+    layout->addWidget( new QLabel( tr( "AttentionTo " ), group_box ),
+                       row, 0, Qt::AlignRight );
+    M_attentionto_count = new QLabel( tr( "     0" ), group_box );
+    layout->addWidget( M_attentionto_count, row, 1, Qt::AlignRight );
+    ++row;
+
     layout->addWidget( new QLabel( tr( "BallRelPos " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_player_ball_rel_pos = new QLabel( tr( " 000.00, 000.00" ), group_box );
+    M_player_ball_rel_pos = new QLabel( tr( "   0.00,   0.00" ), group_box );
     layout->addWidget( M_player_ball_rel_pos, row, 1, Qt::AlignRight );
-    ++row;
-
-    layout->addWidget( new QLabel( tr( "Polar " ), group_box ),
-                       row, 0, Qt::AlignRight );
-    M_player_ball_rel_polar = new QLabel( tr( " 000.00, 000.00" ), group_box );
-    layout->addWidget( M_player_ball_rel_polar, row, 1, Qt::AlignRight );
+    M_player_ball_rel_polar = new QLabel( tr( " (  0.000,    0.0)" ), group_box );
+    layout->addWidget( M_player_ball_rel_polar, row, 2, Qt::AlignRight );
     ++row;
 
     layout->addWidget( new QLabel( tr( "BallRelVel " ), group_box ),
                        row, 0, Qt::AlignRight );
-    M_player_ball_rel_vel = new QLabel( tr( " 000.00, 000.00" ), group_box );
+    M_player_ball_rel_vel = new QLabel( tr( "   0.00,   0.00" ), group_box );
     layout->addWidget( M_player_ball_rel_vel, row, 1, Qt::AlignRight );
     ++row;
 
-    //group_box->setLayout( layout ); // qt4
     return group_box;
 }
 
@@ -358,13 +366,13 @@ DetailDialog::updateLabels()
 
     const double reverse = vconf.reverseValue();
 
-    char buf[32];
+    char buf[64];
 
     // update ball
 
     const Ball & ball = view->ball();
 
-    std::snprintf( buf, 32, " %6.2f, %6.2f",
+    std::snprintf( buf, 64, " % 6.2f, % 6.2f",
                    ball.x() * reverse,
                    ball.y() * reverse );
     M_ball_pos->setText( QString::fromAscii( buf ) );
@@ -373,19 +381,19 @@ DetailDialog::updateLabels()
     {
         rcsc::Vector2D vel( ball.deltaX(), ball.deltaY() );
         vel *= reverse;
-        std::snprintf( buf, 32, " %6.2f, %6.2f",
+        std::snprintf( buf, 64, " %6.2f, %6.2f",
                        vel.x, vel.y );
 				M_ball_vel->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, " %6.3f, %6.1f",
+        std::snprintf( buf, 64, " (%7.3f, %6.1f)",
                        vel.r(), vel.th().degree() );
-				M_ball_polar_vel->setText( QString::fromAscii( buf ) );
+ 				M_ball_polar_vel->setText( QString::fromAscii( buf ) );
 		}
 
     if ( ! last_view )
     {
-        M_ball_last_move->setText( tr( "      0,      0" ) );
-        M_ball_last_polar_move->setText( tr( "      0,      0" ) );
+        M_ball_last_move->setText( tr( "   0.00,   0.00" ) );
+        M_ball_last_polar_move->setText( tr( " (  0.000,    0.0)" ) );
     }
     else
     {
@@ -393,11 +401,11 @@ DetailDialog::updateLabels()
                              ball.y() - last_view->ball().y() );
         move *= reverse;
 
-        std::snprintf( buf, 32, " %6.2f, %6.2f",
+        std::snprintf( buf, 64, " %6.2f, %6.2f",
                        move.x, move.y );
         M_ball_last_move->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, " %6.3f, %6.1f",
+        std::snprintf( buf, 64, " (%7.3f, %6.1f)",
                        move.r(), move.th().degree() );
         M_ball_last_polar_move->setText( QString::fromAscii( buf ) );
     }
@@ -416,7 +424,7 @@ DetailDialog::updateLabels()
         = M_main_data.viewHolder().playerType( player.type() );
 
     // side, number
-    std::snprintf( buf, 32, "%s     %2d",
+    std::snprintf( buf, 64, "%8s  %2d",
                    ( vconf.reverseSide()
                      ? ( number > 0 ? "   Right" : "   Left" )
                      : ( number > 0 ? "   Left" : "   Right" ) ),
@@ -424,12 +432,12 @@ DetailDialog::updateLabels()
     M_player_number->setText( QString::fromAscii( buf ) );
 
     // player type
-    std::snprintf( buf, 32, " %d" ,
+    std::snprintf( buf, 64, " %d" ,
                    player.type() );
     M_player_type->setText( QString::fromAscii( buf ) );
 
     // pos
-    std::snprintf( buf, 32, " %6.2f, %6.2f",
+    std::snprintf( buf, 64, " %6.2f, %6.2f",
                    player.x() * reverse,
                    player.y() * reverse );
 		M_player_pos->setText( QString::fromAscii( buf ) );
@@ -440,28 +448,29 @@ DetailDialog::updateLabels()
 				rcsc::Vector2D vel( player.deltaX(), player.deltaY() );
         vel *= reverse;
 
-				std::snprintf( buf, 32, " %6.2f, %6.2f",
+				std::snprintf( buf, 64, " %6.2f, %6.2f",
                        vel.x, vel.y );
 				M_player_vel->setText( QString::fromAscii( buf ) );
 
-				std::snprintf( buf, 32, " %6.3f, %6.1f",
+				std::snprintf( buf, 64, " (%7.3f, %6.1f)",
                        vel.r(), vel.th().degree() );
 				M_player_polar_vel->setText( QString::fromAscii( buf ) );
 
         // ball relative velocity
-        std::snprintf( buf, 32, " %6.2f, %6.2f",
+        std::snprintf( buf, 64, " %6.2f, %6.2f",
                        ball.deltaX() - vel.x, ball.deltaY() - vel.y );
         M_player_ball_rel_vel->setText( QString::fromAscii( buf ) );
 
+        // max turn moment
         double max_turn = player_type.effectiveTurn( 180.0, vel.r() );
-        std::snprintf( buf, 32, " %3.2f", max_turn );
+        std::snprintf( buf, 64, " %3.2f", max_turn );
         M_max_turn_moment->setText( QString::fromAscii( buf ) );
-		}
+    }
 
     if ( ! last_view )
     {
-        M_player_last_move->setText( tr( "      0,      0" ) );
-        M_player_last_polar_move->setText( tr( "      0,      0" ) );
+        M_player_last_move->setText( tr( "   0.00,   0.00" ) );
+        M_player_last_polar_move->setText( tr( "  (  0.000,    0.0)" ) );
     }
     else
     {
@@ -470,11 +479,11 @@ DetailDialog::updateLabels()
                                   player.y() - last_player.y() );
         last_move *= reverse;
 
-				std::snprintf( buf, 32, " %6.2f, %6.2f",
+				std::snprintf( buf, 64, " %6.2f, %6.2f",
                        last_move.x, last_move.y );
 				M_player_last_move->setText( QString::fromAscii( buf ) );
 
-				std::snprintf( buf, 32, " %6.3f, %6.1f",
+				std::snprintf( buf, 64, " (%7.3f, %6.1f)",
                        last_move.r(), last_move.th().degree() );
 				M_player_last_polar_move->setText( QString::fromAscii( buf ) );
     }
@@ -483,7 +492,7 @@ DetailDialog::updateLabels()
     rcsc::AngleDeg body = player.body();
     if ( vconf.reverseSide() ) body += 180.0;
 
-    std::snprintf( buf, 32," %6.1f",
+    std::snprintf( buf, 64," %6.1f",
                    body.degree() );
     M_player_body->setText( QString::fromAscii( buf ) );
 
@@ -494,23 +503,51 @@ DetailDialog::updateLabels()
         rcsc::AngleDeg head = player.head();
         if ( vconf.reverseSide() ) head += 180.0;
 
-        std::snprintf( buf, 32, " %6.1f(%6.1f)",
+        std::snprintf( buf, 64, " %6.1f(%6.1f)",
                        head.degree(), neck.degree() );
         M_player_head->setText( QString::fromAscii( buf ) );
     }
 
+    // pointto point
+    if ( player.isPointing() )
+    {
+        std::snprintf( buf, 64, " %6.2f, %6.2f",
+                       player.data().point_x_ * reverse,
+                       player.data().point_y_ * reverse );
+        M_player_pointto_pos->setText( QString::fromAscii( buf ) );
+    }
+    else
+    {
+        M_player_pointto_pos->setText( tr( "      -,      -") );
+    }
+
+    // focus target
+    if ( player.isFocusing() )
+    {
+        std::snprintf( buf, 64, " %5s %2d",
+                       ( vconf.reverseSide()
+                         ? player.data().focus_side_ == 'l' ? "Left" : "Right"
+                         : player.data().focus_side_ == 'l' ? "Right" : "Left" ),
+                       player.data().focus_unum_ );
+        M_player_focus_target->setText( QString::fromAscii( buf ) );
+    }
+    else
+    {
+        M_player_focus_target->setText( tr( " --- ") );
+    }
+
     // stamina, effort, recovery
     if ( player.hasStamina() )
     {
-        std::snprintf( buf, 32, " %6.1f",
+        std::snprintf( buf, 64, " %6.1f",
                        player.stamina() );
         M_stamina->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, " %5.3f / %5.3f",
+        std::snprintf( buf, 64, " %5.3f / %5.3f",
                        player.effort(), player_type.effortMax() );
         M_effort->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, " %5.3f / 1.0",
+        std::snprintf( buf, 64, " %5.3f / 1.0",
                        player.recovery() );
         M_recovery->setText( QString::fromAscii( buf ) );
     }
@@ -518,37 +555,49 @@ DetailDialog::updateLabels()
     // command count
     if ( player.hasCommandCount() )
     {
-        std::snprintf( buf, 32, "  %5d",
+        std::snprintf( buf, 64, "  %5d",
                        player.kickCount() );
         M_kick_count->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, "  %5d",
+        std::snprintf( buf, 64, "  %5d",
                        player.dashCount() );
         M_dash_count->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, "  %5d",
+        std::snprintf( buf, 64, "  %5d",
                        player.turnCount() );
         M_turn_count->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, "  %5d",
+        std::snprintf( buf, 64, "  %5d",
                        player.sayCount() );
         M_say_count->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, "  %5d",
+        std::snprintf( buf, 64, "  %5d",
                        player.turnNeckCount() );
         M_turn_neck_count->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, "  %5d",
+        std::snprintf( buf, 64, "  %5d",
                        player.catchCount() );
         M_catch_count->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, "  %5d",
+        std::snprintf( buf, 64, "  %5d",
                        player.moveCount() );
         M_move_count->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, "  %5d",
+        std::snprintf( buf, 64, "  %5d",
                        player.changeViewCount() );
         M_change_view_count->setText( QString::fromAscii( buf ) );
+
+        std::snprintf( buf, 64, "  %5d",
+                       player.tackleCount() );
+        M_tackle_count->setText( QString::fromAscii( buf ) );
+
+        std::snprintf( buf, 64, "  %5d",
+                       player.pointtoCount() );
+        M_pointto_count->setText( QString::fromAscii( buf ) );
+
+        std::snprintf( buf, 64, "  %5d",
+                       player.attentiontoCount() );
+        M_attentionto_count->setText( QString::fromAscii( buf ) );
     }
 
     // ball related info
@@ -557,11 +606,11 @@ DetailDialog::updateLabels()
                                        ball.y() - player.y() );
         player_to_ball *= reverse;
 
-        std::snprintf( buf, 32, " %6.2f, %6.2f",
+        std::snprintf( buf, 64, " %6.2f, %6.2f",
                        player_to_ball.x, player_to_ball.y );
         M_player_ball_rel_pos->setText( QString::fromAscii( buf ) );
 
-        std::snprintf( buf, 32, "%7.3f, %6.1f",
+        std::snprintf( buf, 64, " (%7.3f, %6.1f)",
                        player_to_ball.r(), player_to_ball.th().degree() );
         M_player_ball_rel_polar->setText( QString::fromAscii( buf ) );
     }
