@@ -78,6 +78,10 @@ private:
     QLabel * M_effort;
     QLabel * M_recovery;
 
+    QLabel * M_player_pointto_pos;
+
+    QLabel * M_player_focus_target;
+
     QLabel * M_kick_count;
     QLabel * M_dash_count;
     QLabel * M_turn_count;
@@ -86,6 +90,9 @@ private:
     QLabel * M_catch_count;
     QLabel * M_move_count;
     QLabel * M_change_view_count;
+    QLabel * M_tackle_count;
+    QLabel * M_pointto_count;
+    QLabel * M_attentionto_count;
 
     QLabel * M_player_ball_rel_pos;
     QLabel * M_player_ball_rel_polar;
