@@ -70,6 +70,7 @@ const QColor DrawConfig::COLLIDE_BALL_COLOR = QColor( 5, 255, 255 );
 const QColor DrawConfig::COLLIDE_PLAYER_COLOR = QColor( 105, 185, 255 );
 const QColor DrawConfig::TACKLE_COLOR = QColor( 255, 136, 127 );
 const QColor DrawConfig::TACKLE_FAULT_COLOR = QColor( 79, 159, 159 );
+const QColor DrawConfig::POINTTO_COLOR = QColor( 255, 136, 127 );
 const QColor DrawConfig::MEASURE_COLOR = QColor( 0, 255, 255 );
 const QColor DrawConfig::MEASURE_FONT_COLOR = QColor( 255, 191, 191 );
 const QColor DrawConfig::DEBUG_BALL_COLOR = QColor( 255, 0, 127 );
@@ -81,6 +82,7 @@ const QColor DrawConfig::DEBUG_UNKNOWN_OPPONENT_COLOR = QColor( 127, 95, 255 );
 const QColor DrawConfig::DEBUG_UNKNOWN_PLAYER_COLOR = QColor( 191, 191, 191 );
 const QColor DrawConfig::DEBUG_COMMENT_FONT_COLOR = QColor( 191, 191, 191 );
 const QColor DrawConfig::DEBUG_MESSAGE_FONT_COLOR = QColor( 255, 255, 255 );
+const QColor DrawConfig::DEBUG_TARGET_COLOR = QColor( 255, 127, 0 );
 const QColor DrawConfig::DEBUG_LOG_MESSAGE_FONT_COLOR = QColor( 0, 0, 0 );
 const QColor DrawConfig::DEBUG_FIGURE_COLOR = QColor( 255, 127, 0 );
 
@@ -131,6 +133,7 @@ DrawConfig::DrawConfig()
     , M_tackle_pen( TACKLE_COLOR, 2, Qt::SolidLine )
     , M_tackle_brush( TACKLE_COLOR, Qt::SolidPattern )
     , M_tackle_fault_brush( TACKLE_FAULT_COLOR, Qt::SolidPattern )
+    , M_pointto_pen( POINTTO_COLOR, 1, Qt::SolidLine )
     , M_kick_accel_pen( QColor( 0, 255, 0 ), 0, Qt::SolidLine )
     , M_tackle_area_pen( TACKLE_COLOR, 0, Qt::SolidLine )
     , M_measure_pen( MEASURE_COLOR, 1, Qt::SolidLine )
@@ -147,7 +150,7 @@ DrawConfig::DrawConfig()
     , M_debug_unknown_teammate_brush( DEBUG_UNKNOWN_TEAMMATE_COLOR, Qt::SolidPattern )
     , M_debug_unknown_opponent_brush( DEBUG_UNKNOWN_OPPONENT_COLOR, Qt::SolidPattern )
     , M_debug_unknown_player_brush( DEBUG_UNKNOWN_PLAYER_COLOR, Qt::SolidPattern )
-    , M_debug_target_pen( DEBUG_SELF_COLOR, 2, Qt::SolidLine )
+    , M_debug_target_pen( DEBUG_TARGET_COLOR, 2, Qt::SolidLine )
     , M_debug_comment_font( "Sans Serif", 10 )
     , M_debug_comment_font_pen( DEBUG_COMMENT_FONT_COLOR, 0, Qt::SolidLine )
     , M_debug_message_font( "Sans Serif", 14 )
@@ -157,7 +160,7 @@ DrawConfig::DrawConfig()
     , M_debug_figure_pen( DEBUG_FIGURE_COLOR, 1, Qt::SolidLine )
 {
     //std::cerr << "create DrawConfig" << std::endl;
-    loadSettings();
+    readSettings();
 
     for ( int i = 0; i < 256; ++i )
     {
@@ -220,6 +223,7 @@ DrawConfig::setDefaultColors()
     M_tackle_pen.setColor( TACKLE_COLOR );
     M_tackle_brush.setColor( TACKLE_COLOR );
     M_tackle_fault_brush.setColor( TACKLE_FAULT_COLOR );
+    M_pointto_pen.setColor( POINTTO_COLOR );
     M_kick_accel_pen.setColor( QColor( 0, 255, 0 ) );
     M_tackle_area_pen.setColor( TACKLE_COLOR );
     M_measure_pen.setColor( MEASURE_COLOR );
@@ -235,7 +239,7 @@ DrawConfig::setDefaultColors()
     M_debug_unknown_teammate_brush.setColor( DEBUG_UNKNOWN_TEAMMATE_COLOR );
     M_debug_unknown_opponent_brush.setColor( DEBUG_UNKNOWN_OPPONENT_COLOR );
     M_debug_unknown_player_brush.setColor( DEBUG_UNKNOWN_PLAYER_COLOR );
-    M_debug_target_pen.setColor( DEBUG_SELF_COLOR );
+    M_debug_target_pen.setColor( DEBUG_TARGET_COLOR );
     M_debug_comment_font_pen.setColor( DEBUG_COMMENT_FONT_COLOR );
     M_debug_message_font_pen.setColor( DEBUG_MESSAGE_FONT_COLOR );
     M_debug_log_message_font_pen.setColor( DEBUG_LOG_MESSAGE_FONT_COLOR );
@@ -274,10 +278,10 @@ DrawConfig::setDefaultFonts()
 
 /*-------------------------------------------------------------------*/
 /*!
-  load configuration from file.
+  read configuration from file.
 */
 void
-DrawConfig::loadSettings()
+DrawConfig::readSettings()
 {
     QSettings settings( QSettings::Ini );
     settings.insertSearchPath( QSettings::Unix,
@@ -322,212 +326,230 @@ DrawConfig::loadSettings()
 
     // color
 
-    // score boar
+    // score board
     val = settings.readEntry( "score_board_color" );
     if ( ! val.isEmpty() )
     {
         M_score_board_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
+
     val = settings.readEntry( "score_board_font_color" );
     if ( ! val.isEmpty() )
     {
         M_score_board_font_pen.setColor( val );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     // field
     val = settings.readEntry( "field_color" );
     if ( ! val.isEmpty() )
     {
         M_field_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "field_dark_color" );
     if ( ! val.isEmpty() )
     {
         M_field_dark_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "line_color" );
     if ( ! val.isEmpty() )
     {
         M_line_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     // ball
     val = settings.readEntry( "ball_pen_color" );
     if ( ! val.isEmpty() )
     {
         M_ball_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "ball_color" );
     if ( ! val.isEmpty() )
     {
         M_ball_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
+
     val = settings.readEntry( "ball_font_color" );
     if ( ! val.isEmpty() )
     {
         M_ball_font_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     // player body
     val = settings.readEntry( "player_pen_color" );
     if ( ! val.isEmpty() )
     {
         M_player_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "real_body_pen_color" );
     if ( ! val.isEmpty() )
     {
         M_real_body_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "left_team_color" );
     if ( ! val.isEmpty() )
     {
         M_left_team_pen.setColor( toColor( val ) );
         M_left_team_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "left_goalie_color" );
     if ( ! val.isEmpty() )
     {
         M_left_goalie_pen.setColor( toColor( val ) );
         M_left_goalie_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "right_team_color" );
     if ( ! val.isEmpty() )
     {
         M_right_team_pen.setColor( toColor( val ) );
         M_right_team_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "right_goalie_color" );
     if ( ! val.isEmpty() )
     {
         M_right_goalie_pen.setColor( toColor( val ) );
         M_right_goalie_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "player_number_font_color" );
     if ( ! val.isEmpty() )
     {
         M_player_number_font_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "player_stamina_font_color" );
     if ( ! val.isEmpty() )
     {
         M_player_stamina_font_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "player_detail_font_color" );
     if ( ! val.isEmpty() )
     {
         M_player_detail_font_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "selected_player_font_color" );
     if ( ! val.isEmpty() )
     {
         M_selected_player_font_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     // player pen
     val = settings.readEntry( "effort_decayed_pen_color" );
     if ( ! val.isEmpty() )
     {
         M_effort_decayed_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "recovery_decayed_pen_color" );
     if ( ! val.isEmpty() )
     {
         M_recovery_decayed_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "view_cone_pen_color" );
     if ( ! val.isEmpty() )
     {
         M_view_cone_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "view_area_pen_color" );
     if ( ! val.isEmpty() )
     {
         M_view_area_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     // player status
     val = settings.readEntry( "kick_pen_color" );
     if ( ! val.isEmpty() )
     {
         M_kick_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "kick_fault_color" );
     if ( ! val.isEmpty() )
     {
         M_kick_fault_pen.setColor( toColor( val ) );
         M_kick_fault_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "catch_color" );
     if ( ! val.isEmpty() )
     {
         M_catch_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "catch_fault_color" );
     if ( ! val.isEmpty() )
     {
         M_catch_fault_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "collide_ball_color" );
     if ( ! val.isEmpty() )
     {
         M_collide_ball_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "collide_player_color" );
     if ( ! val.isEmpty() )
     {
         M_collide_player_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "tackle_color" );
     if ( ! val.isEmpty() )
     {
         M_tackle_pen.setColor( toColor( val ) );
         M_tackle_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
+
     val = settings.readEntry( "tackle_area_color" );
     if ( ! val.isEmpty() )
     {
         M_tackle_area_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
+
     val = settings.readEntry( "tackle_fault_color" );
     if ( ! val.isEmpty() )
     {
         M_tackle_fault_brush.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
+    val = settings.readEntry( "pointto_color" );
+    if ( ! val.isEmpty() )
+    {
+        M_pointto_pen.setColor( toColor( val ) );
+    }
+
+    val = settings.readEntry( "kick_accel_color" );
+    if ( ! val.isEmpty() )
+    {
+        M_kick_accel_pen.setColor( toColor( val ) );
+    }
+
+    // measure
     val = settings.readEntry( "measure_color" );
     if ( ! val.isEmpty() )
     {
         M_measure_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
     val = settings.readEntry( "measure_font_color" );
     if ( ! val.isEmpty() )
     {
         M_measure_font_pen.setColor( toColor( val ) );
-    } //else { std::cerr << "load error" << __LINE__ << std::endl; }
+    }
 
+    // debug view
     val = settings.readEntry( "debug_teammate_color" );
     if ( ! val.isEmpty() )
     {
@@ -576,6 +598,7 @@ DrawConfig::loadSettings()
         M_debug_message_font_pen.setColor( toColor( val ) );
     }
 
+    // debug log
     val = settings.readEntry( "debug_log_message_font_color" );
     if ( ! val.isEmpty() )
     {
@@ -689,6 +712,10 @@ DrawConfig::saveSettings()
                          toString( tackleAreaPen().color() ) );
     settings.writeEntry( "tackle_fault_color",
                          toString( tackleFaultBrush().color() ) );
+    settings.writeEntry( "pointto_color",
+                         toString( pointtoPen().color() ) );
+    settings.writeEntry( "kick_accel_color",
+                         toString( kickAccelPen().color() ) );
 
     settings.writeEntry( "measure_color",
                          toString( measurePen().color() ) );
