@@ -38,10 +38,6 @@
 #include <qpen.h>
 #include <qstring.h>
 
-#include <rcsc/types.h>
-#include <iostream>
-#include <cmath>
-
 //! draw object configuration manager class
 class DrawConfig {
 public:
@@ -78,6 +74,7 @@ public:
     static const QColor COLLIDE_PLAYER_COLOR;
     static const QColor TACKLE_COLOR;
     static const QColor TACKLE_FAULT_COLOR;
+    static const QColor POINTTO_COLOR;
     static const QColor MEASURE_COLOR;
     static const QColor MEASURE_FONT_COLOR;
     static const QColor DEBUG_BALL_COLOR;
@@ -89,6 +86,7 @@ public:
     static const QColor DEBUG_UNKNOWN_PLAYER_COLOR;
     static const QColor DEBUG_COMMENT_FONT_COLOR;
     static const QColor DEBUG_MESSAGE_FONT_COLOR;
+    static const QColor DEBUG_TARGET_COLOR;
     static const QColor DEBUG_LOG_MESSAGE_FONT_COLOR;
     static const QColor DEBUG_FIGURE_COLOR;
 
@@ -189,6 +187,7 @@ private:
     QPen M_tackle_pen; //!< edge pen when tackling
     QBrush M_tackle_brush; //!< body paint brush when tackling
     QBrush M_tackle_fault_brush; //!< body paint brush when tackle fault
+    QPen M_pointto_pen; //!< pointto painting
 
     //! kick accel info pen
     QPen M_kick_accel_pen;
@@ -262,7 +261,7 @@ public:
 
     //--------------------------------------------------
     //! load configuration from file.
-    void loadSettings();
+    void readSettings();
     //! save configuration to file.
     void saveSettings();
 
@@ -697,6 +696,16 @@ public:
           return M_tackle_fault_brush;
       }
 
+    QPen * pointtoPenPtr()
+      {
+          return &M_pointto_pen;
+      }
+    const
+    QPen & pointtoPen() const
+      {
+          return M_pointto_pen;
+      }
+
     QPen * kickAccelPenPtr()
       {
           return &M_kick_accel_pen;
