@@ -49,6 +49,12 @@
 #include "voronoi_diagram_painter.h"
 #include "debug_painter.h"
 #include "debug_log_painter.h"
+#include "team_graphic_painter.h"
+
+#include "ball_painter_rcss.h"
+#include "player_painter_rcss.h"
+#include "score_board_painter_rcss.h"
+
 // model
 #include "main_data.h"
 #include "app_config.h"
@@ -61,7 +67,7 @@
 #include <cassert>
 
 namespace {
-int cursor_timeout = 1000;
+int cursor_timeout = 5000;
 }
 
 /*-------------------------------------------------------------------*/
@@ -76,9 +82,10 @@ FieldCanvas::FieldCanvas( MainData & main_data,
     , M_system_menu( static_cast< QPopupMenu * >( 0 ) )
     , M_monitor_menu( static_cast< QPopupMenu * >( 0 ) )
     , M_cursor_timer( new QTimer( this ) )
+    , M_draw_type( -1 )
 {
-    //this->setPalette( M_main_data.drawConfig().fieldBrush().color() );
-    //this->setAutoFillBackground( true );
+    //this->setPalette( DrawConfig::instance().fieldBrush().color() );
+    this->setPaletteBackgroundColor( DrawConfig::instance().fieldBrush().color() );
 
     // need for the MouseMoveEvent
     this->setMouseTracking( true );
@@ -86,36 +93,12 @@ FieldCanvas::FieldCanvas( MainData & main_data,
     //this->setFocusPolicy( QWidget::StrongFocus );
     this->setFocusPolicy( QWidget::WheelFocus );
 
-    // paint directory
-    //this->setAttribute( Qt::WA_PaintOnScreen );
-    M_field_painter
-        = boost::shared_ptr< FieldPainter >
-        ( new FieldPainter( M_main_data.viewConfig() ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new BallTracePainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new PlayerTracePainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new PlayerPainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new BallPainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new OffsideLinePainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new PlayerControlPainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new VoronoiDiagramPainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new DebugPainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new DebugLogPainter( M_main_data ) ) );
-    M_painters.push_back( boost::shared_ptr< PainterInterface >
-                          ( new ScoreBoardPainter( M_main_data ) ) );
+    createPainters();
 
     M_canvas_pixmap.resize( this->size() );
 
-    //connect( M_cursor_timer, SIGNAL( timeout() ),
-    //         this, SLOT( hideCursor() ) );
+    connect( M_cursor_timer, SIGNAL( timeout() ),
+             this, SLOT( hideCursor() ) );
 }
 
 /*-------------------------------------------------------------------*/
@@ -130,6 +113,87 @@ FieldCanvas::~FieldCanvas()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+FieldCanvas::createPainters()
+{
+    ViewConfig::DrawType draw_type = M_main_data.viewConfig().drawType();
+    if ( M_draw_type == static_cast< int >( draw_type ) )
+    {
+        return;
+    }
+
+    M_draw_type = static_cast< int >( draw_type );
+    M_painters.clear();
+
+    if ( draw_type == ViewConfig::DRAW_RCSSMONITOR )
+    {
+        M_field_painter
+            = boost::shared_ptr< FieldPainter >
+            ( new FieldPainter( M_main_data.viewConfig() ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new TeamGraphicPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new BallTracePainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new PlayerTracePainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new PlayerPainterRCSS( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new BallPainterRCSS( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new OffsideLinePainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new PlayerControlPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new VoronoiDiagramPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new DebugPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new DebugLogPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new ScoreBoardPainterRCSS( M_main_data ) ) );
+        return;
+    }
+
+    if ( draw_type != ViewConfig::DRAW_DEFAULT )
+    {
+        std::cerr << "***WARNING*** Unsupported draw type id=" << draw_type
+                  << std::endl;
+    }
+
+    {
+        M_field_painter
+            = boost::shared_ptr< FieldPainter >
+            ( new FieldPainter( M_main_data.viewConfig() ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new TeamGraphicPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new BallTracePainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new PlayerTracePainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new PlayerPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new BallPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new OffsideLinePainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new PlayerControlPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new VoronoiDiagramPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new DebugPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new DebugLogPainter( M_main_data ) ) );
+        M_painters.push_back( boost::shared_ptr< PainterInterface >
+                              ( new ScoreBoardPainter( M_main_data ) ) );
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 FieldCanvas::setNormalMenu( QPopupMenu * menu )
@@ -183,27 +247,25 @@ void
 FieldCanvas::paintEvent( QPaintEvent * event )
 {
     QWidget::paintEvent( event );
-#if 1
+
     if ( M_canvas_pixmap.isNull()
          || M_canvas_pixmap.size() != this->size() )
     {
         M_canvas_pixmap.resize( this->size() );
     }
-#else
-    QRect rect = event->rect();
-    QSize new_size = rect.size().expandedTo( M_canvas_pixmap.size() );
-    M_canvas_pixmap.resize( new_size );
-    M_canvas_pixmap.fill( this, rect.topLeft() );
-#endif
+
     M_main_data.update( this->width(),
                         this->height() );
 
     QPainter painter;
     painter.begin( &M_canvas_pixmap, this );
 
-    //M_canvas_pixmap.fill( this, 0, 0 );
-    //painter.translate( this->width(), 0 );
-    //painter.rotate( 90.0 );
+#if 0
+    //M_canvas_pixmap.fill( DrawConfig::instance().fieldBrush().color() );
+    painter.translate( this->width()/2, this->height()/2 );
+    painter.rotate( -90.0 );
+    painter.translate( - this->width()/2, - this->height()/2 );
+#endif
 
     draw( painter );
 
@@ -213,6 +275,11 @@ FieldCanvas::paintEvent( QPaintEvent * event )
         drawMouseMeasure( painter );
     }
 
+    if ( ! M_player_dragged_point.isNull() )
+    {
+        drawDraggedPlayer( painter );
+    }
+
     painter.end();
 #if 1
     bitBlt( this, 0, 0,
@@ -237,7 +304,10 @@ FieldCanvas::mouseDoubleClickEvent( QMouseEvent * event )
         emit focusChanged( event->pos() );
     }
 
-    //M_cursor_timer->start( cursor_timeout, true ); // single shot
+    if ( M_main_data.viewConfig().cursorHide() )
+    {
+        M_cursor_timer->start( cursor_timeout, true ); // single shot
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -262,6 +332,10 @@ FieldCanvas::mousePressEvent( QMouseEvent * event )
         {
             M_measure_ball_speed_point = event->pos();
         }
+        else if ( M_main_data.trainerData().dragMode() )
+        {
+            grabPlayer( event->pos() );
+        }
     }
     else if ( event->button() == Qt::MidButton )
     {
@@ -277,17 +351,21 @@ FieldCanvas::mousePressEvent( QMouseEvent * event )
 
         M_mouse_state[2].pressed( event->pos() );
         M_measure_ball_speed_point = event->pos();
+
+        if ( M_main_data.trainerData().dragMode()
+                  && M_main_data.trainerData().isPlayerDragged() )
+        {
+            M_mouse_state[2].setMenuFailed( true );
+            M_player_dragged_point = QPoint();
+            M_main_data.getTrainerData().unsetDrag();
+        }
     }
 
-//     if ( event->button() == Qt::RightButton )
-//     {
-//         this->setCursor( QCursor( Qt::CrossCursor ) );
-//     }
-//     else //if ( this->cursor().shape() != Qt::ArrowCursor )
-//     {
-//         //this->setCursor( QCursor( Qt::ArrowCursor ) );
-//         this->unsetCursor();
-//     }
+
+    if ( M_main_data.viewConfig().cursorHide() )
+    {
+        M_cursor_timer->stop();
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -318,6 +396,14 @@ FieldCanvas::mouseReleaseEvent( QMouseEvent * event )
                 }
             }
         }
+        else
+        {
+            if ( M_main_data.trainerData().isPlayerDragged() )
+            {
+                M_player_dragged_point = QPoint(); // set Null
+                emit playerMoved( event->pos() );
+            }
+        }
     }
     else if ( event->button() == Qt::MidButton )
     {
@@ -352,7 +438,10 @@ FieldCanvas::mouseReleaseEvent( QMouseEvent * event )
         }
     }
 
-    //M_cursor_timer->start( cursor_timeout, true ); // single shot
+    if ( M_main_data.viewConfig().cursorHide() )
+    {
+        M_cursor_timer->start( cursor_timeout, true ); // single shot
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -362,18 +451,31 @@ FieldCanvas::mouseReleaseEvent( QMouseEvent * event )
 void
 FieldCanvas::mouseMoveEvent( QMouseEvent * event )
 {
-    if ( M_mouse_state[0].isDragged() )
+    if ( this->cursor().shape() == Qt::BlankCursor )
     {
-        if ( this->cursor().shape() != Qt::SizeAllCursor )
-        {
-            this->setCursor( QCursor( Qt::SizeAllCursor ) );
-        }
+        this->unsetCursor();
+    }
 
-        int new_x = M_main_data.viewConfig().screenX( M_main_data.viewConfig().focusPoint().x );
-        int new_y = M_main_data.viewConfig().screenY( M_main_data.viewConfig().focusPoint().y );
-        new_x -= ( event->pos().x() - M_mouse_state[0].draggedPoint().x() );
-        new_y -= ( event->pos().y() - M_mouse_state[0].draggedPoint().y() );
-        emit focusChanged( QPoint( new_x, new_y ) );
+    //if ( M_mouse_state[0].isDragged() )
+    if ( event->state() & Qt::LeftButton )
+    {
+        if ( M_main_data.trainerData().isPlayerDragged() )
+        {
+            dragPlayer( event->pos() );
+        }
+        else
+        {
+            if ( this->cursor().shape() != Qt::SizeAllCursor )
+            {
+                this->setCursor( QCursor( Qt::SizeAllCursor ) );
+            }
+
+            int new_x = M_main_data.viewConfig().absScreenX( M_main_data.viewConfig().focusPoint().x );
+            int new_y = M_main_data.viewConfig().absScreenY( M_main_data.viewConfig().focusPoint().y );
+            new_x -= ( event->pos().x() - M_mouse_state[0].draggedPoint().x() );
+            new_y -= ( event->pos().y() - M_mouse_state[0].draggedPoint().y() );
+            emit focusChanged( QPoint( new_x, new_y ) );
+        }
     }
 
     for ( int i = 0; i < 3; ++i )
@@ -381,7 +483,8 @@ FieldCanvas::mouseMoveEvent( QMouseEvent * event )
         M_mouse_state[i].moved( event->pos() );
     }
 
-    if ( M_mouse_state[2].isDragged() )
+    //if ( M_mouse_state[2].isDragged() )
+    if ( event->state() & Qt::RightButton )
     {
         if ( this->cursor().shape() != Qt::CrossCursor )
         {
@@ -408,26 +511,19 @@ FieldCanvas::mouseMoveEvent( QMouseEvent * event )
 #endif
     }
 
-    //     if ( M_mouse_state[2].isPressed() )
-    //     {
-
-    //     }
-    //     else if ( this->cursor().shape() != Qt::ArrowCursor )
-    //     {
-    //         //        this->setCursor( QCursor( Qt::ArrowCursor ) );
-    //         this->unsetCursor();
-    //     }
-
-    //     if ( M_mouse_state[0].isPressed()
-    //          || M_mouse_state[1].isPressed()
-    //          || M_mouse_state[2].isPressed() )
-    //     {
-    //         M_cursor_timer->stop();
-    //     }
-    //     else
-    //     {
-    //         M_cursor_timer->start( cursor_timeout, true ); // single shot
-    //     }
+    if ( M_main_data.viewConfig().cursorHide() )
+    {
+        if ( M_mouse_state[0].isPressed()
+             || M_mouse_state[1].isPressed()
+             || M_mouse_state[2].isPressed() )
+        {
+            M_cursor_timer->stop();
+        }
+        else
+        {
+            M_cursor_timer->start( cursor_timeout, true ); // single shot
+        }
+    }
 
     emit mouseMoved( event->pos() );
 }
@@ -439,12 +535,7 @@ FieldCanvas::mouseMoveEvent( QMouseEvent * event )
 void
 FieldCanvas::draw( QPainter & painter )
 {
-    if ( DrawConfig::instance().scoreBoardFont().pointSize()
-         != M_main_data.viewConfig().scoreBoardFontSize() )
-    {
-        DrawConfig::instance().resizeScoreBoardFont
-            ( M_main_data.viewConfig().scoreBoardFontSize() );
-    }
+    createPainters();
 
     M_field_painter->draw( painter );
 
@@ -530,8 +621,8 @@ FieldCanvas::drawMouseMeasure( QPainter & painter )
                         start_point.y() - 2 );
         while ( total_travel < max_length )
         {
-            QPoint pt( vconf.screenX( ball_pos.x ) - 1,
-                       vconf.screenY( ball_pos.y ) - 1 );
+            QPoint pt( vconf.absScreenX( ball_pos.x ) - 1,
+                       vconf.absScreenY( ball_pos.y ) - 1 );
             if ( std::abs( pt.x() - last_pt.x() ) < 1
                  && std::abs( pt.y() - last_pt.y() ) < 1 )
             {
@@ -595,6 +686,162 @@ FieldCanvas::drawMouseMeasure( QPainter & painter )
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+FieldCanvas::drawDraggedPlayer( QPainter & painter )
+{
+    const TrainerData & data = M_main_data.trainerData();
+
+    if ( M_player_dragged_point.isNull()
+         || ! data.isPlayerDragged() )
+    {
+        return;
+    }
+
+    const ViewConfig & vconf = M_main_data.viewConfig();
+
+    MonitorViewConstPtr view = M_main_data.getViewData( M_main_data.viewIndex() );
+
+    if ( ! view )
+    {
+        std::cerr << "drawDraggedPlayer no view data" << std::endl;
+        return;
+    }
+
+    int index = data.draggedPlayerNumber() - 1;
+    if ( data.draggedPlayerSide() == rcsc::RIGHT )
+    {
+        index += 11;
+    }
+
+    if ( index < 0 || 21 < index )
+    {
+        std::cerr << "drawDraggedPlaeyr. Illegal index = " << index
+                  << std::endl;
+        return;
+    }
+
+    const Player & player = view->players()[index];
+    const rcsc::PlayerType & type = M_main_data.viewHolder().playerType( player.type() );
+
+    int draw_radius = vconf.scale( type.kickableArea() );
+
+    const DrawConfig & dconf = DrawConfig::instance();
+
+    painter.setPen( dconf.playerPen() );
+    painter.setBrush( dconf.transparentBrush() );
+
+    painter.drawEllipse( M_player_dragged_point.x() - draw_radius,
+                         M_player_dragged_point.y() - draw_radius,
+                         draw_radius * 2,
+                         draw_radius * 2 );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FieldCanvas::grabPlayer( const QPoint & point )
+{
+    MonitorViewConstPtr view = M_main_data.getViewData( M_main_data.viewIndex() );
+    if ( ! view )
+    {
+        return;
+    }
+
+    const ViewConfig & vconf = M_main_data.viewConfig();
+
+    const rcsc::Vector2D field_pos( vconf.fieldX( point.x() ),
+                                    vconf.fieldY( point.y() ) );
+
+    int player_index = -1;
+    double min_dist = 100000.0;
+    const std::vector< Player >::const_iterator end = view->players().end();
+    int index = 0;
+    for ( std::vector< Player >::const_iterator p = view->players().begin();
+          p != end;
+          ++p, ++index )
+    {
+        double size = ( vconf.playerSize() > 0.0
+                        ? vconf.playerSize()
+                        : M_main_data.viewHolder().playerType( p->type() ).kickableArea() );
+
+        rcsc::Vector2D ppos( p->x(), p->y() );
+        if ( vconf.reverseSide() ) ppos *= -1.0;
+
+        double dist = field_pos.dist( ppos );
+        if ( dist < size
+             && dist < min_dist )
+        {
+            min_dist = dist;
+            player_index = index;
+        }
+    }
+
+    if ( player_index < 0 )
+    {
+        M_main_data.getTrainerData().unsetDrag();
+        return;
+    }
+
+    rcsc::SideID side = ( player_index >= 11
+                          ? rcsc::RIGHT
+                          : rcsc::LEFT );
+    int unum = ( player_index >= 11
+                 ? player_index - 11 + 1
+                 : player_index + 1 );
+
+    M_main_data.getTrainerData().setDrag( side, unum );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+FieldCanvas::dragPlayer( const QPoint & point )
+{
+    static QRect s_last_rect;
+
+    const TrainerData & data = M_main_data.trainerData();
+
+    if ( ! data.isPlayerDragged() )
+    {
+        M_player_dragged_point = QPoint();
+        M_main_data.getTrainerData().unsetDrag();
+        return;
+    }
+
+    M_player_dragged_point = point;
+
+    const ViewConfig & vconf = M_main_data.viewConfig();
+
+    const rcsc::Vector2D field_pos( vconf.fieldX( point.x() ),
+                                    vconf.fieldY( point.y() ) );
+
+    M_main_data.getTrainerData().setPlayer( data.draggedPlayerSide(),
+                                            data.draggedPlayerNumber(),
+                                            field_pos,
+                                            0.0 );
+
+    // calculate an update area
+    int player_size = ( vconf.playerSize() > 0.0
+                        ? vconf.scale( vconf.playerSize() + 0.3 )
+                        : vconf.scale( rcsc::ServerParam::i().defaultKickableArea() + 0.3 ) );
+
+    QRect new_rect( point.x() - player_size,
+                    point.y() - player_size,
+                    player_size * 2,
+                    player_size * 2 );
+
+    this->update( s_last_rect.unite( new_rect ) );
+    s_last_rect = new_rect;
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 FieldCanvas::dropBall()
