@@ -75,10 +75,13 @@ private:
 
     QPixmap M_canvas_pixmap;
 
+    int M_draw_type;
     boost::shared_ptr< FieldPainter > M_field_painter;
 
     std::vector< boost::shared_ptr< PainterInterface > > M_painters;
 
+    QPoint M_player_dragged_point;
+
     // not used
     FieldCanvas( const FieldCanvas & );
     const FieldCanvas & operator=( const FieldCanvas & );
@@ -91,6 +94,10 @@ public:
 
     ~FieldCanvas();
 
+    void createPainters();
+
+public:
+
     void setNormalMenu( QPopupMenu * menu );
     void setSystemMenu( QPopupMenu * menu );
     void setMonitorMenu( QPopupMenu * menu );
@@ -99,7 +106,13 @@ public:
 
 private:
 
+    void drawTeamGraphic( QPainter & painter );
+
     void drawMouseMeasure( QPainter & painter );
+    void drawDraggedPlayer( QPainter & painter );
+
+    void grabPlayer( const QPoint & point );
+    void dragPlayer( const QPoint & point );
 
 protected:
 
@@ -126,6 +139,8 @@ signals:
     void freeKickLeft( const QPoint & pos );
     void freeKickRight( const QPoint & pos );
 
+    void playerMoved( const QPoint & point );
+
     void focusChanged( const QPoint & point );
     void mouseMoved( const QPoint & point );
 
