@@ -47,7 +47,7 @@
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 FieldPainter::FieldPainter( const ViewConfig & conf )
     : M_conf( conf )
 {
@@ -57,7 +57,7 @@ FieldPainter::FieldPainter( const ViewConfig & conf )
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::draw( QPainter & painter )
 {
@@ -66,16 +66,22 @@ FieldPainter::draw( QPainter & painter )
     drawPenaltyAreaLines( painter );
     drawGoalAreaLines( painter );
     drawGoals( painter );
+
     if ( M_conf.isShownFlags() )
     {
         drawFlags( painter );
     }
+
+    if ( M_conf.gridStep() > 0 )
+    {
+        drawGrid( painter );
+    }
 }
 
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::drawBackGround( QPainter & painter ) const
 {
@@ -97,7 +103,7 @@ FieldPainter::drawBackGround( QPainter & painter ) const
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::drawLinesGrass( QPainter & painter ) const
 {
@@ -151,7 +157,7 @@ FieldPainter::drawLinesGrass( QPainter & painter ) const
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::drawCheckerGrass( QPainter & painter )const
 {
@@ -249,7 +255,7 @@ FieldPainter::drawCheckerGrass( QPainter & painter )const
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::drawLines( QPainter & painter ) const
 {
@@ -260,10 +266,10 @@ FieldPainter::drawLines( QPainter & painter ) const
     painter.setBrush( dconf.transparentBrush() );
 
     // set screen coordinates of field
-    int left_x   = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength() );
-    int right_x  = M_conf.screenX( + rcsc::ServerParam::i().pitchHalfLength() );
-    int top_y    = M_conf.screenY( - rcsc::ServerParam::i().pitchHalfWidth() );
-    int bottom_y = M_conf.screenY( + rcsc::ServerParam::i().pitchHalfWidth() );
+    int left_x   = M_conf.absScreenX( - rcsc::ServerParam::i().pitchHalfLength() );
+    int right_x  = M_conf.absScreenX( + rcsc::ServerParam::i().pitchHalfLength() );
+    int top_y    = M_conf.absScreenY( - rcsc::ServerParam::i().pitchHalfWidth() );
+    int bottom_y = M_conf.absScreenY( + rcsc::ServerParam::i().pitchHalfWidth() );
 
     // side lines & goal lines
     painter.drawLine( left_x, top_y, right_x, top_y );
@@ -275,8 +281,8 @@ FieldPainter::drawLines( QPainter & painter ) const
          || rcsc::ServerParam::i().keepawayMode() )
     {
         // keepaway area
-        int ka_left = M_conf.screenX( - rcsc::ServerParam::i().keepawayLength() * 0.5 );
-        int ka_top = M_conf.screenY( - rcsc::ServerParam::i().keepawayWidth() * 0.5 );
+        int ka_left = M_conf.absScreenX( - rcsc::ServerParam::i().keepawayLength() * 0.5 );
+        int ka_top = M_conf.absScreenY( - rcsc::ServerParam::i().keepawayWidth() * 0.5 );
         int ka_width = M_conf.scale( rcsc::ServerParam::i().keepawayWidth() );
         int ka_length = M_conf.scale( rcsc::ServerParam::i().keepawayWidth() );
 
@@ -295,12 +301,26 @@ FieldPainter::drawLines( QPainter & painter ) const
                              center_radius * 2,
                              center_radius * 2 );
     }
+
+    // corner arc
+    {
+        int r = M_conf.scale( rcsc::ServerParam::i().cornerArcR() );
+
+        painter.drawArc( left_x - r, top_y - r, r * 2, r * 2,
+                         -90*16, 90*16 );
+        painter.drawArc( left_x - r, bottom_y - r, r * 2, r * 2,
+                         0*16, 90*16 );
+        painter.drawArc( right_x - r, bottom_y - r, r * 2, r * 2,
+                         90*16, 90*16 );
+        painter.drawArc( right_x - r, top_y - r, r * 2, r * 2,
+                         180*16, 90*16 );
+    }
 }
 
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::drawPenaltyAreaLines( QPainter & painter ) const
 {
@@ -309,13 +329,13 @@ FieldPainter::drawPenaltyAreaLines( QPainter & painter ) const
     painter.setPen( dconf.linePen() );
     painter.setBrush( dconf.transparentBrush() );
 
-    // set screen coordinates of field
-    int left_x   = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength() );
-    int right_x  = M_conf.screenX( + rcsc::ServerParam::i().pitchHalfLength() );
+    // set absScreen coordinates of field
+    int left_x   = M_conf.absScreenX( - rcsc::ServerParam::i().pitchHalfLength() );
+    int right_x  = M_conf.absScreenX( + rcsc::ServerParam::i().pitchHalfLength() );
 
     // set penalty area params
-    int pen_top_y    = M_conf.screenY( - rcsc::ServerParam::i().penaltyAreaHalfWidth() );
-    int pen_bottom_y = M_conf.screenY( + rcsc::ServerParam::i().penaltyAreaHalfWidth() );
+    int pen_top_y    = M_conf.absScreenY( - rcsc::ServerParam::i().penaltyAreaHalfWidth() );
+    int pen_bottom_y = M_conf.absScreenY( + rcsc::ServerParam::i().penaltyAreaHalfWidth() );
     double pen_circle_y_degree_abs
         = std::acos( ( rcsc::ServerParam::i().penaltyAreaLength()
                        - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST )
@@ -326,11 +346,11 @@ FieldPainter::drawPenaltyAreaLines( QPainter & painter ) const
     int pen_circle_size = M_conf.scale( rcsc::ServerParam::DEFAULT_PENALTY_CIRCLE_R * 2.0 );
 
     // left penalty area X
-    int pen_x = M_conf.screenX( -( rcsc::ServerParam::i().pitchHalfLength()
-                                   - rcsc::ServerParam::i().penaltyAreaLength() ) );
+    int pen_x = M_conf.absScreenX( -( rcsc::ServerParam::i().pitchHalfLength()
+                                      - rcsc::ServerParam::i().penaltyAreaLength() ) );
     // left arc
-    int pen_spot_x = M_conf.screenX( -( rcsc::ServerParam::i().pitchHalfLength()
-                                        - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST ) );
+    int pen_spot_x = M_conf.absScreenX( -( rcsc::ServerParam::i().pitchHalfLength()
+                                           - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST ) );
     painter.drawArc( pen_spot_x - pen_circle_r + 1,
                      M_conf.fieldCenter().y - pen_circle_r,
                      pen_circle_size,
@@ -345,11 +365,11 @@ FieldPainter::drawPenaltyAreaLines( QPainter & painter ) const
     painter.drawPoint( pen_spot_x, M_conf.fieldCenter().y );
 
     // right penalty area X
-    pen_x = M_conf.screenX( +( rcsc::ServerParam::i().pitchHalfLength()
-                               - rcsc::ServerParam::i().penaltyAreaLength() ) );
+    pen_x = M_conf.absScreenX( +( rcsc::ServerParam::i().pitchHalfLength()
+                                  - rcsc::ServerParam::i().penaltyAreaLength() ) );
     // right arc
-    pen_spot_x = M_conf.screenX( +( rcsc::ServerParam::i().pitchHalfLength()
-                                    - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST ) );
+    pen_spot_x = M_conf.absScreenX( +( rcsc::ServerParam::i().pitchHalfLength()
+                                       - rcsc::ServerParam::DEFAULT_PENALTY_SPOT_DIST ) );
     painter.drawArc( pen_spot_x - pen_circle_r,
                      M_conf.fieldCenter().y - pen_circle_r,
                      pen_circle_size, pen_circle_size,
@@ -366,7 +386,7 @@ FieldPainter::drawPenaltyAreaLines( QPainter & painter ) const
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::drawGoalAreaLines( QPainter & painter ) const
 {
@@ -375,9 +395,9 @@ FieldPainter::drawGoalAreaLines( QPainter & painter ) const
     painter.setPen( dconf.linePen() );
     painter.setBrush( dconf.transparentBrush() );
 
-    // set screen coordinates of field
-    int left_x   = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength() );
-    int right_x  = M_conf.screenX( + rcsc::ServerParam::i().pitchHalfLength() );
+    // set absScreen coordinates of field
+    int left_x   = M_conf.absScreenX( - rcsc::ServerParam::i().pitchHalfLength() );
+    int right_x  = M_conf.absScreenX( + rcsc::ServerParam::i().pitchHalfLength() );
 
     // set coordinates M_confs
     int goal_area_y_abs = M_conf.scale( rcsc::ServerParam::i().goalAreaHalfWidth() );
@@ -385,15 +405,15 @@ FieldPainter::drawGoalAreaLines( QPainter & painter ) const
     int goal_area_bottom_y = M_conf.fieldCenter().y + goal_area_y_abs;
 
     // left goal area
-    int goal_area_x = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength()
-                                      + rcsc::ServerParam::i().goalAreaLength() );
+    int goal_area_x = M_conf.absScreenX( - rcsc::ServerParam::i().pitchHalfLength()
+                                         + rcsc::ServerParam::i().goalAreaLength() );
     painter.drawLine( left_x, goal_area_top_y, goal_area_x, goal_area_top_y );
     painter.drawLine( goal_area_x, goal_area_top_y, goal_area_x, goal_area_bottom_y );
     painter.drawLine( goal_area_x, goal_area_bottom_y, left_x, goal_area_bottom_y );
 
     // right goal area
-    goal_area_x = M_conf.screenX( rcsc::ServerParam::i().pitchHalfLength()
-                                  - rcsc::ServerParam::i().goalAreaLength() );
+    goal_area_x = M_conf.absScreenX( rcsc::ServerParam::i().pitchHalfLength()
+                                     - rcsc::ServerParam::i().goalAreaLength() );
     painter.drawLine( right_x, goal_area_top_y, goal_area_x, goal_area_top_y );
     painter.drawLine( goal_area_x, goal_area_top_y, goal_area_x, goal_area_bottom_y );
     painter.drawLine( goal_area_x, goal_area_bottom_y, right_x, goal_area_bottom_y );
@@ -402,7 +422,7 @@ FieldPainter::drawGoalAreaLines( QPainter & painter ) const
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::drawGoals( QPainter & painter ) const
 {
@@ -411,24 +431,24 @@ FieldPainter::drawGoals( QPainter & painter ) const
     painter.setBrush( Qt::black );
 
     // set coordinates param
-    int goal_top_y = M_conf.screenY( - rcsc::ServerParam::i().goalHalfWidth() );
+    int goal_top_y = M_conf.absScreenY( - rcsc::ServerParam::i().goalHalfWidth() );
     int goal_size_x = M_conf.scale( rcsc::ServerParam::i().goalDepth() );
     int goal_size_y = M_conf.scale( rcsc::ServerParam::i().goalWidth() );
 
-    int post_top_y = M_conf.screenY( - rcsc::ServerParam::i().goalHalfWidth()
-                                     - rcsc::ServerParam::i().goalPostRadius() * 2.0 );
-    int post_bottom_y = M_conf.screenY( + rcsc::ServerParam::i().goalHalfWidth() );
+    int post_top_y = M_conf.absScreenY( - rcsc::ServerParam::i().goalHalfWidth()
+                                        - rcsc::ServerParam::i().goalPostRadius() * 2.0 );
+    int post_bottom_y = M_conf.absScreenY( + rcsc::ServerParam::i().goalHalfWidth() );
     int post_diameter = M_conf.scale( rcsc::ServerParam::i().goalPostRadius() * 2.0 );
 
     // left goal
-    painter.drawRect( M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength()
-                                      - rcsc::ServerParam::i().goalDepth() ) - 1,
+    painter.drawRect( M_conf.absScreenX( - rcsc::ServerParam::i().pitchHalfLength()
+                                         - rcsc::ServerParam::i().goalDepth() ) - 1,
                       goal_top_y,
                       goal_size_x,
                       goal_size_y );
     if ( post_diameter >= 1 )
     {
-        int post_x = M_conf.screenX( - rcsc::ServerParam::i().pitchHalfLength() );
+        int post_x = M_conf.absScreenX( - rcsc::ServerParam::i().pitchHalfLength() );
         painter.drawEllipse( post_x,
                              post_top_y,
                              post_diameter,
@@ -439,14 +459,14 @@ FieldPainter::drawGoals( QPainter & painter ) const
                              post_diameter );
     }
     // right goal
-    painter.drawRect( M_conf.screenX( rcsc::ServerParam::i().pitchHalfLength() ) + 1,
+    painter.drawRect( M_conf.absScreenX( rcsc::ServerParam::i().pitchHalfLength() ) + 1,
                       goal_top_y,
                       goal_size_x,
                       goal_size_y );
     if ( post_diameter >= 1 )
     {
-        int post_x = M_conf.screenX( rcsc::ServerParam::i().pitchHalfLength()
-                                     - rcsc::ServerParam::i().goalPostRadius() * 2.0 );
+        int post_x = M_conf.absScreenX( rcsc::ServerParam::i().pitchHalfLength()
+                                        - rcsc::ServerParam::i().goalPostRadius() * 2.0 );
         painter.drawEllipse( post_x,
                              post_top_y,
                              post_diameter,
@@ -461,7 +481,7 @@ FieldPainter::drawGoals( QPainter & painter ) const
 /*-------------------------------------------------------------------*/
 /*!
 
-*/
+ */
 void
 FieldPainter::drawFlags( QPainter & painter ) const
 {
@@ -695,3 +715,97 @@ FieldPainter::drawFlags( QPainter & painter ) const
     y = M_conf.fieldCenter().y + scale30 - flag_radius;
     painter.drawEllipse( x, y, flag_diameter, flag_diameter );
 }
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+void
+FieldPainter::drawGrid( QPainter & painter ) const
+{
+    const double grid_step = 0.1 * M_conf.gridStep();
+    const int istep = M_conf.scale( grid_step );
+    const int text_step = ( M_conf.isShownGridCoord()
+                            ? 10
+                            : 100000 );
+
+    if ( istep < 2 )
+    {
+        return;
+    }
+
+    const QRect win = painter.window();
+
+    const int max_ix = win.right();
+    const int min_ix = win.left();
+    const int max_iy = win.bottom();
+    const int min_iy = win.top();
+    const double max_x = M_conf.fieldX( max_ix );
+    const double min_x = M_conf.fieldX( min_ix );
+    const double max_y = M_conf.fieldY( max_iy );
+    const double min_y = M_conf.fieldY( min_iy );
+
+    //     std::cerr << "drawGrid  min_x = " < min_x
+    //               << "  max_x = " << max_x
+    //               << "  min_y = " << min_y
+    //               << "  max_y = " << max_y
+    //               << std::endl;
+
+    painter.setPen( DrawConfig::instance().linePen() );
+    painter.setBrush( DrawConfig::instance().transparentBrush() );
+
+    QString text;
+
+    double x = 0.0;
+    while ( x < max_x )
+    {
+        int ix = M_conf.absScreenX( x );
+        if ( istep > text_step )
+        {
+            text.sprintf( "%.1f", x );
+            painter.drawText( ix, max_iy, text );
+        }
+        painter.drawLine( ix, max_iy, ix, min_iy );
+        x += grid_step;
+    }
+
+    x = -grid_step;
+    while ( min_x < x )
+    {
+        int ix = M_conf.absScreenX( x );
+        if ( istep > text_step )
+        {
+            text.sprintf( "%.1f", x );
+            painter.drawText( ix, max_iy, text );
+        }
+        painter.drawLine( ix, max_iy, ix, min_iy );
+        x -= grid_step;
+    }
+
+
+    double y = 0.0;
+    while ( y < max_y )
+    {
+        int iy = M_conf.absScreenY( y );
+        if ( istep > text_step )
+        {
+            text.sprintf( "%.1f", y );
+            painter.drawText( min_ix, iy, text );
+        }
+        painter.drawLine( max_ix, iy, min_ix, iy );
+        y += grid_step;
+    }
+
+    y = -grid_step;
+    while ( min_y < y )
+    {
+        int iy = M_conf.absScreenY( y );
+        if ( istep > text_step )
+        {
+            text.sprintf( "%.1f", y );
+            painter.drawText( min_ix, iy, text );
+        }
+        painter.drawLine( max_ix, iy, min_ix, iy );
+        y -= grid_step;
+    }
+}
