@@ -109,6 +109,11 @@ private:
     */
     void drawFlags( QPainter & painter ) const;
 
+    /*!
+      \brief draw grid lines
+     */
+    void drawGrid( QPainter & painter ) const;
+
 };
 
 #endif
