@@ -209,7 +209,7 @@ LogPlayer::playBack()
 
     if ( ! M_timer->isActive() )
     {
-        M_timer_interval = AppConfig::instance().defaultTimerInterval();
+        M_timer_interval = AppConfig::instance().timerInterval();
         M_timer->start( M_timer_interval );
     }
 }
@@ -227,7 +227,7 @@ LogPlayer::playForward()
 
     if ( ! M_timer->isActive() )
     {
-        M_timer_interval = AppConfig::instance().defaultTimerInterval();
+        M_timer_interval = AppConfig::instance().timerInterval();
         M_timer->start( M_timer_interval );
     }
 }
