@@ -244,8 +244,8 @@ LogPlayerToolBar::createControls( LogPlayer * log_player )
                            tr( "Stop" ), QKeySequence(), log_player );
         //act->setAccel( Qt::Key_Down );
         act->setStatusTip( tr( "Stop the log player. (Down)" ) );
-        connect( act, SIGNAL( activated() ),
-                 log_player, SLOT( stop() ) );
+        //connect( act, SIGNAL( activated() ),
+        //         log_player, SLOT( stop() ) );
         act->addTo( this ); //this->addAction( act );
         act->setVisible( false );
 
@@ -258,8 +258,8 @@ LogPlayerToolBar::createControls( LogPlayer * log_player )
                            tr( "Play Backward" ), QKeySequence(), log_player );
         //act->setAccel( Qt::CTRL + Qt::Key_Down );
         act->setStatusTip( tr( "Play backward the log player.(Ctrl+Down)" ) );
-        connect( act, SIGNAL( activated() ),
-                 log_player, SLOT( playBack() ) );
+        //connect( act, SIGNAL( activated() ),
+        //         log_player, SLOT( playBack() ) );
         act->addTo( this ); //this->addAction( act );
         act->setVisible( false );
 
@@ -272,8 +272,8 @@ LogPlayerToolBar::createControls( LogPlayer * log_player )
                            tr( "Play Forward" ), QKeySequence(), log_player );
         //act->setAccel( Qt::Key_Up );
         act->setStatusTip( tr( "Play forward the log player.(Up)" ) );
-        connect( act, SIGNAL( activated() ),
-                 log_player, SLOT( playForward() ) );
+        //connect( act, SIGNAL( activated() ),
+        //         log_player, SLOT( playForward() ) );
         act->addTo( this ); //this->addAction( act );
         act->setVisible( false );
 
@@ -309,6 +309,16 @@ LogPlayerToolBar::createControls( LogPlayer * log_player )
              this, SLOT( editCycle() ) );
     QToolTip::add( M_cycle_edit, tr( "Cycle Input" ) );
 
+    // invisible action
+    {
+        QAction * act
+            = new QAction( tr( "Focus Cycle Edit" ), QKeySequence(), log_player );
+        act->addTo( this );
+        act->setVisible( false );
+
+        accel->connectItem( accel->insertItem( tr( "Ctrl+F" ) ),
+                            M_cycle_edit, SLOT( setFocus() ) );
+    }
 }
 
 /*-------------------------------------------------------------------*/
