@@ -43,6 +43,8 @@
 class QAction;
 class QActionGroup;
 class QCloseEvent;
+class QDragEnterEvent;
+class QDropEvent;
 class QPoint;
 class CProcess;
 class QLabel;
@@ -57,6 +59,7 @@ class LauncherDialog;
 class LogPlayer;
 class LogPlayerToolBar;
 class MonitorClient;
+class MonitorMoveDialog;
 class PlayerTypeDialog;
 class ViewConfigDialog;
 
@@ -74,10 +77,13 @@ private:
     LogPlayer * M_log_player;
 
     LogPlayerToolBar * M_log_player_tool_bar;
+    //QToolBar * M_monitor_tool_bar;
+
     QLabel * M_position_label;
 
     DetailDialog * M_detail_dialog;
     PlayerTypeDialog * M_player_type_dialog;
+    MonitorMoveDialog * M_monitor_move_dialog;
     ViewConfigDialog * M_view_config_dialog;
     LauncherDialog * M_launcher_dialog;
 
@@ -86,7 +92,7 @@ private:
     boost::shared_ptr< MonitorClient > M_monitor_client;
     boost::shared_ptr< DebugServer > M_debug_server;
 
-    std::string M_last_connected_host;
+    QString M_last_connected_host;
 
     QString M_server_command;
 
@@ -105,6 +111,8 @@ private:
     QAction * M_disconnect_monitor_act;;
     QAction * M_kill_server_act;;
     QAction * M_restart_server_act;;
+    QAction * M_toggle_drag_move_mode_act;
+    QAction * M_show_monitor_move_dialog_act;
     QAction * M_show_launcher_dialog_act;
 
     // view actions
@@ -141,7 +149,7 @@ public:
 
 private:
 
-    void loadSettings();
+    void readSettings();
     void saveSettings();
 
     void createActions();
@@ -171,12 +179,15 @@ protected:
     void resizeEvent( QResizeEvent * event );
     void wheelEvent( QWheelEvent * event );
 
+    void dragEnterEvent( QDragEnterEvent * event );
+    void dropEvent( QDropEvent * event );
+
 private:
 
-    void loadRCG( const QString & file_path );
+    void openRCG( const QString & file_path );
     void connectMonitorTo( const char * hostname );
 
-public slots:
+private slots:
 
     // file menu actions slots
     void openRCG();
@@ -195,6 +206,7 @@ public slots:
     void startServer();
     void restartServer();
     void restartServer( const QString & command );
+    void toggleDragMoveMode( bool on );
     void showLauncherDialog();
 
     // view menu actions slots
@@ -207,6 +219,7 @@ public slots:
     void changeStyle( const QString & style );
     void showColorSettingDialog();
     void showFontSettingDialog();
+    void showMonitorMoveDialog();
     void showViewConfigDialog();
 
     // tool menu actions slots
@@ -221,6 +234,8 @@ public slots:
 
     void resizeCanvas( const QSize & size );
 
+    void saveImageAndQuit();
+
 public slots:
 
     void receiveMonitorPacket();
@@ -228,9 +243,12 @@ public slots:
     void updatePositionLabel( const QPoint & point );
 
     void dropBallThere();
-    void dropBall( const QPoint & pos );
-    void freeKickLeft( const QPoint & pos );
-    void freeKickRight( const QPoint & pos );
+    void dropBall( const QPoint & point );
+    void freeKickLeft( const QPoint & point );
+    void freeKickRight( const QPoint & point );
+
+    void moveDraggedPlayer( const QPoint & point );
+    void moveObjects();
 
 signals:
 
