@@ -94,7 +94,7 @@ OffsideLinePainter::draw( QPainter & painter )
         offside_l = std::min( offside_l, ball_x );
         offside_l = std::max( offside_l, - rcsc::ServerParam::i().pitchHalfLength() );
     }
-    const int offside_line_l = vconf.screenX( offside_l * vconf.reverseValue() );
+    const int offside_line_l = vconf.screenX( offside_l );
 
     double offside_r = 0.0;
     {
@@ -121,7 +121,7 @@ OffsideLinePainter::draw( QPainter & painter )
         offside_r = std::max( offside_r, ball_x );
         offside_r = std::min( offside_r, rcsc::ServerParam::i().pitchHalfLength() );
     }
-    const int offside_line_r = vconf.screenX( offside_r * vconf.reverseValue() );
+    const int offside_line_r = vconf.screenX( offside_r );
 
     const int top_y = vconf.screenY( rcsc::ServerParam::i().pitchHalfWidth() );
     const int bottom_y = vconf.screenY( - rcsc::ServerParam::i().pitchHalfWidth() );
@@ -130,11 +130,15 @@ OffsideLinePainter::draw( QPainter & painter )
 
     painter.setBrush( dconf.transparentBrush() );
 
-    painter.setPen( dconf.leftTeamPen() );
+    painter.setPen( ( vconf.reverseSide()
+                      ? dconf.rightTeamPen()
+                      : dconf.leftTeamPen() ) );
     painter.drawLine( offside_line_l, top_y,
                       offside_line_l, bottom_y );
 
-    painter.setPen( dconf.rightTeamPen() );
+    painter.setPen( ( vconf.reverseSide()
+                      ? dconf.leftTeamPen()
+                      : dconf.rightTeamPen() ) );
     painter.drawLine( offside_line_r, top_y,
                       offside_line_r, bottom_y );
 }
