@@ -115,10 +115,10 @@ PlayerControlPainter::draw( QPainter & painter )
             max_kick_accel = sparam.ballAccelMax();
         }
 
-        QPoint bpos_screen( vconf.screenX( bpos.x * vconf.reverseValue() ),
-                            vconf.screenY( bpos.y * vconf.reverseValue() ) );
-        QPoint bnext_screen( vconf.screenX( bnext.x * vconf.reverseValue() ),
-                             vconf.screenY( bnext.y * vconf.reverseValue() ) );
+        QPoint bpos_screen( vconf.screenX( bpos.x ),
+                            vconf.screenY( bpos.y ) );
+        QPoint bnext_screen( vconf.screenX( bnext.x ),
+                             vconf.screenY( bnext.y ) );
         int max_speed_screen = vconf.scale( sparam.ballSpeedMax() );
         int max_kick_accel_screen = vconf.scale( max_kick_accel );
 
