@@ -58,8 +58,8 @@ PlayerPainter::Param::Param( const Player & player,
                              const Ball & ball,
                              const ViewConfig & view_conf,
                              const rcsc::PlayerType & ptype )
-    : x_( view_conf.screenX( player.x() * view_conf.reverseValue() ) )
-    , y_( view_conf.screenY( player.y() * view_conf.reverseValue() ) )
+    : x_( view_conf.screenX( player.x() ) )
+    , y_( view_conf.screenY( player.y() ) )
     , body_( player.body() + ( view_conf.reverseSide() ? 180.0 : 0.0 ) )
     , head_( player.head() + ( view_conf.reverseSide() ? 180.0 : 0.0 ) )
     , body_radius_( view_conf.scale( ptype.playerSize() ) )
@@ -73,9 +73,22 @@ PlayerPainter::Param::Param( const Player & player,
     if ( body_radius_ < 1 ) body_radius_ = 1;
     if ( kick_radius_ < 5 ) kick_radius_ = 5;
 
-    draw_radius_ = ( view_conf.isEnlarged()
-                     ? kick_radius_
-                     : body_radius_ );
+    if ( view_conf.isEnlarged() )
+    {
+        if ( view_conf.playerSize() > 0.0 )
+        {
+            draw_radius_ = view_conf.scale( view_conf.playerSize() );
+            if ( draw_radius_ < 1 ) draw_radius_ = 1;
+        }
+        else
+        {
+            draw_radius_ = kick_radius_;
+        }
+    }
+    else
+    {
+        draw_radius_ = body_radius_;
+    }
 }
 
 /*-------------------------------------------------------------------*/
@@ -136,9 +149,9 @@ PlayerPainter::draw( QPainter & painter )
 
 */
 void
-PlayerPainter::drawAll(  QPainter & painter,
-                         const Player & player,
-                         const Ball & ball ) const
+PlayerPainter::drawAll( QPainter & painter,
+                        const Player & player,
+                        const Ball & ball ) const
 {
     const Param param( player,
                        ball,
@@ -146,7 +159,10 @@ PlayerPainter::drawAll(  QPainter & painter,
                        M_main_data.viewHolder().playerType( player.type() ) );
 
     drawBody( painter, param );
-    drawShadow( painter, param );
+    if ( M_main_data.viewConfig().isShownBodyShadow() )
+    {
+        drawShadow( painter, param );
+    }
     drawEdge( painter, param );
 
     if ( M_main_data.viewConfig().isSelectedPlayer( player.side(), player.unum() )
@@ -156,15 +172,22 @@ PlayerPainter::drawAll(  QPainter & painter,
         drawFuture( painter, param );
     }
 
-    if ( player.hasView()
-         && M_main_data.viewConfig().isShownViewCone() )
+    if ( player.hasView() )
     {
-        drawViewCone( painter, param );
+        if ( M_main_data.viewConfig().isShownViewCone() )
+        {
+            drawViewCone( painter, param );
+        }
+//         else
+//         {
+//             drawViewDir( painter, param );
+//         }
     }
 
     if ( M_main_data.viewConfig().isShownControlArea() )
     {
         drawControlArea( painter, param );
+        drawPointTo( painter, param );
     }
 
     drawText( painter, param );
@@ -224,29 +247,29 @@ PlayerPainter::drawBody( QPainter & painter,
     {
         painter.setBrush( dconf.shadowBrush() );
     }
-    if ( param.player_.isKick() )
+    if ( param.player_.isKicking() )
     {
         painter.setPen( dconf.kickPen() );
     }
-    if ( param.player_.isKickFault() )
+    if ( param.player_.isKickingFault() )
     {
         painter.setPen( dconf.kickFaultPen() );
         painter.setBrush( dconf.kickFaultBrush() );
     }
-    if ( param.player_.isCatch() )
+    if ( param.player_.isCatching() )
     {
         painter.setBrush( dconf.catchBrush() );
     }
-    if ( param.player_.isCatchFault() )
+    if ( param.player_.isCatchingFault() )
     {
         painter.setBrush( dconf.catchFaultBrush() );
     }
-    if ( param.player_.isTackle() )
+    if ( param.player_.isTackling() )
     {
         painter.setPen( dconf.tacklePen() );
         painter.setBrush( dconf.tackleBrush() );
     }
-    if ( param.player_.isTackleFault() )
+    if ( param.player_.isTacklingFault() )
     {
         painter.setPen( dconf.tacklePen() );
         painter.setBrush( dconf.tackleFaultBrush() );
@@ -336,23 +359,33 @@ void
 PlayerPainter::drawEdge( QPainter & painter,
                          const PlayerPainter::Param & param ) const
 {
+    const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
-    // draw body edge or kickable area edge
-    if ( M_main_data.viewConfig().isEnlarged() )
+    int edge_radius = 1;
+    if ( vconf.isEnlarged() )
     {
-        // draw real body edge
-        painter.setPen( dconf.realBodyPen() );
-        painter.setBrush( dconf.transparentBrush() );
-        painter.drawEllipse( param.x_ - param.body_radius_,
-                             param.y_ - param.body_radius_,
-                             param.body_radius_ * 2,
-                             param.body_radius_ * 2 );
+        if ( vconf.isShownBodyShadow() )
+        {
+            painter.setPen( dconf.realBodyPen() );
+        }
+        else
+        {
+            painter.setPen( dconf.playerPen() );
+        }
+
+        edge_radius = param.body_radius_;
     }
     else
     {
         // draw kickable area edge
-        if ( param.player_.side() == rcsc::LEFT )
+        rcsc::SideID side = param.player_.side();
+        if ( vconf.reverseSide() )
+        {
+            side = static_cast< rcsc::SideID >( -1 * side );
+        }
+
+        if ( side == rcsc::LEFT )
         {
             painter.setPen( dconf.leftTeamPen() );
         }
@@ -360,11 +393,28 @@ PlayerPainter::drawEdge( QPainter & painter,
         {
             painter.setPen( dconf.rightTeamPen() );
         }
-        painter.setBrush( dconf.transparentBrush() );
-        painter.drawEllipse( param.x_ - param.kick_radius_,
-                             param.y_ - param.kick_radius_,
-                             param.kick_radius_ * 2,
-                             param.kick_radius_ * 2 );
+
+        edge_radius = param.kick_radius_;
+    }
+
+    painter.setBrush( dconf.transparentBrush() );
+
+    painter.drawEllipse( param.x_ - edge_radius,
+                         param.y_ - edge_radius,
+                         edge_radius * 2,
+                         edge_radius * 2 );
+
+    // body direction line
+    if ( ! vconf.isShownBodyShadow() )
+    {
+        int end_x = vconf.absScreenX( param.player_.x() * vconf.reverseValue()
+                                      + param.player_type_.kickableArea()
+                                      * std::cos( param.body_ * rcsc::AngleDeg::DEG2RAD ) );
+        int end_y = vconf.absScreenY( param.player_.y() * vconf.reverseValue()
+                                      + param.player_type_.kickableArea()
+                                      * std::sin( param.body_ * rcsc::AngleDeg::DEG2RAD ) );
+        // same pen & brush
+        painter.drawLine( param.x_, param.y_, end_x, end_y );
     }
 
     // draw stamina status if effort or recovery is decayed.
@@ -402,6 +452,7 @@ void
 PlayerPainter::drawFuture( QPainter & painter,
                            const PlayerPainter::Param & param ) const
 {
+    const ViewConfig & vconf = M_main_data.viewConfig();
     const DrawConfig & dconf = DrawConfig::instance();
 
     // draw future state
@@ -413,14 +464,20 @@ PlayerPainter::drawFuture( QPainter & painter,
         pvel *= -1.0;
     }
 
-    const int last = M_main_data.viewConfig().playerFutureCycle();
+    const int last = vconf.playerFutureCycle();
 
-    QPoint first_point( M_main_data.viewConfig().screenX( ppos.x ),
-                        M_main_data.viewConfig().screenY( ppos.y ) ) ;
+    QPoint first_point( vconf.absScreenX( ppos.x ),
+                        vconf.absScreenY( ppos.y ) ) ;
     QPoint last_point = first_point;
 
     // draw kickable area edge
-    if ( param.player_.side() == rcsc::LEFT )
+    rcsc::SideID side = param.player_.side();
+    if ( vconf.reverseSide() )
+    {
+        side = static_cast< rcsc::SideID >( -1 * side );
+    }
+
+    if ( side == rcsc::LEFT )
     {
         painter.setPen( dconf.rightTeamPen() );
     }
@@ -436,8 +493,8 @@ PlayerPainter::drawFuture( QPainter & painter,
         ppos += pvel;
         pvel *= param.player_type_.playerDecay();
 
-        QPoint pt( M_main_data.viewConfig().screenX( ppos.x ),
-                   M_main_data.viewConfig().screenY( ppos.y ) );
+        QPoint pt( vconf.absScreenX( ppos.x ),
+                   vconf.absScreenY( ppos.y ) );
         if ( std::abs( last_point.x() - pt.x() ) < 1
              && std::abs( last_point.y() - pt.y() ) < 1 )
         {
@@ -561,6 +618,29 @@ PlayerPainter::drawViewCone( QPainter & painter,
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+PlayerPainter::drawViewDir( QPainter & painter,
+                            const PlayerPainter::Param & param ) const
+{
+    const ViewConfig & vconf = M_main_data.viewConfig();
+    const DrawConfig & dconf = DrawConfig::instance();
+
+    int end_x = vconf.absScreenX( param.player_.x() * vconf.reverseValue()
+                                  + param.player_type_.kickableArea()
+                                  * std::cos( param.head_ * rcsc::AngleDeg::DEG2RAD ) );
+    int end_y = vconf.absScreenY( param.player_.y() * vconf.reverseValue()
+                                  + param.player_type_.kickableArea()
+                                  * std::sin( param.head_ * rcsc::AngleDeg::DEG2RAD ) );
+
+    painter.setPen( dconf.viewConePen() );
+    painter.setBrush( dconf.transparentBrush() );
+    painter.drawLine( param.x_, param.y_, end_x, end_y );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 PlayerPainter::drawControlArea( QPainter & painter,
@@ -571,8 +651,14 @@ PlayerPainter::drawControlArea( QPainter & painter,
 
     if ( param.player_.isGoalie() )
     {
+        rcsc::SideID side = param.player_.side();
+        if ( vconf.reverseSide() )
+        {
+            side = static_cast< rcsc::SideID >( -1 * side );
+        }
+
         int catchable = vconf.scale( rcsc::ServerParam::i().catchableArea() );
-        painter.setPen( ( param.player_.side() == rcsc::LEFT )
+        painter.setPen( ( side == rcsc::LEFT )
                         ? dconf.leftGoaliePen()
                         : dconf.rightGoaliePen() );
         painter.setBrush( dconf.transparentBrush() );
@@ -599,10 +685,10 @@ PlayerPainter::drawControlArea( QPainter & painter,
     // draw tackle area & probability
     double tackle_dist = ( player_to_ball.x > 0.0
                            ? rcsc::ServerParam::i().tackleDist()
-                           : rcsc::ServerParam::i().tackleBackDist() );
+                           : rcsc::ServerParam::i().tackleBackDist() ); //: 0.0 );
     double tackle_prob = ( std::pow( player_to_ball.absX() / tackle_dist,
                                      rcsc::ServerParam::i().tackleExponent() )
-                           + std::pow( player_to_ball.absY() / rcsc::ServerParam::i().tackleWidth(),
+                           + std::pow( player_to_ball.absY() / rcsc::ServerParam::i().tackleWidth(), // 1.25,
                                        rcsc::ServerParam::i().tackleExponent() ) );
     if ( tackle_prob < 1.0 )
     {
@@ -612,25 +698,27 @@ PlayerPainter::drawControlArea( QPainter & painter,
         double body_y = body_angle.sin();
         double forward_x = rcsc::ServerParam::i().tackleDist() * body_x;
         double forward_y = rcsc::ServerParam::i().tackleDist() * body_y;
-        double back_x = rcsc::ServerParam::i().tackleBackDist() * -body_x;
-        double back_y = rcsc::ServerParam::i().tackleBackDist() * -body_y;
-        double right_x = rcsc::ServerParam::i().tackleWidth() * body_angle_side.cos();
-        double right_y = rcsc::ServerParam::i().tackleWidth() * body_angle_side.sin();
+        double back_x = rcsc::ServerParam::i().tackleBackDist() * -body_x; // 0.0 * -body_x;
+        double back_y = rcsc::ServerParam::i().tackleBackDist() * -body_y; // 0.0 * -body_y;
+        double right_x = rcsc::ServerParam::i().tackleWidth() * body_angle_side.cos(); // 1.25 * body_angle_side.cos();
+        double right_y = rcsc::ServerParam::i().tackleWidth() * body_angle_side.sin(); // 1.25 * body_angle_side.sin();
 
-        QPointArray pts( 4 );
-        pts[0].setX( vconf.screenX( ppos.x + forward_x + right_x ) );
-        pts[0].setY( vconf.screenY( ppos.y + forward_y + right_y ) );
-        pts[1].setX( vconf.screenX( ppos.x + forward_x - right_x ) );
-        pts[1].setY( vconf.screenY( ppos.y + forward_y - right_y ) );
-        pts[2].setX( vconf.screenX( ppos.x + back_x - right_x ) );
-        pts[2].setY( vconf.screenY( ppos.y + back_y - right_y ) );
-        pts[3].setX( vconf.screenX( ppos.x + back_x + right_x ) );
-        pts[3].setY( vconf.screenY( ppos.y + back_y + right_y ) );
+        QPointArray pts( 5 );
+        pts[0].setX( vconf.absScreenX( ppos.x + forward_x + right_x ) );
+        pts[0].setY( vconf.absScreenY( ppos.y + forward_y + right_y ) );
+        pts[1].setX( vconf.absScreenX( ppos.x + forward_x - right_x ) );
+        pts[1].setY( vconf.absScreenY( ppos.y + forward_y - right_y ) );
+        pts[2].setX( vconf.absScreenX( ppos.x + back_x - right_x ) );
+        pts[2].setY( vconf.absScreenY( ppos.y + back_y - right_y ) );
+        pts[3].setX( vconf.absScreenX( ppos.x + back_x + right_x ) );
+        pts[3].setY( vconf.absScreenY( ppos.y + back_y + right_y ) );
+        pts[4] = pts[0];
 
         painter.setPen( dconf.tackleAreaPen() );
         painter.setBrush( dconf.transparentBrush() );
 
-        painter.drawConvexPolygon( pts, 0, 4 );
+        //painter.drawConvexPolygon( pts, 0, 4 );
+        painter.drawPolyline( pts, 0, 5 );
 
         int text_radius = param.draw_radius_;
         if ( text_radius > 40 )
@@ -642,11 +730,37 @@ PlayerPainter::drawControlArea( QPainter & painter,
         painter.setPen( dconf.tacklePen() );
 
         char msg[32];
-        std::snprintf( msg, 32, "TakleProb=%.3f", 1.0 - tackle_prob );
+        std::snprintf( msg, 32, "TackleProb=%.3f", 1.0 - tackle_prob );
         painter.drawText( param.x_ + text_radius,
                           param.y_ + 4 + painter.fontMetrics().ascent(),
                           QString::fromAscii( msg ) );
     }
+
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+PlayerPainter::drawPointTo( QPainter & painter,
+                            const PlayerPainter::Param & param ) const
+{
+    if ( ! param.player_.isPointing() )
+    {
+        return;
+    }
+
+    int px = M_main_data.viewConfig().screenX( param.player_.data().point_x_ );
+    int py = M_main_data.viewConfig().screenY( param.player_.data().point_y_ );
+
+    painter.setPen( DrawConfig::instance().pointtoPen() );
+    painter.setBrush( DrawConfig::instance().transparentBrush() );
+
+    painter.drawLine( param.x_, param.y_, px, py );
+    painter.drawLine( px - 4, py, px + 4, py );
+    painter.drawLine( px, py - 4, px, py + 4 );
+
 }
 
 /*-------------------------------------------------------------------*/
@@ -662,6 +776,11 @@ PlayerPainter::drawText( QPainter & painter,
 
     const int text_radius = std::min( 40, param.draw_radius_ );
 
+    //     painter.save();
+    //     painter.translate( param.x_, param.y_ );
+    //     painter.rotate( -90.0 );
+    //     painter.translate( -param.x_, -param.y_ );
+
     painter.setFont( dconf.playerFont() );
 
     if ( vconf.isShownPlayerNumber()
@@ -726,4 +845,6 @@ PlayerPainter::drawText( QPainter & painter,
                               QString::fromAscii( buf ) );
         }
     }
+
+    //    painter.restore();
 }
