@@ -143,6 +143,9 @@ private:
     void drawViewCone( QPainter & painter,
                        const PlayerPainter::Param & param ) const;
 
+    void drawViewDir( QPainter & painter,
+                      const PlayerPainter::Param & param ) const;
+
     /*!
       \brief draw goalie catchable area. And if ball is in player's tackla
       area, tackle area rectangle is drawn.
@@ -152,6 +155,9 @@ private:
     void drawControlArea( QPainter & painter,
                           const PlayerPainter::Param & param ) const;
 
+    void drawPointTo( QPainter & painter,
+                      const PlayerPainter::Param & param ) const;
+
     /*!
       \brief draw text info
       \param painter reference to painter instance
