@@ -101,9 +101,14 @@ PlayerTracePainter::draw( QPainter & painter )
         ( vconf.selectedNumber() > 0
           ? vconf.selectedNumber() - 1
           : 11 - vconf.selectedNumber() - 1 );
-    const QPen & my_pen = ( vconf.selectedNumber() > 0
-                            ? DrawConfig::instance().leftTeamPen()
-                            : DrawConfig::instance().rightTeamPen() );
+    const QPen & my_pen = ( vconf.reverseSide()
+                            ? ( vconf.selectedNumber() > 0
+                                ? DrawConfig::instance().rightTeamPen()
+                                : DrawConfig::instance().leftTeamPen() )
+                            : ( vconf.selectedNumber() > 0
+                                ? DrawConfig::instance().leftTeamPen()
+                                : DrawConfig::instance().rightTeamPen() )
+                            );
     QPen black_dot_pen( Qt::black );
     black_dot_pen.setStyle( Qt::DotLine );
 
@@ -119,8 +124,8 @@ PlayerTracePainter::draw( QPainter & painter )
     }
 
     std::size_t i = first;
-    int prev_x = vconf.screenX( vc[i]->players()[idx].x() * vconf.reverseValue() );
-    int prev_y = vconf.screenY( vc[i]->players()[idx].y() * vconf.reverseValue() );
+    int prev_x = vconf.screenX( vc[i]->players()[idx].x() );
+    int prev_y = vconf.screenY( vc[i]->players()[idx].y() );
     ++i;
     for ( ; i <= last; ++i )
     {
@@ -138,8 +143,8 @@ PlayerTracePainter::draw( QPainter & painter )
             break;
         }
 
-        int ix = vconf.screenX( vc[i]->players()[idx].x() * vconf.reverseValue() );
-        int iy = vconf.screenY( vc[i]->players()[idx].y() * vconf.reverseValue() );
+        int ix = vconf.screenX( vc[i]->players()[idx].x() );
+        int iy = vconf.screenY( vc[i]->players()[idx].y() );
         if ( line_trace )
         {
             painter.drawLine( prev_x, prev_y, ix, iy );
