@@ -79,6 +79,11 @@ ScoreBoardPainter::draw( QPainter & painter )
 
     const DrawConfig & dconf = DrawConfig::instance();
 
+    if ( dconf.scoreBoardFont().pointSize() != vconf.scoreBoardFontSize() )
+    {
+        DrawConfig::instance().resizeScoreBoardFont( vconf.scoreBoardFontSize() );
+    }
+
     int board_left_x = 0;
     int board_top_y = 0;
     int board_width = vconf.canvasWidth();
@@ -102,21 +107,15 @@ ScoreBoardPainter::draw( QPainter & painter )
                               : view->leftTeam() );
 
         QString temp_str;
-        if ( team.name().empty() )
-        {
-            temp_str = QString::fromAscii( "left team" );
-        }
-        else
-        {
-            char buf[32];
-            std::snprintf( buf, 32,
-                           "%s  %d",
-                           AppConfig::instance().anonymousMode()
-                           ? "left team"
-                           : team.name().c_str(),
-                           team.score() );
-            temp_str = QString::fromAscii( buf );
-        }
+        char buf[32];
+        std::snprintf( buf, 32,
+                       "%s  %d",
+                       ( vconf.anonymousMode()
+                         || team.name().empty() )
+                       ? "left team"
+                       : team.name().c_str(),
+                       team.score() );
+        temp_str = QString::fromAscii( buf );
 
         painter.drawText( left_rect,
                           Qt::AlignCenter,
@@ -135,21 +134,15 @@ ScoreBoardPainter::draw( QPainter & painter )
                               : view->rightTeam() );
 
         QString temp_str;
-        if ( team.name().empty() )
-        {
-            temp_str = QString::fromAscii( "right team" );
-        }
-        else
-        {
-            char buf[32];
-            std::snprintf( buf, 32,
-                           "%s  %d",
-                           AppConfig::instance().anonymousMode()
-                           ? "right team"
-                           : team.name().c_str(),
-                           team.score() );
-            temp_str = QString::fromAscii( buf );
-        }
+        char buf[32];
+        std::snprintf( buf, 32,
+                       "%s  %d",
+                       ( vconf.anonymousMode()
+                         || team.name().empty() )
+                       ? "right team"
+                       : team.name().c_str(),
+                       team.score() );
+        temp_str = QString::fromAscii( buf );
 
         painter.drawText( right_rect,
                           Qt::AlignCenter,
@@ -168,6 +161,18 @@ ScoreBoardPainter::draw( QPainter & painter )
                        "%s  %4ld",
                        view->playmode().name().c_str(),
                        view->cycle() );
+        if ( vconf.reverseSide() )
+        {
+            std::size_t len = view->playmode().name().length() - 1;
+            if ( buf[len] == 'l' )
+            {
+                buf[len] = 'r';
+            }
+            else if ( buf[len] == 'r' )
+            {
+                buf[len] = 'l';
+            }
+        }
 
         painter.drawText( time_rect,
                           Qt::AlignCenter,
@@ -208,8 +213,10 @@ ScoreBoardPainter::drawPenaltyScores( QPainter & painter )
         return;
     }
 
-    if ( view->cycle() < scores_left.front().first
-         && view->cycle() < scores_right.front().first
+    if ( ( ! scores_left.empty()
+           && view->cycle() < scores_left.front().first )
+         && ( ! scores_right.empty()
+              && view->cycle() < scores_right.front().first )
          && view->playmode().mode() != rcsc::PM_PenaltySetup_Left
          && view->playmode().mode() != rcsc::PM_PenaltySetup_Right
          && view->playmode().mode() != rcsc::PM_PenaltyReady_Left
@@ -255,7 +262,7 @@ ScoreBoardPainter::drawPenaltyScores( QPainter & painter )
     int board_width = name_width + cell_size*score_size;
     int board_height = cell_size*3;
 
-    int board_right_x = board_left_x + board_width;
+    //int board_right_x = board_left_x + board_width;
     int board_bottom_y = board_top_y + board_height;
 
     painter.fillRect( board_left_x, board_top_y,
