@@ -32,9 +32,8 @@
 #ifndef SOCCERWINDOW2_QT3_VIEW_CONFIG_DIALOG_H
 #define SOCCERWINDOW2_QT3_VIEW_CONFIG_DIALOG_H
 
-#include <qdialog.h>
+#include <qtabdialog.h>
 
-class QPushButton;
 class QCheckBox;
 class QComboBox;
 class QLabel;
@@ -43,7 +42,6 @@ class QPushButton;
 class QRadioButton;
 class QSlider;
 class QSpinBox;
-class QBoxLayout;
 
 class MainData;
 class ViewConfig;
@@ -51,7 +49,7 @@ class ViewConfig;
 
 //! field canvas configuration dialog
 class ViewConfigDialog
-    : public QDialog {
+    : public QTabDialog {
 
     Q_OBJECT
 
@@ -61,9 +59,14 @@ private:
     ViewConfig & M_view_config;
 
     // zoom control
-    QCheckBox * M_enlarge_cb;
+    //    QCheckBox * M_score_board_auto_fit_cb;
     QSlider * M_scale_slider;
-    QLabel * M_scale_text;
+    QLineEdit * M_scale_text;
+
+    // object size
+    QCheckBox * M_enlarge_cb;
+    QLineEdit * M_ball_size_text;
+    QLineEdit * M_player_size_text;
 
     // canvas size control
     QLineEdit * M_canvas_width_text;
@@ -78,22 +81,34 @@ private:
     QCheckBox * M_hetero_number_cb;
     QCheckBox * M_stamina_cb;
     QCheckBox * M_view_cone_cb;
+    QCheckBox * M_body_shadow_cb;
     QCheckBox * M_control_area_cb;
 
     // show/hide control
+    QCheckBox * M_anonymous_mode_cb;
     QCheckBox * M_show_score_board_cb;
+    QCheckBox * M_show_team_logo_cb;
     QCheckBox * M_show_ball_cb;
     QCheckBox * M_show_players_cb;
     QCheckBox * M_show_flags_cb;
     QCheckBox * M_show_offside_line_cb;
 
-    // grass type
+    // field style
     QRadioButton * M_grass_normal_rb;
     QRadioButton * M_grass_line_rb;
     QRadioButton * M_grass_checker_rb;
 
     QCheckBox * M_keepaway_mode_cb;
 
+    QCheckBox * M_show_grid_coord_cb;
+    QSlider * M_grid_step_slider;
+    QLineEdit * M_grid_step_text;
+
+    QComboBox * M_draw_type_choice;
+
+    // cursor
+    QCheckBox * M_cursor_hide_cb;
+
     // computational geometry control
     QCheckBox * M_show_voronoi_cb;
     QCheckBox * M_show_delaunay_cb;
@@ -140,17 +155,20 @@ private:
 
     void createWidgets();
 
-    QWidget * createZoomControls();
-    QWidget * createCanvasSizeControls();
-    QWidget * createReverseControls();
-    QWidget * createPlayersDetailControls();
-    QWidget * createShowControls();
-    QWidget * createGrassTypeControls();
-    QWidget * createCompGeomControls();
-    QWidget * createFocusControls();
-    QWidget * createPlayerSelectionControls();
-    QWidget * createTraceControls();
-    QWidget * createInertiaMoveControls();
+    QWidget * createZoomControls( QWidget * parent );
+    QWidget * createObjectSizeControls( QWidget * parent );
+    QWidget * createCanvasSizeControls( QWidget * parent );
+    QWidget * createReverseControls( QWidget * parent );
+    QWidget * createPlayersDetailControls( QWidget * parent );
+    QWidget * createShowControls( QWidget * parent );
+    QWidget * createFieldStyleControls( QWidget * parent );
+    QWidget * createMiscControls( QWidget * parent );
+    QWidget * createGridStepControls( QWidget * parent );
+    QWidget * createCompGeomControls( QWidget * parent );
+    QWidget * createFocusControls( QWidget * parent );
+    QWidget * createPlayerSelectionControls( QWidget * parent );
+    QWidget * createTraceControls( QWidget * parent );
+    QWidget * createInertiaMoveControls( QWidget * parent );
 
 
 protected:
@@ -168,8 +186,11 @@ private slots:
 
     // connect to itself
     // emit configured()
+    //    void clickScoreBoardAutoFit( bool checked );
+
     void clickEnlarge( bool checked );
     void slideFieldScale( int value );
+    void editFieldScale( const QString & text );
 
     void clickReverseSide( bool checked );
     void clickPlayerReverseDraw( bool checked );
@@ -178,9 +199,12 @@ private slots:
     void clickShowHeteroNumber( bool checked );
     void clickShowStamina( bool checked );
     void clickShowViewCone( bool checked );
+    void clickShowBodyShadow( bool checked );
     void clickShowControlArea( bool checked );
 
+    void clickAnonymousMode( bool checked );
     void clickShowScoreBoard( bool checked );
+    void clickShowTeamLogo( bool checked );
     void clickShowBall( bool checked );
     void clickShowPlayers( bool checked );
     void clickShowFlags( bool checked );
@@ -192,6 +216,13 @@ private slots:
 
     void clickKeepawayMode( bool checked );
 
+    void clickShowGridCoord( bool checked );
+    void slideGridStep( int value );
+    void editGridStep( const QString & text );
+    void selectDrawType( int index );
+
+    void clickCursorHide( bool checked );
+
     void clickShowVoronoiDiagram( bool checked );
     void clickShowDelaunayTrianglation( bool checked );
     void selectCompGeomSide( int index );
@@ -233,7 +264,10 @@ public slots:
     void zoomIn();
     void zoomOut();
     void unzoom();
+
     void toggleEnlarge();
+    void editBallSize( const QString & text );
+    void editPlayerSize( const QString & text );
 
     void applyCanvasSize();
 
@@ -244,9 +278,12 @@ public slots:
     void toggleShowHeteroNumber();
     void toggleShowStamina();
     void toggleShowViewCone();
+    void toggleShowBodyShadow();
     void toggleShowControlArea();
 
+    void toggleAnonymousMode();
     void toggleShowScoreBoard();
+    void toggleShowTeamLogo();
     void toggleShowPlayers();
     void toggleShowBall();
     void toggleShowFlags();
@@ -265,6 +302,7 @@ public slots:
 
     // 1-11: left, 12-22: right
     void selectPlayer( int number );
+    void choicePlayer( int number );
 
     void toggleKeepawayMode();
 
