@@ -248,10 +248,10 @@ VoronoiDiagramPainter::draw( QPainter & painter )
               it != end;
               ++it )
         {
-            painter.drawLine( vconf.screenX( (*it)->point1.x ),
-                              vconf.screenY( (*it)->point1.y ),
-                              vconf.screenX( (*it)->point2.x ),
-                              vconf.screenY( (*it)->point2.y ) );
+            painter.drawLine( vconf.absScreenX( (*it)->point1.x ),
+                              vconf.absScreenY( (*it)->point1.y ),
+                              vconf.absScreenX( (*it)->point2.x ),
+                              vconf.absScreenY( (*it)->point2.y ) );
         }
     }
 
@@ -265,10 +265,10 @@ VoronoiDiagramPainter::draw( QPainter & painter )
               it != end;
               ++it )
         {
-            painter.drawLine( vconf.screenX( players_pos[(*it)->player1].x ),
-                              vconf.screenY( players_pos[(*it)->player1].y ),
-                              vconf.screenX( players_pos[(*it)->player2].x ),
-                              vconf.screenY( players_pos[(*it)->player2].y ) );
+            painter.drawLine( vconf.absScreenX( players_pos[(*it)->player1].x ),
+                              vconf.absScreenY( players_pos[(*it)->player1].y ),
+                              vconf.absScreenX( players_pos[(*it)->player2].x ),
+                              vconf.absScreenY( players_pos[(*it)->player2].y ) );
         }
     }
 }
